--[[
-- FileName: LayerManager.lua
-- Author: wangming
-- Date: 2015-09-08
-- Purpose: 层的管理器, layroot以及m_baseLayer在一个scene里存在切且唯一，
		在本项目中暂时只存在login以及mainCity的scne切换
		层级结构：
		scene{
		 	layroot{
		 		m_baseLayer,
		 		layer1,
		 		layer2,
		 		layer3,
		 		...
	 		}
		}
	TODO List
]]

LayerManager = {}

LAYER_NAME_TAG = {
	-- LAYER_LOGIN = "login",
	LAYER_MAINCITY = "mainCity",
	LAYER_BATTLE = "battle",
	LAYER_LOADING = "LoadingCircle"
}

local m_director = cc.Director:getInstance()
local m_baseLayer = nil
local m_topinfolayer = nil
local logButton = nil
local particleLayer = nil

local mMrgStack = {} -- 记录当前模块堆叠的容器栈

local nZPop = 100 -- 弹出窗口的初始Zorder
local nShieldLayoutTag = 666669 -- ShieldLayout 的 tag，用于检测是否存在
local nLoadingTag = 666670 -- LoadingTag 的 tag，用于检测是否存在

---------------------get set 控制 -------------------

local function getCurManager()
	return mMrgStack
end

local function getCurRoot()
	return mMrgStack._layRoot
end

local function getCurStack()
	return mMrgStack._tbLayoutStack
end

local function getCurPopStack()
	return mMrgStack._tbPopStack
end

--创建一个全屏幕的layer ， 可控该层是否接收touch
local function getFullLayout( notGetTouch )
	local pLay = cc.Layer:create()
	if(notGetTouch) then
		pLay:setTouchEnabled(false)
	else
		pLay:setTouchEnabled(true)
		local function touchCall( eventType, x, y )
			if (eventType == "began") then
				return true
			end
		end
		pLay:registerScriptTouchHandler(touchCall)
	end
	return pLay
end

function LayerManager:closeLoading()
	local runningScene = m_director:getRunningScene()
	if (runningScene == nil) then
		return
	end
	local loading = runningScene:getChildByTag(nLoadingTag)
	if loading then
		loading:removeFromParent()
	end
end

--[[desc:屏蔽旧界面往新界面传递触摸 添加屏蔽层
—]]
function LayerManager.addShieldLayout( isOnlyGet, sTime )
	if isOnlyGet then
		return getFullLayout()
	end
	local runningScene = m_director:getRunningScene()
	if (runningScene == nil) then
		return
	end
	local touchLayer = getFullLayout()
	touchLayer:setTag(nShieldLayoutTag) 
	runningScene:addChild(touchLayer, nShieldLayoutTag, nShieldLayoutTag)

	local _time = tonumber(sTime) or 0.01
	performWithDelay(touchLayer,function()
		if tolua.isnull(touchLayer) then
			return
		end
		touchLayer:removeFromParent()
		-- local shield = runningScene:getChildByTag(nShieldLayoutTag)
		-- if (shield) then
		-- 	shield:removeFromParent()
		-- end
	end, _time)
end

function LayerManager.getBaseLayer()
	return m_baseLayer
end

function LayerManager.getTopInfoLayer()
	return m_topinfolayer
end

function LayerManager.getCurRootLayer()
	return getCurRoot()
end

function LayerManager.getLogButton()  --获取log按钮
	return logButton
end

function LayerManager.closeLogButton()  --关闭log按钮
	logButton:removeFromParent()
	logButton = nil
end

function LayerManager.reset()
	if m_baseLayer then
		m_baseLayer:removeFromParent()
	end
	m_baseLayer = nil
	if m_topinfolayer then
		m_topinfolayer:removeFromParent()
	end
	m_topinfolayer = nil
	if logButton then
		logButton:removeFromParent()
	end
	logButton = nil
	if particleLayer then
		particleLayer:removeFromParent()
	end
	particleLayer = nil
	mMrgStack = {}
end

--返回主城
function LayerManager.backToMainCity( doOnEnter )
    LayerManager.removeLayoutToDefult( doOnEnter )
end

-------------------UI创建、移除控制-----------------------------
local function _preloadFormations()
	local nowForm = PlayerData:getNowFormationsInfo()
	if not nowForm or not nowForm["status"] then
		return
	end
	for i = 1, 9 do
		local _heroId = tonumber(nowForm["location"..i]) or 0
		if _heroId > 0 then
			local hero = PlayerData:getGeneralInfoById(_heroId)
			zc.battle.createHeroArmature({
				fileName = hero.modelId, 
				async = true, 
				asyncCallback = function(_armature, fileName, num) 
					-- print("wm---_preloadFormationsOver : ", fileName)
				end
			})
		end
	end
end

--登录和进入游戏的初始入口
function LayerManager.pushModule( layerName )--, slayer )
	if layerName ~= LAYER_NAME_TAG.LAYER_MAINCITY 
	  -- and layerName ~= LAYER_NAME_TAG.LAYER_LOGIN
	  then
		return
	end
	LayerManager.reset()
	_preloadFormations()

	local runningScene = cc.Scene:create()
	runningScene:setName(layerName)

	mMrgStack = {}

	local _layRoot = cc.Layer:create()
	runningScene:addChild(_layRoot)
	_layRoot._scene = runningScene
	mMrgStack._layRoot = _layRoot

	mMrgStack._tbLayoutStack = {} --附加到parent上的Layout的容器栈
	mMrgStack._tbPopStack = {} --附加到parent上的Pop的容器栈

	if layerName == LAYER_NAME_TAG.LAYER_MAINCITY then
		m_baseLayer = LayerManager.addLayout("src/layer/mainCity/MainCityLayer.lua", {layerName = LAYER_NAME_TAG.LAYER_MAINCITY})
		-- m_baseLayer = LayerManager.addLayout("src/layer/mainCity/MainCityTestLayer.lua", {layerName = LAYER_NAME_TAG.LAYER_MAINCITY})
		m_topinfolayer = requires("src/layer/mainCity/UserTopLayer.lua"):create({sceneName = LAYER_NAME_TAG.LAYER_MAINCITY})
        _layRoot:addChild(m_topinfolayer)
        --添加一个查看log的按钮（后端用,暂时处理）
        if logButton then
        	logButton:removeFromParent()
        	logButton = nil
        end
        logButton = ZCPushButton:createWithParams({
	        normalFile = "res/Main/common/button/common_btn2_u.png",
	        selectedFile = "res/Main/common/button/common_btn2_d.png",
	        needSwallow = true,
	        endCallback = function()
        		zc.createSourcePop("LogData", "src/layer/log/LogData.lua", {})
	        end,
	        anchor = cc.p(0.5, 0.5),
	        pos = cc.p(20, zc.height - 20)
	    })
    	_layRoot:addChild(logButton)
    	logButton:setVisible(false)
    	-- 添加触摸粒子特效
    	particleLayer = cc.Layer:create()
    	particleLayer:setTouchEnabled( true )
    	particleLayer:setSwallowsTouches( false )
		local function onTouchEvent( eventType, x, y )
			if eventType == "began" then
		    	local particle = cc.ParticleSystemQuad:create("res/Main/multyCopy/weijiesuolizi.plist")
				particle:setPosition( x, y )
				particle:setDuration( 0.5 )
				particleLayer:addChild( particle )
				particle:setAutoRemoveOnFinish(true)
			end
		end
		particleLayer:registerScriptTouchHandler(onTouchEvent)
    	_layRoot:addChild(particleLayer)
		local _currentGID = getGuideManager():getCurrentGID()
	    if _currentGID == GuideKey.KEY_1001 then
	    	zc.createTollgateLayer({
                tollgateId = 1, 
                nationId = 1, 
            })
	    end
	end
	
	m_director:replaceScene(runningScene)
	return runningScene
end

function LayerManager.addNode(node, params, addShield)
	local _layRoot = getCurRoot()
	if not _layRoot then
		-- assert(_layRoot, "addLayout : _layRoot get nil ")
		return nil
	end
	local _addShield = addShield == nil and true or addShield
	if _addShield then
		LayerManager.addShieldLayout()
	end
    local _layer = node
    -- assert(_layer, "addLayout : _layer get nil ")
	if not _layer then
		return nil
	end

    local _params = params or {} 
    local _layerName = _params.layerName
	--设置名字
    if _layerName then
	    _layer:setName(_layerName)

	    if _layerName == LAYER_NAME_TAG.LAYER_LOADING then
	    	local runningScene = m_director:getRunningScene()
			if (runningScene == nil) then
				return nil
			end
			_layer:setTag(nLoadingTag) 
			runningScene:addChild(_layer, nLoadingTag, nLoadingTag)
			return nil
	    end
    end

	--标记这个layer是不是pop
	local _isPop = _params.isPop == nil and false or _params.isPop
	_layer.isPop = _isPop

	local _zorder = tonumber(_params.zorder) or 0
	-- if not _isPop then
	-- 	local _pLayCeng = getFullLayout()
	-- 	_layer:addChild(_pLayCeng, -100)
	-- end
	_layRoot:addChild(_layer, _zorder)


    --标记这个layer存放的table
	local _curStack = _isPop and getCurPopStack() or getCurStack() 
	table.insert(_curStack, _layer)
	print("LayerManager====addOne : ", (_isPop and "pop" or "layer"))
	if not _isPop then
		if not _params.noHide then
			local _length = #_curStack
			local pLay = _curStack[_length-1]
			if pLay then
				if pLay:getLocalZOrder() <= _zorder then
					local pDelayTime = tonumber(_params.delayHide) or 0
					local _doExit = _params.doExit == nil and true or _params.doExit
					local function _toDoExit()
						pLay:setVisible(false)
						if _doExit then
							xpcall(function()
								if pLay.onExit then
									pLay:onExit()
								end
								zc.doFuncForAllChild(pLay, function( child )
									if child.pause then
										child:pause()
									end
								end)
							end, function() end)
						end
					end
					if pDelayTime > 0 then
						performWithDelay(pLay, _toDoExit, pDelayTime)
					else
						_toDoExit()
					end
				end
			end
		end
		
		--然后设置头部信息显示
	    if m_topinfolayer then
			_layRoot:reorderChild(m_topinfolayer, m_topinfolayer:getLocalZOrder())
	        m_topinfolayer:setVisible(true)
	        m_topinfolayer:setPopInfo(_layerName)
	    end
		if logButton then
			_layRoot:reorderChild(logButton, logButton:getLocalZOrder())
			if SHOW_LOG_BUTTON_TEST then
				logButton:setVisible(true)
			else
				logButton:setVisible(false)
			end
		end
	    if particleLayer then
	    	particleLayer:reorderChild(particleLayer, particleLayer:getLocalZOrder())
	    end
	end

	return _layer
end

--[[desc:—
	params : 
		noHide 堆栈上一层隐藏控制
		delayHide 堆栈上一层的延迟隐藏控制

]]
function LayerManager.addLayout(source, params, addShield)
	local _layRoot = getCurRoot()
	if not _layRoot then
		-- assert(_layRoot, "addLayout : _layRoot get nil ")
		return nil
	end
    local layerFile = requires(source)
    local _layer = layerFile:create(params)
	return LayerManager.addNode(_layer, params, addShield)
end

function LayerManager.removeLayout( isPop, notRemove, doOnEnter )
	local _layRoot = getCurRoot()
	if not _layRoot then
		return
	end
	local _isPop = isPop == nil and false or isPop
	local _curStack = _isPop and getCurPopStack() or getCurStack() 
	local _length = _curStack and #_curStack or 0
	local _num = _isPop and 0 or 1
	local _doOnEnter = doOnEnter == nil and true or doOnEnter
	print("LayerManager====removeOne : ", (_isPop and "pop" or "layer"), " , _curStackNum : ", _num, " , ", _length)
	if _length > _num then
		local pLay = _curStack[_length-1]
		local popLayer = table.remove(_curStack)
		if not tolua.isnull(popLayer) then
			if not notRemove then
				popLayer:removeFromParent()
			end
			if not _isPop and not tolua.isnull(pLay) then
				if m_topinfolayer then
			        m_topinfolayer:setVisible(true)
			        m_topinfolayer:setPopInfo(pLay:getName())
				end
				if logButton then
					if SHOW_LOG_BUTTON_TEST then
						logButton:setVisible(true)
					else
						logButton:setVisible(false)
					end
				end
				if not pLay:isVisible() then
					pLay:setVisible(true)
					xpcall(function()
						zc.doFuncForAllChild(pLay, function( child )
							if child.resume then
								child:resume()
							end
						end)
					end, function() end)
					if _doOnEnter then
						xpcall(function()
							if pLay.onEnter then
								-- 仅作刷新界面用，不要在onEnter里调用LayerManager.removeLayout，会导致下面的pLay被移除
								pLay:onEnter()
							end
						end, function() end)
					end
				end
			end
		end
	end
end

function LayerManager.removeLayoutToDefult( doOnEnter )
	m_director:popToRootScene()
	local _doOnEnter = doOnEnter == nil and true or doOnEnter
	local _layRoot = getCurRoot()
	if not _layRoot then
		return
	end
	while true do
		local _curStack = getCurPopStack() or {}
		local _length = #_curStack
		if _length > 0 then
			xpcall(function()
				local popLayer = table.remove(_curStack)
				if not tolua.isnull(popLayer) then
					popLayer:removeFromParent()
				end
			end, function() end)
		else
			break
		end
	end
	local _haveRemove = false
	while true do
		local _curStack = getCurStack() or {}
		local _length = #_curStack
		if _length > 1 then
			xpcall(function()
				local popLayer = table.remove(_curStack)
				if not tolua.isnull(popLayer) then
					popLayer:removeFromParent()
				end
				_haveRemove = true
			end, function() end)
		else
			xpcall(function()
				local pLay = _curStack[_length]
				if not tolua.isnull(pLay) then
					if pLay.removeFarm then
						pLay:removeFarm()
					end
					if not pLay:isVisible() then
						pLay:setVisible(true)
					end
					if m_topinfolayer and pLay:getLocalZOrder() == 0 then
						_layRoot:reorderChild(m_topinfolayer, m_topinfolayer:getLocalZOrder())
				        m_topinfolayer:setVisible(true)
				        m_topinfolayer:setPopInfo("mainCity")
					end

					xpcall(function()
						zc.doFuncForAllChild(pLay, function( child )
							if child.resume then
								child:resume()
							end
						end)
					end, function() end)
					if _haveRemove and _doOnEnter then
						xpcall(function()
							if pLay.onEnter then
								pLay:onEnter()
							end
						end, function() end)
					end
				end
			end, function() end)
			break
		end
	end
	helper.collectMemory()
end

