--[[
    FileName: HotPacksLayer.lua
    Author: andong
    Date: 2016-11-26
    Purpose: 热卖礼包界面
]]
local HotPacksLayer = class( "HotPacksLayer", function ()
    local layer = cc.Sprite:create()
    layer:setContentSize( 720, 463 )
    return layer
end)

function HotPacksLayer:create(parmas)
    return HotPacksLayer.new(parmas)
end

function HotPacksLayer:ctor(parmas)
    self:initData(parmas)
    self:initUI()
    local function onNodeEvent(event)
        if "cleanup" == event then
            self:onCleanup()
        end
    end
    self:registerScriptHandler(onNodeEvent)
end

function HotPacksLayer:initData(parmas)
    local parmas = parmas or {}
    if parmas and parmas.callback then
        self._callback = parmas.callback
    end
    self.activityType = parmas.activityType

    self._table = parmas.table or {}

    self._packgeList = {}
    local _itemList = parmas.numLimit or {}
    for k,v in pairs(_itemList) do
        local _packgeId = tonumber(k) or 0
        -- local _packgeInfo = gameData.getDataFromCacheWithPrimaryKey("hot_gift", _packgeId)
        local _packgeInfo = self._table[tostring(_packgeId)]
        if _packgeInfo and _packgeInfo.id then
            --test
            self._packgeList[#self._packgeList+1] = {
                id = k,
                _info = _packgeInfo,
                _buyNum = tonumber(v) or 0, --购买次数
                _limitNum = tonumber(_packgeInfo.number) or 0, --限购数量
                _limitType = _packgeInfo.limit, --限购类型（1不限、2个人每天、3全服每天、4个人活动时间内、5全服活动时间内）
            }
        end
    end

    table.sort(self._packgeList,function(a, b)
        return tonumber(a.id) < tonumber(b.id)
    end)
end
function HotPacksLayer:initUI()
    self._size = self:getContentSize()
    local background = zc.createSprite("res/Main/activity/hotPacks/mainBg.png")
    local x,y 
    local scalex
    local attr_bgSize
    local layerwidth
    if self.activityType == 2 then
        layerwidth = 960
        background:setScaleX(960/730)
        background:setScaleY(1.2)
        x = self._size.width/2 - 10
        y = self._size.height + 32
        scalex = 960/730
        attr_bgX = self._size.width/2 - 3
        attr_bgSize = cc.size(960, 72)
    else
        layerwidth = 726
        background:setScaleX(730/706)
        x = self._size.width/2
        y = self._size.height + 3
        scalex = 1
        attr_bgX = self._size.width/2+3
        attr_bgSize = cc.size(layerwidth, 72)
    end
    background:setAnchorPoint( 0.5, 1 )
    background:setPosition( x, y)
    self:addChild( background )

    local tipLab = zc.createLabel({
        text = zc.lang("tips_click_box_can_preview"),
        fontSize = 19,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(layerwidth/2 - 180, -34),
        color =cc.c3b(230,224,163),
    })
    self:addChild(tipLab)
    

    self:initTableView()

end
function HotPacksLayer:initTableView()
    local tableNode = self
    local tableSize
    local tablePos
    if self.activityType == 2 then
        tableSize = cc.size(932, 495)
        tablePos = cc.p(tableNode:getContentSize().width/2 - 12, self._size.height + 34)
    else
        tableSize = cc.size(723, 425)
        tablePos = cc.p(tableNode:getContentSize().width/2+5, self._size.height+5)
    end

    local myTableBg = zc.createSprite()
    myTableBg:setContentSize(tableSize)
    myTableBg:setAnchorPoint(cc.p(0.5, 1))
    myTableBg:setPosition(tablePos)

    tableNode:addChild(myTableBg)
    
    local myTable = zc.ZCTableView:create(cc.size(myTableBg:getContentSize().width-4,myTableBg:getContentSize().height-4))
    myTable:setPosition(2,2)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_HORIZONTAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    
    myTableBg:addChild(myTable)
    
    local function cellSizeForTable(table,idx)
        return tableSize.height, 150
    end
    local function numberOfCellsInTableView(table)
        return #self._packgeList
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(150, tableSize.height)
        else
            cell:removeAllChildren()
        end
        self:updateCell(cell, nowIdx)
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    
    myTable:reloadData()
    self._myTable = myTable

end
function HotPacksLayer:updateCell( cell, nowIdx )

    local cellData = self._packgeList[nowIdx]
    local _info = cellData._info or {}
    local cellSize = cell:getContentSize()

    local touchSprite = zc.createSprite()
    touchSprite:setContentSize(cellSize)
    touchSprite:setPosition(cellSize.width/2,cellSize.height/2)
    cell:addChild(touchSprite)


    local _labType = tonumber(_info.label) or 0
    local _titlePath = ""
    if _labType > 0 then
        _titlePath = "res/Main/activity/hotPacks/type_".._labType..".png"
        if not zc.checkFileExist(_titlePath) then
            _titlePath = "res/Main/activity/hotPacks/type_1.png"
        end
    end
    if _titlePath ~= "" then
        local title = zc.createSprite(_titlePath)
        title:setAnchorPoint(0, 1)
        title:setPosition(0, cellSize.height)
        touchSprite:addChild(title, 1)
    end
    
    local _backgroundType = tonumber(_info.light) or 1
    local imgPath = "res/Main/activity/hotPacks/bj_".._backgroundType..".png"

    if not zc.checkFileExist(imgPath) then
        imgPath = "res/Main/activity/hotPacks/bj_1.png"
        _backgroundType = 1
    end
    local cell_bg = zc.createSprite(imgPath)
    cell_bg:setAnchorPoint(0.5, 0.5)
    -- cell_bg:setScaleY(1.2)
    cell_bg:setPosition(cellSize.width/2, cellSize.height/2 - 50)
    touchSprite:addChild(cell_bg)

    local nameBg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(42, 180))
    nameBg:setAnchorPoint(cc.p(0, 1))
    nameBg:setPosition(cc.p(18, cell_bg:getContentSize().height-60))
    cell_bg:addChild(nameBg)

    local name = zc.createLabel({
        text = zc.getActivityGtChangeTest(_info.giftname),
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 1),
        pos = cc.p(8, nameBg:getContentSize().height-6),
        color = cc.c3b(255,238,169),
        color2 =cc.c3b(38,2,2),
        pixel = 2,
        width = 22,
    })
    nameBg:addChild(name)
    name:setLineSpacing(-4)

    local _descColor1 = display.COLOR_WHITE
    local _descColor2 = display.COLOR_BLACK
    if _backgroundType == 1 then --绿色背景
        _descColor1 = cc.c3b(255,180,0)
        _descColor2 = cc.c3b(28,7,0)
    elseif _backgroundType == 2 then --蓝色背景
        _descColor1 = cc.c3b(137,231,201)
    elseif _backgroundType == 3 then --紫色背景
        _descColor1 = cc.c3b(255,159,186)
    end

    local descLab = zc.createLabel({
        text = zc.getActivityGtChangeTest(_info.remark),
        outLine = true,
        fontSize = 18,
        ap = cc.p(0, 1),
        pos = cc.p(80, nameBg:getPositionY() ),
        color = _descColor1,
        color2 = _descColor2,
        pixel = 2,
        width = 18,
    })
    cell_bg:addChild(descLab)
    descLab:setLineSpacing(-5)

    local itemBg = zc.createSprite("res/Main/activity/hotPacks/itemBg.png")
    itemBg:setAnchorPoint(0.5, 0.5)
    itemBg:setPosition(cell_bg:getContentSize().width/2, cellSize.height - 65)
    cell_bg:addChild(itemBg)

    local iocnPath = "res/Main/activity/hotPacks/lb_"..tostring(_info.icon)..".png"
    if not zc.checkFileExist(iocnPath) then
        iocnPath = "res/Main/activity/hotPacks/lb_101.png"
    end
    local itemSize = itemBg:getContentSize()
    local itemImg = zc.createSprite(iocnPath)
    itemImg:setAnchorPoint(0.5, 0.5)
    itemImg:setPosition(itemSize.width/2, itemSize.height/2)
    itemBg:addChild(itemImg)

    local priceBg = zc.createSprite("res/Main/activity/hotPacks/pricebg.png")
    priceBg:setAnchorPoint(0.5, 0.5)
    priceBg:setPosition(itemBg:getContentSize().width/2, 10)
    itemBg:addChild(priceBg)
    local price = zc.createLabel({
        text = zc.getGtMoneyFlag() .. zc.changeGtMoney(_info.price),
        outLine = true,
        fontSize = 22,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(priceBg:getContentSize().width/2, priceBg:getContentSize().height/2),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    priceBg:addChild(price)

    --卖完
    local _limitType = tonumber(cellData._limitType) or 1

    --限购类型（1不限、2个人每天、3全服每天、4个人活动时间内、5全服活动时间内）
    local _scaledOut = false --是否卖完
    local _buyNum = tonumber(cellData._buyNum) or 0
    local _limitNum = tonumber(cellData._limitNum) or 0

    if _limitType == 1 then
    elseif _limitType == 2 then
    elseif _limitType == 3 then
    elseif _limitType == 4 then
    elseif _limitType == 5 then
    end
    if _limitType ~= 1 and _buyNum >= _limitNum then
        _scaledOut = true
    end

    if _scaledOut then
        local _scaledOutImg = zc.createSprite("res/Main/activity/hotPacks/saled.png")
        _scaledOutImg:setAnchorPoint(0.5, 0.5)
        _scaledOutImg:setPosition(cell_bg:getContentSize().width/2+10, 120)
        cell_bg:addChild(_scaledOutImg)
    end

    local btn = ccui.Widget:create()
    btn:setContentSize( cellSize )
    btn:setPosition( cellSize.width/2, cellSize.height/2 )
    btn:setTouchEnabled( true )
    btn:setSwallowTouches( false )
    btn:onTouch(function(event)
        if event.name == "began" then
            touchSprite:runAction(
                cc.ScaleTo:create( 0.05, 0.9 )
            )
        elseif event.name == "moved" then
        elseif event.name == "ended" then
            touchSprite:runAction(
                cc.ScaleTo:create( 0.05, 1 )
            )
            zc.createSourcePop("HotPacksReward", "src/layer/activity/HotPacksRewardPop.lua", {
                packageInfo=cellData,
                callback = function()
                    self._myTable:reloadDataAndScrollToCurrentCell()
                end,
            })
        elseif event.name == "cancelled" then
            touchSprite:runAction(
                cc.ScaleTo:create( 0.05, 1 )
            )
        end
    end)
    cell:addChild( btn )
end

function HotPacksLayer:onCleanup()
    if self._callback and type(self._callback) == "function" then
        self._callback()
    end
end

return HotPacksLayer