--[[
	七日活动领取兵器
	唐实聪
	2016.6.29
]]
local SevenDayWeaponPop = class("SevenDayWeaponPop", function()
	return ZCPopLayer:create()
end)

function SevenDayWeaponPop:create( params )
	return SevenDayWeaponPop.new( params )
end

function SevenDayWeaponPop:ctor( params )
	self:initData( params )
	self:initUI()
	-- self:refresh( 1 )
end

function SevenDayWeaponPop:initData( params )
	self._list = params._list
	-- dump( self._list, "_list" )
	self._data = params._data
	-- dump( self._data, "_data" )
	self._callback = params._callback

	if not self._list then
		-- 没有数据，只是预览，需要自己取数据
		local _list = gameData.getDataFromCache("sevenDay", {days=7, type=1})
		if #_list == 0 and next(_list) then
			_list = { _list }
		end
		for i, v in ipairs( _list ) do
			local _conditions = tonumber( string.split( v.conditions, "|" )[1] ) or 0
			local _flag = false
			if _conditions == 48 then
				_flag = true
			end
			if _flag then
				local _tmp = clone( v )
				local _reward = {}
				for j, u in ipairs( string.split( _tmp.awards, "," ) ) do
					local _item = string.split( u, "|" )
					_reward[#_reward + 1] = {
						itemType = _item[1],
						itemId = _item[2],
						itemNum = _item[3],
					}
				end
				_tmp.reward = _reward
				self._list = _tmp
			end
		end
	end


	self._weapon = {}

	self._index = nil

	self._size = self:getContentSize()
end

function SevenDayWeaponPop:initUI()
	local _bg = cc.LayerColor:create( cc.c4b( 0, 0, 0, 200 ) )
	_bg:setAnchorPoint( 0, 0 )
	_bg:setTouchEnabled( true )
	_bg:setSwallowsTouches( true )
	self:addContent( _bg )
	self._bg = _bg
	local _bgSize = _bg:getContentSize()
	local _bgWidth = _bgSize.width
	local _bgHeight = _bgSize.height
	-- 返回
	local _back = zc.createTopBackButton({
		listener = function ()
			self:hide()
		end
	})
	_bg:addChild( _back )
	-- 六把兵器
	local _dif = 160
	local _beginX = ( _bgWidth - _dif*5 )/2 - _dif + 20
	for i, v in ipairs( self._list.reward or {} ) do
		local _posX = _beginX + _dif*i
		-- 背景
		local _weaponBg = cc.Sprite:create( "res/Main/activity/sevenDay/weapon_bg_u.png" )
		_weaponBg:setPosition( _posX, 367 )
		_bg:addChild( _weaponBg )
		-- 阴影
		local _shadow = cc.Sprite:create( "res/Main/activity/sevenDay/weapon_shadow.png" )
		_shadow:setPosition( _posX - 15, 274 )
		_bg:addChild( _shadow )
		-- 兵器
		local _info = gameData.getDataFromCacheWithPrimaryKey("weapon", v.itemId)
		local _weapon = zc.createSprite("res/Main/weapon/weaponImage/".._info.iconId..".png")
		local _type = tonumber( _info.type ) or 0
		if _type == 1 then
			-- 长柄兵器
			_weapon:setAnchorPoint( 1, 0.5 )
			_weapon:setRotation( 90 )
			_weapon:setPosition( _posX - 5, 255 )
			_shadow:setPositionX( _posX - 10 )
		elseif _type == 2 or _type == 4 then
			_weapon:setAnchorPoint( 0.5, 0.5 )
			_weapon:setRotation( 90 )
			_weapon:setPosition( _posX - 10, 380 )
		else
			_weapon:setAnchorPoint( 0.5, 0.5 )
			_weapon:setPosition( _posX - 10, 380 )
		end
		zc.showWeaponEffect( _weapon, v.itemId )
		_bg:addChild( _weapon )
		-- 名字
		local _weaponName = zc.createLabel({
			text = _info.name,
	        fontSize = 20,
	        outLine = true,
	        pixel = 1.5,
	        color2 = display.COLOR_BLACK,
	        color = display.COLOR_WHITE,
	        ap = cc.p( 0.5, 0.5 ),
	        pos = cc.p( _posX - 35, 220 ),
		})
		_bg:addChild( _weaponName )
		self._weapon[i] = {
			_weaponBg = _weaponBg,
			_shadow = _shadow,
			_weapon = _weapon,
			_weaponName = _weaponName,
		}
		-- btn
		local _weaponSize = _weapon:getContentSize()
		if _weaponSize.width == 0 then
			_weaponSize = cc.size(90,90)
		end
		local _btn = ccui.Widget:create()
		_btn:setTouchEnabled( true )
		_btn:setContentSize( _weaponSize )
		_btn:setAnchorPoint( _weapon:getAnchorPoint() )
		_btn:setPosition( _weapon:getPosition() )
		_btn:setRotation( _weapon:getRotation() )
		_btn:onTouch(function(event)
			if event.name == "began" then
				self:stopAllActions()
				self._touch = true
				self:runAction(
					cc.Sequence:create(
						cc.DelayTime:create(
							0.3
						),
						cc.CallFunc:create(function()
							if self._touch then
								self:showAttr( i, v )
							end
						end)
					)
				)
            elseif event.name == "ended" then
            	self._touch = false
            	if zc.getPop("itemDetail") then
            		zc.closePop("itemDetail")
            	else
		            if self._index ~= i then
			            self:refresh( i )
			        end
            	end
		    elseif event.name == "cancelled" then
            	self._touch = false
		    	self:hideAttr()
            end
        end)
		_bg:addChild( _btn )

	end
	-- 标题
	local _title = cc.Sprite:create( "res/Main/activity/sevenDay/weapon_title.png" )
	_title:setAnchorPoint( 0.5, 1 )
	_title:setPosition( _bgWidth/2, _bgHeight )
	_bg:addChild( _title )
	-- 提示
	local _tip = zc.createLabel({
		text = zc.lang("tips_weaponday"),
        fontSize = 20,
        color = cc.c3b( 127, 128, 129 ),
        ap = cc.p( 0.5, 0.5 ),
        pos = cc.p( _bgWidth/2, 120 ),
        outLine = true,
	})
	_bg:addChild( _tip )
	local _length = _tip:getStringLength()
	for i = _length - 4, _length - 1 do
    	_tip:getLetter( i ):setColor( zc.COLOR_RED )
    end
    local _tip_2 = zc.createLabel({
		text = zc.lang("tips_weaponday_tip"),
        fontSize = 20,
        color = cc.c3b( 127, 128, 129 ),
        ap = cc.p( 0.5, 0.5 ),
        pos = cc.p( _bgWidth/2, 150 ),
        outLine = true,
	})
	_bg:addChild( _tip_2 )
	-- 领取
	local _fetchBtn = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("fetch_2"),
		pos = cc.p( _bgWidth/2, 67 ),
		endCallback = function()
			if self._index then
				zc.sendHttp({
					apiName = "SevenDay_delivery",
					params = {id = self._data.id, arg = self._index},
					successCallback = function(backData)
		                PlayerData:updataData( backData )
		                local _weaponInfo = nil
		                for i, v in ipairs( backData.clientItems ) do
		                 	if tonumber( v.type ) == 3 then
		                 		_weaponInfo = PlayerData:getWeaponInfoInfoById( v.model.id )
		                 		break
		                 	end
		                end
		                if _weaponInfo then
		                	zc.createPop("makeGodWeapon", {info = _weaponInfo, onlyShow = true})
		                end

		                if self._callback then
		                	self._callback()
		                end
						self:hide()
					end,
				})
			else
				zc.tipInfo(zc.lang("tips_weaponday_need_choose"))
			end
		end
	})
	_bg:addChild( _fetchBtn )
	-- 没有数据，只是预览
	if not self._data then
		_fetchBtn:setEnable( false )
		-- _fetchBtn:setBright( false )
	end
end

function SevenDayWeaponPop:refresh( index )
	if self._index then
		self._weapon[self._index]._weaponBg:setTexture( "res/Main/activity/sevenDay/weapon_bg_u.png" )
		self._weapon[self._index]._shadow:setTexture( "res/Main/activity/sevenDay/weapon_shadow.png" )
		self._weapon[self._index]._shadow:setPositionX( self._weapon[self._index]._shadow:getPositionX() - 7 )
		self._weapon[self._index]._shadow:setPositionY( self._weapon[self._index]._shadow:getPositionY() - 40 )
		self._weapon[self._index]._weapon:setPositionX( self._weapon[self._index]._weapon:getPositionX() - 9 )
		self._weapon[self._index]._weapon:setPositionY( self._weapon[self._index]._weapon:getPositionY() - 50 )
		self._weapon[self._index]._weaponName:setPositionX( self._weapon[self._index]._weaponName:getPositionX() - 5 )
		self._weapon[self._index]._weaponName:setPositionY( self._weapon[self._index]._weaponName:getPositionY() - 30 )
	end
	self._index = index
	self._weapon[self._index]._weaponBg:setTexture( "res/Main/activity/sevenDay/weapon_bg_d.png" )
	self._weapon[self._index]._shadow:setTexture( "res/Main/activity/sevenDay/weapon_matrix.png" )
	self._weapon[self._index]._shadow:setPositionX( self._weapon[self._index]._shadow:getPositionX() + 7 )
	self._weapon[self._index]._shadow:setPositionY( self._weapon[self._index]._shadow:getPositionY() + 40 )
	self._weapon[self._index]._weapon:setPositionX( self._weapon[self._index]._weapon:getPositionX() + 9 )
	self._weapon[self._index]._weapon:setPositionY( self._weapon[self._index]._weapon:getPositionY() + 50 )
	self._weapon[self._index]._weaponName:setPositionX( self._weapon[self._index]._weaponName:getPositionX() + 5 )
	self._weapon[self._index]._weaponName:setPositionY( self._weapon[self._index]._weaponName:getPositionY() + 30 )
end
-- 没必要重新写个弹窗，在当前界面处理
function SevenDayWeaponPop:showAttr( index, info )
	self:hideAttr()
	
	local _posX = 0
	if index <= 3 then
		_posX = self._bg:getContentSize().width/4*3
	else
		_posX = self._bg:getContentSize().width/4
	end
	do
		zc.createPop("itemDetail", {
			point = cc.p(_posX, self._bg:getContentSize().height/2),
			params = {
	            mainType=info.itemType,
	            type=info.itemId,
	            id=info.itemId,
			},
		})
		return
	end
	local _width = 400
	local _height = 180 + 30*#_attr

	-- 背景
	local _attrBg = ccui.Scale9Sprite:create( cc.rect( 15, 15, 70, 70 ), "res/Main/common/common_inner17.png" )
	_attrBg:setContentSize( _width, _height )
	_attrBg:setPosition( _posX, self._bg:getContentSize().height/2 )
	self._bg:addChild( _attrBg )
	self._attrBg = _attrBg
	
	-- 兵器名字
	local name = zc.createLabel({
		text = info.name,
		fontSize = 25,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 40, _height - 50 ),
	})
	_attrBg:addChild( name )

	-- 需求等级
	local level = zc.createLabel({
		text = zc.lang("need_level") .. ": "..info.needLevel,
		fontSize = 25,
        color = zc.COLOR_YELLOW,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 40, _height - 80 ),
	})
	_attrBg:addChild( level )

	-- 分隔线
	local ruleSplit = ccui.Scale9Sprite:create( cc.rect( 0, 0, 1, 2 ), "res/Main/common/spline.png" )
	ruleSplit:setContentSize( _width - 18, 5 )
	ruleSplit:setPosition( _width/2, _height - 100 )
	_attrBg:addChild( ruleSplit )

	-- 基础属性
	local _baseAttrTitle = zc.createLabel({
		text = zc.lang("base_attribute"),
		fontSize = 25,
        ap = cc.p( 0.5, 0.5 ),
        pos = cc.p( 80, _height - 125 ),
	})
	_attrBg:addChild( _baseAttrTitle )
	-- 极限属性
	local _limitAttrTitle = zc.createLabel({
		text = zc.lang("limit_attribute"),
		fontSize = 25,
        ap = cc.p( 0.5, 0.5 ),
        pos = cc.p( 264, _height - 125 ),
	})
	_attrBg:addChild( _limitAttrTitle )

	-- 属性
	for i, v in ipairs( _attr ) do
		local _base = zc.createLabel({
			text = zc.getEquipAttriNameByEffectType( v.effectId, true ).. " : "..zc.getAttributeNumById( v.effectId, v.valueMax ),
			fontSize = 25,
	        color = zc.COLOR_BLUE,
	        ap = cc.p( 0, 0.5 ),
	        pos = cc.p( 20, _height - 125 - i*30 ),
		})
		_attrBg:addChild( _base )
		local _limit = zc.createLabel({
			text = zc.getEquipAttriNameByEffectType( v.effectId, true ).. " : "..zc.getAttributeNumById( v.effectId, v.valueLimit ),
			fontSize = 25,
	        color = zc.COLOR_BLUE,
	        ap = cc.p( 0, 0.5 ),
	        pos = cc.p( 204, _height - 125 - i*30 ),
		})
		_attrBg:addChild( _limit )
	end
end

function SevenDayWeaponPop:hideAttr()
	if zc.getPop("itemDetail")  then 
	    zc.closePop("itemDetail")
	end
end

return SevenDayWeaponPop