--[[
	演武榜战报
	唐实聪
	2016.3.18
]]
local ArenaRecordPop = class("ArenaRecordPop", function()
	return ZCPopLayer:create()
end)

function ArenaRecordPop:create( params )
	return ArenaRecordPop.new( params )
end

function ArenaRecordPop:ctor( params )
	self:show()
	self:initData( params )
	self:initUI()
end

function ArenaRecordPop:initData( params )
	self._recordType = tonumber(params.data.recordType) or 1
	local recordData = params.data.records
	-- dump( recordData )
	self._myUserId = tonumber( PlayerData:getBaseInfo().userId )
	-- 战报
	self._recordData = {}
	-- 防守战报
	self._recordData[1] = {}
	-- 进攻战报
	self._recordData[2] = {}
	for i, v in ipairs( recordData ) do
		if tonumber( v.attackerId ) == self._myUserId then
			self._recordData[2][#self._recordData[2] + 1] = v
		elseif tonumber( v.defenderId ) == self._myUserId then
			self._recordData[1][#self._recordData[1] + 1] = v
		end
	end
	-- 按时间倒序排序
	for i, v in ipairs( self._recordData ) do
		table.sort(v, function( a, b )
			return a.time > b.time
		end)
	end

	-- 进攻战报和防守战报
	self._type = params.data.type or 1
	self._size = self:getContentSize()
	self._rightSize = cc.size( 685, 450 )
end

function ArenaRecordPop:initUI()
	-- 标题背景云
	local titleCloud = cc.Sprite:create( "res/Main/common/title_bg_cloud.png" )
	self:addContent( titleCloud )
	-- 背景
	local background = zc.createNormalPop({
		tag = 2,
		src = "res/Main/common/popBg/bgWhite.png",
		bianZOrder = 0,
		height = 527 + 31,
	})
	background:setPosition( self._size.width/2, self._size.height/2 )
	self:addContent( background )
	self._bg = background
	self._bgSize = background:getContentSize()

	titleCloud:setAnchorPoint( 0, 0.5 )
	titleCloud:setPosition( self._size.width/2 - background:getContentSize().width/2 - 80, self._size.height/2 + background:getContentSize().height/2 )
	-- 标题背景
	local titleBg = cc.Sprite:create( "res/Main/common/title_bg_shadow.png" )
	titleBg:setAnchorPoint( 0, 0.5 )
	titleBg:setPosition( -30, self._bgSize.height )
	self._bg:addChild( titleBg )
	-- 标题
	local title = cc.Sprite:create( "res/Main/arena/record/title.png" )
	title:setAnchorPoint( 0, 0.5 )
	title:setPosition( -5, self._bgSize.height )
	self._bg:addChild( title )
	-- 左边标签
	self:initLeft()
	-- 右边
	self:initRight()
	-- 关闭按钮
	local closeBtn = zc.createBackButton({
		pos = cc.p( self._bgSize.width, self._bgSize.height ),
		listener = function ()
			self:hide()
		end
	})
	self._bg:addChild( closeBtn )

	-- 入场动画
	self:initAnimation()
end
-- 初始化左侧
function ArenaRecordPop:initLeft()
	self._typeBtn = {}
	local textTmp = {
		[1] = LANGUAGE_ARENA.defence,
		[2] = LANGUAGE_ARENA.attack,
	}
	for i = 1, 2 do
		local typeBtn = zc.createTypeBtn({
			pos = cc.p( 86, 500 - 72*i ),
			btnText = textTmp[i]
		})
		self._bg:addChild( typeBtn )
		self._typeBtn[i] = typeBtn
		
		-- 监听事件
		typeBtn:setTouchEndedCall(function()
			if self._type ~= i then
				self._typeBtn[self._type]:setSelected(false)
				self._typeBtn[i]:setSelected(true)
				self._type = i
				self:initAnimation()
			end
        end)
	end
	self._typeBtn[self._type]:setSelected(true)
end
-- 初始化右侧
function ArenaRecordPop:initRight()
	-- 容器
	local rightContainer = cc.Sprite:create()
	rightContainer:setContentSize( self._rightSize )
	rightContainer:setAnchorPoint( 0, 0.5 )
	rightContainer:setPosition( 163, 240 )
	self._bg:addChild( rightContainer )
	self._rightContainer = rightContainer
	-- 背景
    local rightBg = ccui.Scale9Sprite:create( cc.rect( 25, 26, 3, 2 ), "res/Main/common/common_inner20.png" )
    rightBg:setContentSize( self._rightSize.width, self._rightSize.height + 6 )
    rightBg:setPosition( self._rightSize.width/2, self._rightSize.height/2 )
    rightContainer:addChild( rightBg )

    -- 顶部滑动阴影
    local topShadow = cc.Sprite:create( "res/Main/arena/rank/shadow.png" )
    topShadow:setAnchorPoint( 0.5, 1 )
    topShadow:setPosition( self._rightSize.width/2, self._rightSize.height )
    rightContainer:addChild( topShadow, 1 )
    self._topShadow = topShadow
    topShadow:setVisible( false )
    local topArrow = cc.Sprite:create( "res/Main/common/arrow_left.png" )
    topArrow:setRotation( 90 )
    topArrow:setScale( 0.5 )
    topArrow:setAnchorPoint( 0, 0.5 )
    topArrow:setPosition( topShadow:getContentSize().width/2, topShadow:getContentSize().height )
    topShadow:addChild( topArrow )
    topArrow:runAction(
    	cc.RepeatForever:create(
    		cc.Sequence:create(
	    		cc.MoveTo:create(
	    			2, cc.p( topShadow:getContentSize().width/2, topShadow:getContentSize().height - 10 )
				),
	    		cc.MoveTo:create(
	    			2, cc.p( topShadow:getContentSize().width/2, topShadow:getContentSize().height )
				)
			)
		)
	)
    -- 底部滑动阴影
    local bottomShadow = cc.Sprite:create( "res/Main/arena/rank/shadow.png" )
    bottomShadow:setFlippedY( true )
    bottomShadow:setAnchorPoint( 0.5, 0 )
    bottomShadow:setPosition( self._rightSize.width/2, 0 )
    rightContainer:addChild( bottomShadow, 1 )
    self._bottomShadow = bottomShadow
    bottomShadow:setVisible( false )
    local bottomArrow = cc.Sprite:create( "res/Main/common/arrow_left.png" )
    bottomArrow:setRotation( -90 )
    bottomArrow:setScale( 0.5 )
    bottomArrow:setAnchorPoint( 0, 0.5 )
    bottomArrow:setPosition( topShadow:getContentSize().width/2, 0 )
    bottomShadow:addChild( bottomArrow )
    bottomArrow:runAction(
    	cc.RepeatForever:create(
    		cc.Sequence:create(
	    		cc.MoveTo:create(
	    			2, cc.p( topShadow:getContentSize().width/2, 10 )
				),
	    		cc.MoveTo:create(
	    			2, cc.p( topShadow:getContentSize().width/2, 0 )
				)
			)
		)
	)
	-- tableview
	local recordTabelview = zc.ZCTableView:create( self._rightSize )
    recordTabelview:setBounceable( true )
    recordTabelview:setInertia( true )
    recordTabelview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    recordTabelview:setPosition( cc.p( 0, 0 ) )
    recordTabelview:setDelegate()
    recordTabelview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local _scale = 0.98
    local cellWidth = self._rightSize.width
    local cellHeight = 96
    -- 屏幕上显示的cell数量
    local cellShowNum = math.ceil( self._rightSize.height/cellHeight )
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildCell( cell, index, cellWidth, cellHeight )
        end
        cell._cellBg:stopAllActions()
        cell._cellBg:setScale( _scale )
        -- 更新界面
        self:updateCell( cell, index, cellHeight )
        return cell
    end
    local function numberOfCellsInTableView()
        return #self._recordData[self._type]
    end
    local function scorllviewScriptScroll( table )
    	local cellNum = numberOfCellsInTableView()
    	if cellNum > cellShowNum then
        	self:scorllviewScriptScroll( table, cellNum )
        end
    end
    recordTabelview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    recordTabelview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    recordTabelview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    recordTabelview:registerScriptHandler( scorllviewScriptScroll, zctech.SCROLLVIEW_SCRIPT_SCROLL )
    rightContainer:addChild(recordTabelview)
    self._recordTabelview = recordTabelview
end
function ArenaRecordPop:buildCell( cell, cellIndex, cellWidth, cellHeight )
	cell._index = cellIndex
	cell._shareData = ""
	local middleY = cellHeight/2
	-- 背景
	local cellBg = cc.Sprite:create()
	cellBg:setContentSize( 686, 92 )
	cellBg:setPosition( cellWidth/2, middleY )
	cell:addChild( cellBg )
	cell._cellBg = cellBg
	-- 胜利失败图标
	local winLoseIcon = cc.Sprite:create()
	winLoseIcon:setContentSize( 74, 58 )
	winLoseIcon:setPosition( 44, middleY )
	cellBg:addChild( winLoseIcon )
	cell._winLoseIcon = winLoseIcon
	-- 分隔线1
	local split1 = cc.Sprite:create( "res/Main/arena/rank/split.png" )
	split1:setPosition( 88, middleY )
	cellBg:addChild( split1 )
	-- 积分
	local score = zc.createLabel({
        fontSize = 20,
        outLine = true,
        pixel = 1.3,
        alignment = cc.TEXT_ALIGNMENT_CENTER,
        pos = cc.p( 140, middleY ),
	})
	cellBg:addChild( score )
	cell._score = score
	-- 分隔线2
	local split2 = cc.Sprite:create( "res/Main/arena/rank/split.png" )
	split2:setPosition( 192, middleY )
	cellBg:addChild( split2 )
    -- 兵器图标
    local weaponIcon = cc.Sprite:create()
    weaponIcon:setContentSize( 39, 39 )
    weaponIcon:setPosition( 295, 65 )
    cellBg:addChild( weaponIcon, 1 )
    cell._weaponIcon = weaponIcon
    -- 名字背景
    local nameBg = cc.Sprite:create( "res/Main/arena/record/nameBg.png" )
    nameBg:setAnchorPoint( 0, 0.5 )
    nameBg:setPosition( weaponIcon:getPositionX() - 4, weaponIcon:getPositionY() )
    cellBg:addChild( nameBg )
    cell._nameBg = nameBg
	-- 名字
	local name = zc.createLabel({
        fontSize = 20,
        outLine = true,
        pixel = 1.3,
        alignment = cc.TEXT_ALIGNMENT_CENTER,
        pos = cc.p( nameBg:getContentSize().width/2, nameBg:getContentSize().height/2 ),
	})
	nameBg:addChild( name )
	cell._name = name
	-- 战斗力图片
    local fightingSp = cc.Sprite:create( "res/Main/hero/hero_zdl.png" )
    fightingSp:setAnchorPoint( 0, 0.5 )
    fightingSp:setPosition( 287, 24 )
	cellBg:addChild( fightingSp )
	-- 战斗力数字
	local fightingNum = zc.createFntLabel({
        fnt = "res/Main/common/fnt/fight.fnt",
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 95, fightingSp:getContentSize().height/2 - 7 ),
        addwidth = -5,
    })
    fightingSp:addChild( fightingNum )
    cell._fightingNum = fightingNum
    -- 时间
    local time = zc.createLabel({
        fontSize = 18,
        color = display.COLOR_GRAY,
        -- stroke = true,
        pixel = 1.3,
        alignment = cc.TEXT_ALIGNMENT_CENTER,
        pos = cc.p( 588, 75 ),
	})
	cellBg:addChild( time )
	cell._time = time
	-- 分享按钮
	local shareBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/btn_sec_small_u.png",
        selectedFile = "res/Main/common/button/btn_sec_small_d.png",
        pos = cc.p( 547, 35 ),
        endCallback = function()
        	getNetManager():getRequestCenter():sendBattleFieldChatData( cell._shareData )
	        zc.tipInfo( LANGUAGE_ARENA.share_success )
    	end
	})
	cellBg:addChild( shareBtn )
	local shareBtnIcon = cc.Sprite:create( "res/Main/arena/record/share_icon.png" )
	shareBtnIcon:setPosition( shareBtn:getContentSize().width/2, shareBtn:getContentSize().height/2 )
	shareBtn:addChild( shareBtnIcon )
	
	-- 播放按钮
	local playBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/btn_sec_small_u.png",
        selectedFile = "res/Main/common/button/btn_sec_small_d.png",
        pos = cc.p( 630, 35 ),
        endCallback = function()
	        if self._recordType == 2 then
	        	zc.createBattleByWarKey(cell._warkey)
	        	return
	        end
        	zc.sendHttp({
        		apiName = "Arena_replay",
        		params = {recordId=cell._recordId},
        		successCallback = function(data)
	        		self:hide()
	        		local _data = {}
	        		_data.data = data
	        		_data.battleType = BattleType.ARENA
	        		local battle = zc.createBattle({data = _data})
	                battle:play()
	    		end
    		})
    	end
	})
	cellBg:addChild( playBtn )
	local playBtnIcon = cc.Sprite:create( "res/Main/arena/record/play_icon.png" )
	playBtnIcon:setPosition( playBtn:getContentSize().width/2, playBtn:getContentSize().height/2 )
	playBtn:addChild( playBtnIcon )
end

function ArenaRecordPop:updateCell( cell, cellIndex, cellHeight )
	-- 数据
	local data = self._recordData[self._type][cellIndex + 1]
	cell._index = cellIndex
	cell._recordId = data.id
	cell._warkey = data.warKey
	-- 数据是相对于进攻方防守方，显示需要相对玩家
	if self._type == 1 then
		-- 防守
		data.defenderInfo.userId = PlayerData.info.userId
		data.defenderInfo.userName = PlayerData.info.userName
		if data.result == 1 then
			-- 进攻方胜利，玩家失败
			cell._cellBg:setTexture( "res/Main/arena/record/cellBg_lose.png" )
			cell._winLoseIcon:setTexture( "res/Main/arena/record/icon_lose.png" )
			cell._score:setColor( display.COLOR_BLUE )
	    	if data.addScores then
				cell._score:setText( LANGUAGE_ARENA.score..":-"..data.deductScores )
				cell._shareData = LANGUAGE_ARENA_SHAREDATA( 1, data )
			elseif data.num then
				local _num = tonumber(data.num) or 0
				if _num == 0 then
					cell._score:setText(zc.lang("food") .. ":" .. data.num)
				else
					cell._score:setText(zc.lang("food") .. ":-" .. data.num)
				end
				cell._shareData = LANGUAGE_ARENA_SHAREDATA(6, data )
			end
		else
			-- 进攻方失败，玩家胜利
			cell._cellBg:setTexture( "res/Main/arena/record/cellBg_win.png" )
			cell._winLoseIcon:setTexture( "res/Main/arena/record/icon_win.png" )
			cell._score:setColor( display.COLOR_GREEN )
			if data.addScores then
				cell._score:setText( LANGUAGE_ARENA.score..":-"..data.deductScores )
				cell._shareData = LANGUAGE_ARENA_SHAREDATA( 2, data )
			elseif data.num then
				local _num = tonumber(data.num) or 0
				if _num == 0 then
					cell._score:setText(zc.lang("food") .. ":" .. data.num)
				else
					cell._score:setText(zc.lang("food") .. ":-" .. data.num)
				end
				cell._shareData = LANGUAGE_ARENA_SHAREDATA(7, data )
			end
		end
		-- 头像
		local _iconId = data.attackerInfo.iconId
		if cell._heroIcon then
			cell._heroIcon:removeFromParent()
			cell._heroIcon = nil
		end
	    if tonumber( data.attackerInfo.userId ) > 0 then
	    	local heroIcon = zc.createPlayerHead({iconId = _iconId, level = data.attackerInfo.level})
		    heroIcon:setPosition( 240, cellHeight/2 )
		    heroIcon:setScale( 0.85 )
		    cell._cellBg:addChild( heroIcon )
		    cell._heroIcon = heroIcon
	    else
			local heroIcon = zc.createIconByData({
		        data = {
		            mainType = zc.mainTypeSoldier,
		            type = _iconId, 
		            id = _iconId,
		            quality = 1,
	            	level = zc.getLevelTipShow()..( data.attackerInfo.level or "" ),
		        }, 
		        showLevel = true,
		        pos = cc.p( 240, cellHeight/2 ), 
		    })
		    heroIcon:setScale( 0.6 )
		    cell._cellBg:addChild( heroIcon )
		    cell._heroIcon = heroIcon
	    end
	    -- 兵器图标
	    cell._weaponIcon:setTexture( "res/Main/hero/hero_type1.png" )
	    -- 名字
		cell._name:setText( data.attackerInfo.userName )
		-- 战斗力
		cell._fightingNum:setString( data.attackerInfo.fighting )
	else
		-- 进攻
		data.attackerInfo.userId = PlayerData.info.userId
		data.attackerInfo.userName = PlayerData.info.userName
		if data.result == 1 then
			-- 玩家胜利，防守方失败
			cell._cellBg:setTexture( "res/Main/arena/record/cellBg_win.png" )
			cell._winLoseIcon:setTexture( "res/Main/arena/record/icon_win.png" )
			cell._score:setColor( display.COLOR_GREEN )
			if data.addScores then
				cell._score:setText( LANGUAGE_ARENA.score..":+"..data.addScores )
				if inArray( data.type, { 1, 2, 3 }) then
					-- 前六天
					cell._shareData = LANGUAGE_ARENA_SHAREDATA( 3, data )
				else
					-- 最后一天
					cell._shareData = LANGUAGE_ARENA_SHAREDATA( 4, data )
				end
			elseif data.num then
				local _num = tonumber(data.num) or 0
				if _num == 0 then
					cell._score:setText(zc.lang("food") .. ":" .. data.num)
				else
					cell._score:setText(zc.lang("food") .. ":+" .. data.num)
				end
				cell._shareData = LANGUAGE_ARENA_SHAREDATA(8, data )
			end
		else
			-- 玩家失败，防守方胜利
			cell._cellBg:setTexture( "res/Main/arena/record/cellBg_lose.png" )
			cell._winLoseIcon:setTexture( "res/Main/arena/record/icon_lose.png" )
			cell._score:setColor( display.COLOR_BLUE )
			if data.addScores then
				cell._score:setText( LANGUAGE_ARENA.score..":+"..data.addScores )
				cell._shareData = LANGUAGE_ARENA_SHAREDATA( 5, data )
			elseif data.num then
				local _num = tonumber(data.num) or 0
				if _num == 0 then
					cell._score:setText(zc.lang("food") .. ":" .. data.num)
				else
					cell._score:setText(zc.lang("food") .. ":+" .. data.num)
				end
				cell._shareData = LANGUAGE_ARENA_SHAREDATA(9, data )
			end
		end
		-- 头像
		local _iconId = 1
		if cell._heroIcon then
			cell._heroIcon:removeFromParent()
			cell._heroIcon = nil
		end
	    if tonumber( data.defenderInfo.userId ) > 0 then
	    	_iconId = data.defenderInfo.iconId
	    else
	    	_iconId = tonumber( data.defenderInfo.iconId ) or 101
	    	_iconId = _iconId%100
	    -- 	local _weaponId = tonumber( data.defenderInfo.weaponId ) or 1001
	    -- 	_weaponId = math.floor( _weaponId/1000 )
	    -- 	local _sex = tonumber( data.defenderInfo.iconId ) or 101
	    -- 	_sex = _sex%100
	    -- 	_iconId = _weaponId*2 + _sex - 2
	    end
    	local heroIcon = zc.createPlayerHead({iconId = _iconId, level = data.defenderInfo.level})
	    heroIcon:setPosition( 240, cellHeight/2 )
	    heroIcon:setScale( 0.85 )
	    cell._cellBg:addChild( heroIcon )
	    cell._heroIcon = heroIcon
	    -- 兵器图标
	    cell._weaponIcon:setTexture( "res/Main/hero/hero_type1.png" )
	    -- 名字
		cell._name:setText( data.defenderInfo.userName )
		-- 战斗力
		cell._fightingNum:setString( data.defenderInfo.fighting )
	end
	cell._time:setText( zc.calculateTime( data.time, 2, true ) )
end

-- 入场动画
function ArenaRecordPop:initAnimation()
	self._topShadow:setVisible( false )
	self._recordTabelview:reloadData()
    local cellHeight = 96
    local cellNum = math.ceil( self._rightSize.height/cellHeight )
    for i = 1, cellNum do
    	local cell = self._recordTabelview:cellAtIndex( i - 1 )
    	if cell then
	    	cell:setPosition( 0, self._recordTabelview:getContentSize().height - cellHeight - self._rightSize.height )
	    	cell:runAction(
	    		cc.Sequence:create(
	    			cc.DelayTime:create( i*0.15 ),--math.sqrt( ( i - 1 )*0.05 ) ),
					cc.EaseExponentialOut:create( cc.MoveTo:create( 0.8, cc.p( 0, self._recordTabelview:getContentSize().height - cellHeight*i ) ) )
				)
			)
    	end
    end
end

function ArenaRecordPop:scorllviewScriptScroll( table, cellNum )
	local cellHeight = 90
	if table:getContentOffset().y >= 0 then
    	self._topShadow:setVisible( true )
    	self._bottomShadow:setVisible( false )
    elseif table:getContentOffset().y <= self._rightSize.height - cellHeight*cellNum then
    	self._topShadow:setVisible( false )
    	self._bottomShadow:setVisible( true )
    else
    	self._topShadow:setVisible( true )
    	self._bottomShadow:setVisible( true )
    end
end

return ArenaRecordPop