--[[
-- 国家日志
-- @author lph
-- Creation  2016-4-19
]]
local CountryLogLayer = class("CountryLogLayer", function ()
    local layer = cc.Sprite:create()
    layer:setContentSize( 565, 464 )
    layer:setAnchorPoint(cc.p(0,0))
    return layer
end);

function CountryLogLayer:create(params)
	local _CountryLogLayer = CountryLogLayer.new(params)
	return _CountryLogLayer
end

function CountryLogLayer:ctor(params)
    self:initData(params)
    self:sortData()
	self:initUI()
end

function CountryLogLayer:initData(params)
	self._logData = params
	self._size = self:getContentSize()
end

function CountryLogLayer:sortData()
	local function comp(a,b)
		return tonumber(a.time) > tonumber(b.time)
	end
	table.sort(self._logData,comp)
	local _dateTimeList = {}
	local _dataTime = 0 
	if self._logData[#self._logData] and self._logData[#self._logData].time then
		local _time = zc.timeToDate(self._logData[#self._logData].time)
		_dataTime = _time.year .. _time.month .. _time.day
		_dateTimeList[#_dateTimeList] = _dataTime
	end
	
	for i=#self._logData,1,-1 do
		if i == #self._logData then
			self._logData[i].needTitle = true
		else
			self._logData[i].needTitle = false
		end
		local _time = zc.timeToDate(self._logData[i].time)
		self._logData[i].dateTime = _time.year .. _time.month .. _time.day
		if tonumber(_dateTimeList[#_dateTimeList]) ~= tonumber(self._logData[i].dateTime) then
			_dateTimeList[#_dateTimeList] = self._logData[i].dateTime
			self._logData[i].needTitle = true
		end
	end
end

function CountryLogLayer:initUI()
    --log日志显示
    self:initLogScrollView()
end

--创建scrollView
function CountryLogLayer:initLogScrollView()
    local downScrollView = zc.createScrollview({
        pos = cc.p(0,0),
        size = cc.size(565, 464),
        innerSize = cc.size(565, 464),
        dir = ccui.ScrollViewDir.vertical,
        bar = false,
        bounceEnable = true,
    })
    self:addChild(downScrollView)
    self.scrollView = downScrollView
	self._pos_y =  0
    self:addCountryLogContent()
end

function CountryLogLayer:addCountryLogContent()
	for k,v in pairs(self._logData) do
		local _time = zc.timeToDate(v.time)
		local _hour = tonumber(_time.hour) > 9 and _time.hour or "0".._time.hour
		local _min = tonumber(_time.min) > 9 and _time.min or "0".._time.min
		local _sec = tonumber(_time.sec) > 9 and _time.sec or "0".._time.sec
		--时间
		local _time_label = zc.createLabel({
            text = "[" .. _hour ..":".. _min .. ":" .. _sec .. "]",
            fontSize = 20,
            ap = cc.p(0,1),
            stroke = true,
            pos = cc.p(10, 25),
            color = display.COLOR_GRAY,
        })
		--文字描述
		local _text = self:analysisCountryLog(v)
    	local _log_label = zc.createRichLabel({
        	text = _text,
        	pos = cc.p(10, 25),
        	anchor = cc.p(0,1),
        })
	    _log_label:enableStroke(display.COLOR_BLACK, 0.2)
		_log_label:setDimensions(cc.size(444, 0))

        self._pos_y = self._pos_y + _log_label:getContentSize().height + 10
        _time_label:setPosition(10,self._pos_y)
        _log_label:setPosition(_time_label:getContentSize().width+20,self._pos_y)
        self.scrollView:addChild(_log_label)
        self.scrollView:addChild(_time_label)
        --是否需要显示标题
		if v.needTitle then
			local _title_bg_s = zc.createScale9Sprite({
		        size = cc.size(550, 30),
		        file = "res/Main/country/main/country_notice_bg_s.png",
		        pos = cc.p(0, 0),
		    })
		    self.scrollView:addChild(_title_bg_s)
		    _title_bg_s:setAnchorPoint(cc.p(0,0))
		    self._pos_y = self._pos_y + 10
		    _title_bg_s:setPosition(cc.p(0, self._pos_y))
		    self._pos_y = self._pos_y + _title_bg_s:getContentSize().height + 5
		    local _date_label = zc.createLabel({
	            text =  _time.year .. zc.lang("date_year") .._time.month .. zc.lang("date_month") .. _time.day .. zc.lang("date_day_1")  ,
	            fontSize = 20,
	            ap = cc.p(0.5,0.5),
	            stroke = true,
	            pos = cc.p(250, 15),
	            color = display.COLOR_GRAY,
	        })
		    _title_bg_s:addChild(_date_label)
		end
	end
	self.scrollView:setInnerContainerSize(cc.size(550, self._pos_y))
	-- self.scrollView:scrollToBottom(0.05, false) 
	self.scrollView:jumpToBottom()
end

--日期转换

--根据log类型解析log
function CountryLogLayer:analysisCountryLog(_logData)
	local _str = ""
	local _msg = ""
	local _type = _logData.type

	if tonumber(_type) == 1 then
		local _tech_name = ""
		local _data = gameData.getDataFromCacheWithPrimaryKey("country_tech", _logData.args.techId)
        if next(_data) ~= nil then
            _tech_name = _data.name
        end
		_str = string.format(LANGUAGE_getCountryLogByType(_type)," ",_tech_name,_logData.args.countryTechLv)
		_msg = "[size=20][color=fffcee54][u]".._logData.args.userName.."[/size][/color][/u]".."[size=20][color=ffffffff]".._str.."[/size][/color]"
	elseif tonumber(_type) == 2 then
		_str = string.format(LANGUAGE_getCountryLogByType(_type)," ") 
		_msg = "[size=20][color=fffcee54][u]".._logData.args.userName.."[/size][/color][/u]".."[size=20][color=ffffffff]".._str.."[/size][/color]"
	elseif tonumber(_type) == 3 then
		_str = string.format(LANGUAGE_getCountryLogByType(_type)," ")
		_msg = "[size=20][color=fffcee54][u]".._logData.args.userName.."[/size][/color][/u]".."[size=20][color=ffffffff]".._str.."[/size][/color]"
	elseif tonumber(_type) == 4 then --抢矿
		if _logData.args.defenderCountryName then
			local _name = self:getNameStr(_logData)
			local _countryName = _logData.args.defenderCountryName
	   		local _staticdata = gameData.getDataFromCacheWithPrimaryKey("mine", _logData.args.mid) or {}
   			local _grade = _staticdata["grade"] or 1
			local _mineName = _staticdata["name"] or ""
			local nameMsg = "[size=20][color=fffcee54][u]".._name.."[/size][/color][/u]".."[size=20][color=ffffffff]" .. zc.lang("seized") .. "【[/size][/color]"
			local countryMsg = "[size=20][color=ffa82e22]".._countryName.."[/size][/color]".."[size=20][color=ffffffff]】" .. zc.lang("defended") .. "[/size][/color]"
			local mineMsg = "[size=20][color="..zc.getColorARGBByQuality(_grade+1).."]".._mineName.."[/size][/color]".."[size=20][color=ffffffff]]![/size][/color]"
			_msg = nameMsg..countryMsg..mineMsg
		end
	elseif tonumber(_type) == 5 then --被抢矿
		if _logData.args.attackCountryName then
			local _name = self:getNameStr(_logData)
			local _countryName = _logData.args.attackCountryName
	   		local _staticdata = gameData.getDataFromCacheWithPrimaryKey("mine", _logData.args.mid) or {}
	   		local _grade = _staticdata["grade"] or 1
			local _mineName = _staticdata["name"] or ""
			local nameMsg = "[size=20][color=ffffffff]】" .. zc.lang("zi_de") .. "[/size][/color]".."[size=20][color=fffcee54][u]".._name.."[/size][/color][/u]"
			local countryMsg = "[size=20][color=ffffffff]【[/size][/color]".."[size=20][color=ffa82e22]".._countryName.."[/size][/color]"
			local mineMsg = "[size=20][color=ffffffff]]" .. zc.lang("seized_mycountry_defended") .. "[/size][/color]".."[size=20][color="..zc.getColorARGBByQuality(_grade+1).."]".._mineName.."[/size][/color]".."[size=20][color=ffffffff]]![/size][/color]"
			_msg = countryMsg..nameMsg..mineMsg
		end
	elseif tonumber(_type) == 6 then --占矿结算
		if _logData.args.mid  then
			local _name = self:getNameStr(_logData)
	   		local _staticdata = gameData.getDataFromCacheWithPrimaryKey("mine", _logData.args.mid) or {}
	   		local _grade = _staticdata["grade"] or 1
			local _mineName = _staticdata["name"] or ""
			local nameMsg = "[size=20][color=fffcee54][u]".._name.."[/size][/color][/u]".."[size=20][color=ffffffff]" .. zc.lang("in_time_success_defended") .. "[/size][/color]"
			local mineMsg = "[size=20][color="..zc.getColorARGBByQuality(_grade+1).."]".._mineName.."[/size][/color]".."[size=20][color=ffffffff]]，" .. zc.lang("recieve_huge_money") .. "！[/size][/color]"
			_msg = nameMsg..mineMsg
		end
	end

	return _msg
end
function CountryLogLayer:getNameStr(_logData)
	local _name = ""
	for i=1,3 do
		if _logData.args["userName"..i] and _logData.args["userName"..i] ~= "" then
			if _name == "" then
				_name = _logData.args["userName"..i]
			else
				_name = _name.."、".._logData.args["userName"..i]
			end
		end
	end
	return _name
end
return CountryLogLayer