--[[
    vip充值弹窗
    唐实聪
    2016.4.13
]]
local RechargePop = class("RechargePop", function()
    return zc.createNormalDialog({
        closeCallBack = function()
            LayerManager.removeLayout(true)
        end
    })
end)

function RechargePop:create( params )
    return self.new( params )
end
function RechargePop:onCleanup()
    zc.removeEventListener(CUSTOM_EVENT.EVENT_RECHARGE_SUCCESS)
end
function RechargePop:ctor( params )
    self._vip_v_file = APP_REVIEW and "res/Main/vip/vip_v_review.png" or "res/Main/vip/vip_v.png"
    self:initData( params )
    self:initUI()
    self:buildVipData()
    self:refreshUI()
    self:refreshInfo()
    
    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_RECHARGE_SUCCESS,
        callback = function(_data)
            self:rechargeSuccess(_data)
            self:refreshInfo()
            self:refreshUI()
        end
    })
end

function RechargePop:initData( params )
    -- 是否显示V0，防止策划改
    self._hideVip0 = true
    -- 特权界面1，充值界面2
    self._pageIndex = params.index or 1
    self._rechargeStatusData = params.rechargeStatusData or {}

    -- vip充值数据，从这张表中取得vip最高等级
    do
        local _vipLevelList = gameData.getDataFromCache( "vip_level" )
        _vipLevelList["0"] = _vipLevelList["100"]
        _vipLevelList["100"] = nil
        -- dump( _vipLevelList, "_vipLevelList" )
        self._vipLevelList = _vipLevelList

        -- vip最高等级
        local _vipMax = 0
        while _vipLevelList[tostring( _vipMax )] do
            _vipMax = _vipMax + 1
        end
        self._vipMax = _vipMax - 1
    end


    -- vip特权数据
    local _vipList = {}
    local _datas = gameData.getAllDataWithNoClone( "vip" )
    for k, v in pairs( _datas ) do
        if v.id ~= 17 then
            -- 是否只显示一次
            local _showOnce = false
            -- 是否已经显示过，showOnce为true的时候有用
            local _showFlag = {}
            if tonumber( v.showOnce ) == 1 then
                _showOnce = true
            end
            for _index = 0, self._vipMax do
                local _value = tonumber( v["vip".._index] )
                if _value > 0 then
                    -- 开通特权
                    if not _showOnce then
                        -- 一直显示
                        _vipList[_index] = _vipList[_index] or {}
                        local __index = #_vipList[_index] + 1
                        _vipList[_index][__index] = {
                            id = v.id,
                            desc = v.desc,
                            num = ( tonumber( v.showNum ) == 1 ) and _value or "",
                        }
                    elseif not _showFlag[_index]  then
                        -- 只显示一次但是还没有显示过
                        _vipList[_index] = _vipList[_index] or {}
                        local __index = #_vipList[_index] + 1
                        _vipList[_index][__index] = {
                            id = v.id,
                            desc = v.desc,
                            num = ( tonumber( v.showNum ) == 1 ) and _value or "",
                        }
                        _showFlag[_index] = true
                    end
                end
            end
        end
    end
    if self._hideVip0 then
        _vipList[0] = nil
    end
    self._vipList = _vipList
    -- 添加所有特权文字
    local _skip = 0
    if self._hideVip0 then
        _skip = 1
    end
    for k, v in pairs( self._vipList ) do
        if k ~= _skip then
            v[#v + 1] = {
                id = 0,
                desc = LANGUAGE_RECHARGE_OWNRIGHT( k - 1 ),
                num = "",
            }
        end
    end
    -- 排序
    for k, v in pairs( self._vipList ) do
        table.sort(v, function( a, b )
            if not a or not b then
                return false
            end
            if tonumber(a.id) == 0 then
                return true
            end
            if tonumber(b.id) == 0 then
                return false
            end
            if tonumber(a.id) == 19 then
                return true
            end
            if tonumber(b.id) == 19 then
                return false
            end
            return tonumber( a.id ) < tonumber( b.id )
        end)
    end

    --vip5加个特例显示
    -- if _vipList[5] then
    --     local vip5Data = {
    --         ["desc"] = LANGUAGE_RECHARGE.tip_5,
    --         ["id"]   = 19,
    --         ["num"]  = "",
    --         ["vip5"] = true,
    --     }
    --     table.insert(_vipList[5], 2, vip5Data)
    -- end
    if _vipList[6] then
        local vip5Data = {
            ["desc"] = LANGUAGE_RECHARGE.tip_6,
            ["id"]   = 19,
            ["num"]  = "",
            ["vip6"] = true,
        }
        table.insert(_vipList[6], 2, vip5Data)
    end
    -- 充值数据
    self._rechargeList = gameData.getDataFromCache( "pay" )
    table.sort(self._rechargeList, function( a, b )
        return tonumber( a.id ) < tonumber( b.id )
    end)
    if not APPSTORE_REVIEW then
        local _yueData = gameData.getDataFromCache( "card" )
        _yueData["7"].type = 2
        table.insert(self._rechargeList, 1, _yueData["7"])
        _yueData["8"].type = 2
        table.insert(self._rechargeList, 2, _yueData["8"])
    end

    self._vipStatus = {}
    self._size = self:getContentSize()
    self._leftSize = cc.size( 216, 453 )
    self._rightSize = cc.size( 634, 453 )
    self._vipFlag = false
    self._rechargeFlag = false
end

function RechargePop:initUI()
    -- 通用背景
    local _commonBg = cc.Sprite:create( "res/Main/common/common_bg.jpg" )
    _commonBg:setPosition( self._size.width/2, self._size.height/2 )
    self:addChild( _commonBg )
    zc.setBgSize( _commonBg )

    -- 背景
    local bg = cc.Sprite:create()
    bg:setContentSize( 885, 527 )
    bg:setPosition( self._size.width/2, self._size.height/2 )
    self:addChild( bg )
    self._bg = bg
    self._bgSize = bg:getContentSize()
    local bgSp = cc.Sprite:create( "res/Main/vip/bg.png" )
    bgSp:setAnchorPoint( 0.5, 0 )
    bgSp:setPosition( self._bgSize.width/2, 5 )
    bg:addChild( bgSp )

    -- 阴影
    local topShadow = ccui.Scale9Sprite:create( cc.rect( 4, 4, 61, 4 ), "res/Main/common/popBg/shadow_white.png" )
    topShadow:setContentSize( self._bgSize.width - 6, 12 )
    topShadow:setAnchorPoint( 0.5, 1 )
    topShadow:setPosition( self._bgSize.width/2, self._bgSize.height - 56 )
    bg:addChild( topShadow )
    -- 框
    local frame_1 = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
    frame_1:setContentSize( self._leftSize.width + 18, self._leftSize.height + 30 )
    frame_1:setPosition( self._leftSize.width/2 + 13, self._leftSize.height/2 + 17 )
    bg:addChild( frame_1 , 1)
    -- top
    local top = cc.Sprite:create( "res/Main/common/popBg/titleBg2.jpg" )
    top:setAnchorPoint( 0.5, 1 )
    top:setPosition( self._bgSize.width/2, self._bgSize.height - 7 )
    bg:addChild( top , 1)
    -- 框
    local frame_2 = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
    frame_2:setContentSize( self._bgSize.width - 10, self._bgSize.height - 12 )
    frame_2:setPosition( self._bgSize.width/2, self._bgSize.height/2 )
    bg:addChild( frame_2 , 1)

    -- side
    local side_b = zc.getScaleNode( "res/Main/common/popBg/shadow_b.png", cc.size( self._bgSize.width + 6, 31 ) )
    side_b:setAnchorPoint( 0, 1 )
    side_b:setPosition( -6, 10 )
    bg:addChild( side_b )
    local side_r = zc.getScaleNode( "res/Main/common/popBg/shadow_r.png", cc.size( 32, self._bgSize.height + 21 ) )
    side_r:setAnchorPoint( 0, 1 )
    side_r:setPosition( self._bgSize.width - 10, self._bgSize.height )
    bg:addChild( side_r )

    -- 标题
    local title = cc.Sprite:create()
    title:setPosition( 120, self._bgSize.height )
    bg:addChild( title, 1 )
    self._title = title

    -- 左边
    self:initLeft()
end
-- 左边
function RechargePop:initLeft()
    local leftCtn = cc.Sprite:create()
    leftCtn:setContentSize( self._leftSize )
    leftCtn:setAnchorPoint( 0, 0 )
    leftCtn:setPosition( 12, 17 )
    self._bg:addChild( leftCtn )
    self._leftCtn = leftCtn
    -- 当前等级
    -- 文字
    local curVipY = 415
    local curVipText = zc.createLabel({
        text = LANGUAGE_RECHARGE.current_level.."：",
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 13, curVipY ),
        color = cc.c3b( 85, 59, 26 ),
    })
    leftCtn:addChild( curVipText )
    -- v
    local curVipIcon = zc.createSprite(self._vip_v_file)
    curVipIcon:setPosition( 133, curVipY )
    curVipIcon:setScale( 0.7 )
    leftCtn:addChild( curVipIcon )
    -- 数字
    local curVipNum = zc.createFntLabel({
        fnt = "res/Main/vip/fnt/vip_num.fnt",
        pos = cc.p( curVipIcon:getPositionX() + curVipIcon:getContentSize().width*curVipIcon:getScale()*0.5, curVipY ),
        addwidth = -8,
    })
    curVipNum:setAnchorPoint( 0, 0.5 )
    curVipNum:setScale( 0.7 )
    leftCtn:addChild( curVipNum )
    self._curVipNum = curVipNum

    -- 经验
    local expBg = cc.Sprite:create( "res/Main/vip/vip_exp_bg.png" )
    expBg:setPosition( 103, 390 )
    leftCtn:addChild( expBg )
    local expBar = cc.ProgressTimer:create( cc.Sprite:create( "res/Main/vip/vip_exp.png" ) )
    expBar:setType( cc.PROGRESS_TIMER_TYPE_BAR )
    expBar:setMidpoint( cc.p( 0, 0.5 ) )
    expBar:setBarChangeRate( cc.p( 1, 0 ) )
    expBar:setPosition( expBg:getContentSize().width/2, expBg:getContentSize().height/2 )
    expBg:addChild( expBar )
    self._expBar = expBar
    local expNum = zc.createLabel({
        fontSize = 20,
        pos = cc.p( expBg:getContentSize().width/2, expBg:getContentSize().height/2 ),
        color = cc.c3b( 255, 204, 1 ),
        stroke = false,
        pixel = 2,
    })
    expBg:addChild( expNum )
    self._expNum = expNum

    -- 已达到最高等级
    local topVip = zc.createLabel({
        text = LANGUAGE_RECHARGE.vip_level_max,
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 13, 365 ),
        color = cc.c3b( 255, 204, 1 ),
        outLine = true,
        pixel = 1.5,
    })
    leftCtn:addChild( topVip )
    self._topVip = topVip
    -- 再充值
    local nextVipY = 365
    local nextVipText = zc.createLabel({
        text = LANGUAGE_RECHARGE.recharge_more.."：",
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 13, nextVipY ),
        color = cc.c3b( 85, 59, 26 ),
    })
    leftCtn:addChild( nextVipText )
    self._nextVipText = nextVipText
    local nextVipIcon = cc.Sprite:create( "res/Main/common/common_icon_gold.png" )
    nextVipIcon:setPosition( 113, nextVipY - 3 )
    nextVipIcon:setScale( 0.7 )
    leftCtn:addChild( nextVipIcon )
    self._nextVipIcon = nextVipIcon
    local nextVipNum = zc.createLabel({
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 133, nextVipY ),
        outLine = true,
    })
    leftCtn:addChild( nextVipNum )
    self._nextVipNum = nextVipNum
    -- 可升级至
    local upToY = 335
    local upToText = zc.createLabel({
        text = LANGUAGE_RECHARGE.can_up_to.."：",
        fontSize = 20,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 13, upToY ),
        color = cc.c3b( 85, 59, 26 ),
    })
    leftCtn:addChild( upToText )
    self._upToText = upToText

    local upToNum = zc.createLabel({
        -- text = ,
        fontSize = 20,
        pos = cc.p( 133, upToY ),
        color = cc.c3b( 255, 204, 1 ),
        outLine = true,
        pixel = 2,
    })
    leftCtn:addChild( upToNum )
    self._upToNum = upToNum

    local rechargeBtnBg = ccui.Scale9Sprite:create( cc.rect( 35, 7, 363, 89 ), "res/Main/role/trinket/attrBg.png" )
    rechargeBtnBg:setContentSize( self._leftSize.width, 115 )
    rechargeBtnBg:setAnchorPoint( 0, 0 )
    rechargeBtnBg:setPosition( 0, 0 )
    leftCtn:addChild( rechargeBtnBg )
    -- 充值
    local rechargeBtn = zc.createCommomBtn({
        tag = 1,
        endCallback = function()
            if self._pageIndex == 1 then
                if APP_REVIEW then
                    zc.tipInfo(zc.lang("tips_recharge_unopen"))
                    return
                end
                zc.sendHttp({
                    apiName = "EveryDayCard_main",
                    successCallback = function(backData)
                        self._rechargeStatusData = backData or {}
                        self._pageIndex = 3 - self._pageIndex
                        self:refreshUI()
                    end
                })
            else
                self._pageIndex = 3 - self._pageIndex
                self:refreshUI()
            end
        end,
        pos = cc.p( self._leftSize.width/2, 55 ),
        text = LANGUAGE_RECHARGE.recharge_space,
    })
    leftCtn:addChild( rechargeBtn )
    self._rechargeBtn = rechargeBtn
end
-- 特权
function RechargePop:initVip()
    local vipCtn = cc.Sprite:create()
    vipCtn:setContentSize( self._rightSize )
    vipCtn:setAnchorPoint( 0, 0 )
    vipCtn:setPosition( 237, 17 )
    self._bg:addChild( vipCtn )
    self._vipCtn = vipCtn
    local _di = zc.getSprite({
        src = "res/Main/vip/bgHead.png",
        ap = cc.p(0, 1),
        pos = cc.p(0, self._rightSize.height),
    })
    vipCtn:addChild(_di, -1)

    -- title
    local vipTitleY = self._rightSize.height - 26
    local vipTitleIcon = zc.createSprite(self._vip_v_file)
    vipTitleIcon:setAnchorPoint(1, 0.5)
    vipTitleIcon:setPosition( self._rightSize.width/2 - 30, vipTitleY )
    vipCtn:addChild( vipTitleIcon )
    local vipTitleNum = zc.createFntLabel({
        fnt = "res/Main/vip/fnt/vip_num.fnt",
        pos = cc.p( self._rightSize.width/2 - 10, vipTitleY ),
        addwidth = -8,
    })
    vipCtn:addChild( vipTitleNum )
    self._vipTitleNum = vipTitleNum
    local vipTitleSp = cc.Sprite:create( "res/Main/vip/vip_tq.png" )
    vipTitleSp:setPosition( self._rightSize.width/2 + 60, vipTitleY )
    vipCtn:addChild( vipTitleSp )
    -- vipTableview
    local vipTableview = zc.ZCTableView:create( cc.size( self._rightSize.width, 260 ) )
    vipTableview:setAutoAlign( true )
    vipTableview:setBounceable( true )
    vipTableview:setInertia( true )
    vipTableview:setDirection( cc.SCROLLVIEW_DIRECTION_HORIZONTAL )
    vipTableview:setPosition( 0, 140 )
    vipTableview:setDelegate()
    vipTableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    -- 配置
    local cellWidth = self._rightSize.width
    local cellHeight = 260

    local function cellSizeForTable( table, index )
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
        end
        cell:removeAllChildren()

        if self._hideVip0 then
            index = index + 1
        end
        local data = self._vipList[index]
        if data then
            -- dump( data )
            -- 特权
            local innerHeight = #data*30
            local outerHeight = innerHeight < 260 and innerHeight or 260
            local scrollview = zc.createScrollview({
                pos = cc.p( 0, cellHeight - outerHeight ),
                size = cc.size( cellWidth, outerHeight ),
                innerSize = cc.size( cellWidth, innerHeight ),
                touchEnable = true,
                bounceEnable = innerHeight > outerHeight,
                dir = ccui.ScrollViewDir.vertical,
            })
            cell:addChild( scrollview )
            scrollview:setSwallowTouches( false )
            for i, v in ipairs( data ) do
                local rightY = innerHeight - 30*( i - 0.5 )
                local rightIcon = cc.Sprite:create( "res/Main/vip/vip_dot.png" )
                rightIcon:setPosition( 40, rightY )
                scrollview:addChild( rightIcon )
                local rightText = zc.createLabel({
                    text = v.desc,
                    fontSize = 20,
                    ap = cc.p( 0, 0.5 ),
                    pos = cc.p( 60, rightY ),
                    color = tonumber(v.id) == 19 and display.COLOR_ORANGE or cc.c3b( 85, 59, 26 ),
                    outLine = tonumber(v.id) == 19,
                })
                scrollview:addChild( rightText )

                local rightNum = zc.createLabel({
                    text = v.num,
                    fontSize = 20,
                    ap = cc.p( 0, 0.5 ),
                    pos = cc.p( rightText:getPositionX() + rightText:getContentSize().width + 10, rightY ),
                    color = display.COLOR_ORANGE,
                    outLine = true,
                })
                scrollview:addChild( rightNum )
            end
        end

        return cell
    end
    local function numberOfCellsInTableView()
        return table.nums( self._vipList )
    end
    local function tablePageAfterSliding( table, cell )
        local index = table:getCurrentPage()
        if self._hideVip0 then
            self._vipIndex = index + 1
        else
            self._vipIndex = index
        end
        self._vipTitleNum:setString( self._vipIndex )
        if index == 0 then
            self._leftArrow:setVisible( false )
            self._rightArrow:setVisible( true )
        elseif index == self._vipMax then
            self._leftArrow:setVisible( true )
            self._rightArrow:setVisible( false )
        else
            self._leftArrow:setVisible( true )
            self._rightArrow:setVisible( true )
        end
        self:refreshGift()
    end
    vipTableview:registerScriptHandler( cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    vipTableview:registerScriptHandler( tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    vipTableview:registerScriptHandler( numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    vipTableview:registerScriptHandler( tablePageAfterSliding, zctech.TABLECELL_AFTER_SLIDING )
    vipCtn:addChild( vipTableview )
    self._vipTableview = vipTableview

    -- 特权礼包背景
    local giftBg = ccui.Scale9Sprite:create( cc.rect( 20, 10, 549, 71 ), "res/Main/role/trinket/sellDi.png" )
    giftBg:setContentSize( self._rightSize.width + 2, 140 )
    giftBg:setAnchorPoint( 0, 0 )
    giftBg:setPosition( -2, 0 )
    vipCtn:addChild( giftBg )
    -- giftBg:setVisible( false )
    self._giftBg = giftBg
    -- 礼包
    local giftIcon = cc.Sprite:create( "res/Main/vip/vip_tqwz.png" )
    giftIcon:setPosition( 40, 65 )
    giftBg:addChild( giftIcon )
    local giftScrollview = ccui.ScrollView:create()
    giftScrollview:setDirection( cc.SCROLLVIEW_DIRECTION_BOTH )
    giftScrollview:setTouchEnabled( true )
    giftScrollview:setBounceEnabled( true )
    giftScrollview:setContentSize( cc.size( 400, 140 ) )
    giftScrollview:setInnerContainerSize( cc.size( 400, 140 ) )
    giftScrollview:setPosition( 70, 0 )
    giftScrollview:setScrollBarEnabled( false )
    giftBg:addChild( giftScrollview )
    self._giftScrollview = giftScrollview
    self._gift = {}
    -- 购买
    local buyX = self._rightSize.width - 80
    local consumeIcon = cc.Sprite:create( zc.getImgByType( 1 ) )
    consumeIcon:setPosition( buyX - 20, 90 )
    giftBg:addChild( consumeIcon )
    local consumeNum = zc.createLabel({
        fontSize = 25,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( buyX, 90 ),
        outLine = true,
        pixel = 2,
        color = display.COLOR_WHITE,
    })
    giftBg:addChild( consumeNum )
    self._consumeNum = consumeNum
    local buyBtn = zc.createCommomBtn({
        tag = 1,
        btnText = "",
        endCallback = function () 
            zc.sendHttp({
                apiName = "User_buyVipItem",
                params = {id = self._vipLevelList[tostring( self._vipIndex )].id},
                successCallback = function(data)
                    self._buyBtn:setEnable( false )
                    self._buyBtn:setText( LANGUAGE_SHOP.bought )
                    data.noAnimation = true
                    -- 道具
                    zc.createShowReward( data )
                    PlayerData:updataData(data)
                    PlayerData.info.vipItems = data.vipItems
                    -- 获得兵器武将
                    local _weaponInfo = nil
                    local _heroId = nil
                    for i, v in ipairs( data.clientItems ) do
                        local _mainType = tonumber( v.type ) or 0
                        if _mainType == 3 then
                            _weaponInfo = PlayerData:getWeaponInfoInfoById( v.model.id )
                            break
                        elseif _mainType == zc.mainTypeSoldier then
                            _heroId = v.model.heroId
                        end
                    end
                    if _weaponInfo then
                        zc.createPop("makeGodWeapon", {info = _weaponInfo, onlyShow = true})
                    elseif _heroId then
                        zc.createPubShowGetHero({id=_heroId})
                    end
                    self:buildVipData()
                    self._vipTableview:updateCellAtIndex( self._vipIndex )
                end,
            })
        end,
        pos = cc.p( buyX, 45 ),
        text = LANGUAGE_SHOP.buy_space,
    })
    giftBg:addChild( buyBtn )
    self._buyBtn = buyBtn

    -- 左右箭头
    local normalNode = cc.Sprite:create( "res/Main/vip/vip_arrow.png" )
    normalNode:setFlippedX( true )
    local leftArrow = zc.createPushButton({
        normalNode = normalNode,
        pos = cc.p( 23, vipTitleY ),
        touchScale = 0.9,
        touchSize = cc.size( 50, 50 ),
        endCallback = function()
            self._vipTableview:scrollToCell( self._vipTableview:getCurrentPage() - 1, true )
        end
    })
    vipCtn:addChild( leftArrow )
    self._leftArrow = leftArrow
    local rightArrow = zc.createPushButton({
        normalFile = "res/Main/vip/vip_arrow.png",
        pos = cc.p( self._rightSize.width - 23, vipTitleY ),
        touchScale = 0.9,
        touchSize = cc.size( 50, 50 ),
        endCallback = function()
            self._vipTableview:scrollToCell( self._vipTableview:getCurrentPage() + 1, true )
        end
    })
    vipCtn:addChild( rightArrow )
    self._rightArrow = rightArrow

    self._vipFlag = true
end
function RechargePop:refreshGift()
    local index = self._vipIndex
    for i, v in ipairs( self._gift ) do
        v:removeFromParent()
    end
    self._gift = {}
    local _height = self._giftScrollview:getContentSize().height
    local giftTable = string.split( self._vipLevelList[tostring( index )].items, "," )
    for i, v in ipairs( giftTable ) do
        local giftData = string.split( v, "|" )
        local _showItem = true
        local _showHero = nil
        if tonumber(giftData[1]) == zc.mainTypeSoldier then
            _showItem = false
            _showHero = function() zc.createHeroInfoPop({heroId = giftData[2], showHero = true}) end
        end
        local gift = zc.createIconByData({
            data = {
                mainType = tonumber( giftData[1] ),
                type = tonumber( giftData[2] ), 
                id = tonumber( giftData[2] ),
                num = tonumber( giftData[3] ),
                quality = 1,
            },
            listener = _showHero,
            pos = cc.p( ( i - 0.5 )*90, _height/2 ),
        })
        if _showHero == nil then
            gift:setTouchEndedShowTip()
        end
        gift:setScale( 0.7 )
        self._giftScrollview:addChild( gift )
        self._gift[i] = gift
    end
    self._giftScrollview:setInnerContainerSize( cc.size( 90*#giftTable, _height ) )
    self._consumeNum:setText( self._vipLevelList[tostring( index )].needGold )
    if self._vipStatus[tostring( index )] then
        self._buyBtn:setEnable( false )
        self._buyBtn:setText( LANGUAGE_SHOP.bought )
    else
        self._buyBtn:setEnable( true )
        self._buyBtn:setText( LANGUAGE_SHOP.buy_space )
    end
end
-- 充值
function RechargePop:initRecharge()
    local rechargeCtn = cc.Sprite:create()
    rechargeCtn:setContentSize( self._rightSize )
    rechargeCtn:setAnchorPoint( 0, 0 )
    rechargeCtn:setPosition( 237, 17 )
    self._bg:addChild( rechargeCtn )
    self._rechargeCtn = rechargeCtn
    -- rechargeTableview
    local rechargeTableview = zc.ZCTableView:create( self._rightSize )
    rechargeTableview:setBounceable( true )
    rechargeTableview:setInertia( true )
    rechargeTableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    rechargeTableview:setPosition( 0, 0 )
    rechargeTableview:setDelegate()
    rechargeTableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    -- 配置
    local cellWidth = self._rightSize.width
    local cellHeight = 130

    local function cellSizeForTable( table, index )
        if index == 0 and not APPSTORE_REVIEW then
            return cellHeight + 30, cellWidth
        end
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildRechargeCell( cell, index, cellWidth, cellHeight )
        end
        self:updateRechargeCell( cell, index )

        return cell
    end
    local function numberOfCellsInTableView()
        return math.ceil( #self._rechargeList/2 )
    end
    rechargeTableview:registerScriptHandler( cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    rechargeTableview:registerScriptHandler( tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    rechargeTableview:registerScriptHandler( numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    rechargeCtn:addChild( rechargeTableview )
    self._rechargeTableview = rechargeTableview

    self._rechargeFlag = true
end

function RechargePop:buildRechargeCell( cell, index, cellWidth, cellHeight )
    cell._item = {}
    for i = 1, 2 do
        cell._item[i] = {}
        -- cellBg
        local _node = cc.Node:create()
        _node:setPosition(cellWidth/4*( 2*i - 1 ), cellHeight/2)
        cell:addChild( _node )

        local cellBg = cc.Sprite:create( "res/Main/vip/cell_bg.png" )
        _node:addChild( cellBg )
        cell._item[i]._cellBg = cellBg
        -- icon
        local icon = cc.Sprite:create()
        icon:setPosition( 80, 66 )
        cellBg:addChild( icon )
        cell._item[i]._icon = icon
        -- gold
        local goldIcon = cc.Sprite:create( zc.getImgByType( 1 ) )
        goldIcon:setPosition( 170, 80 )
        cellBg:addChild( goldIcon )
        cell._item[i]._goldIcon = goldIcon
        -- goldNum
        local goldNum = zc.createLabel({
            fontSize = 20,
            ap = cc.p( 1, 0.5 ),
            outLine = true,
            pixel = 1,
            pos = cc.p( 265, goldIcon:getPositionY() ),
            color = display.COLOR_YELLOW,
        })
        cellBg:addChild( goldNum )
        cell._item[i]._goldNum = goldNum

        local nowGetLab = zc.createRichLabel({
            fontSize = 20,
            anchor = cc.p( 0, 0.5 ),
            pos = cc.p( 150, 80),
            color = cc.c3b(74, 50, 0),
        })
        cellBg:addChild( nowGetLab )
        cell._item[i]._nowGetLab = nowGetLab
        local everyDayGet = zc.createRichLabel({
            fontSize = 20,
            anchor = cc.p( 0, 0.5 ),
            pos = cc.p( 150, 52 ),
            color = cc.c3b(74, 50, 0),
        })
        cellBg:addChild( everyDayGet )
        cell._item[i]._everyDayGet = everyDayGet
        -- money
        local money = zc.createLabel({
            fontSize = 24,
            pos = cc.p( cellBg:getContentSize().width/2, 22),
            outLine = true,
            pixel = 1,
        })
        cellBg:addChild( money )
        cell._item[i]._money = money
        -- noteBg
        local noteBg = zc.getSprite({
            src = "res/Main/activity/sevenDay/limit_bg.png",
            ap = cc.p(0, 1),
            pos = cc.p(-5, cellBg:getContentSize().height + 5),
            scale = 0.75,
        })
        noteBg:setAnchorPoint( 0, 1 )
        cellBg:addChild( noteBg )
        cell._item[i]._noteBg = noteBg
        -- note
        local note = zc.createLabel({
            fontSize = 30,
            outLine = true,
            pixel = 1,
            color = cc.c3b(255, 255, 167),
            pos = cc.p( noteBg:getContentSize().width/2 - 12, noteBg:getContentSize().height/2 + 12),
        })
        note:setRotation( -45 )
        noteBg:addChild( note )
        cell._item[i]._note = note
        -- btn
        local btn = zc.createPushButton{
            touchSize = cellBg:getContentSize(),
            pos = cc.p( cellBg:getContentSize().width/2, cellBg:getContentSize().height/2 ),
            needEnableWhenOut = true,
            needEnableWhenMoving = true,
            needSwallow = false,
            endCallback = function() end,
        }
        cellBg:addChild( btn )
        cell._item[i]._btn = btn
    end
end

function RechargePop:updateRechargeCell( cell, index )
    cell._index = index
    for i = 1, 2 do
        local data = self._rechargeList[2*index + i]
        if data then
            cell._item[i]._noteBg:setVisible( false )
            local _status = 0
            local _payNum = tonumber(self._payInfo[tostring(data.id)]) or 0
            if index == 0 and not APPSTORE_REVIEW then
                cell._item[i]._icon:setVisible(false)
                cell._item[i]._cellBg:setTexture("res/Main/vip/cell_sp" .. i .. ".png")
                cell._item[i]._cellBg:setPosition(-5, 10)
                cell._item[i]._goldIcon:setVisible(false)
                cell._item[i]._goldNum:setVisible(false)
                cell._item[i]._nowGetLab:setVisible(true)
                cell._item[i]._everyDayGet:setVisible(true)
                local _addGold = tonumber( data.addGold ) or 0
                cell._item[i]._nowGetLab:setString(zc.lang("to_get_right_now") .. "[color=ffffff00]" .. _addGold .. "[/color]" .. zc.lang("gold"))
                local _everyDayGold = string.split(data.reward, "|")
                _everyDayGold = tonumber(_everyDayGold[3]) or 0
                cell._item[i]._everyDayGet:setString(zc.lang("to_get_every_day") .. "[color=ffffff00]" .. _everyDayGold .. "[/color]" .. zc.lang("gold"))
                _status = self._rechargeStatusData.status or {}
                _status = tonumber(_status[tostring(i)]) or 0
            else
                cell._item[i]._nowGetLab:setVisible(false)
                cell._item[i]._everyDayGet:setVisible(false)
                cell._item[i]._goldIcon:setVisible(true)
                cell._item[i]._goldNum:setVisible(true)
                cell._item[i]._cellBg:setPosition(0, 0)
                cell._item[i]._cellBg:setTexture("res/Main/vip/cell_bg.png")
                cell._item[i]._icon:setVisible(true)
                cell._item[i]._icon:setTexture( "res/Main/vip/icon/"..data.icon..".png" )
        
                local _giveGold = tonumber( data.giveGold ) or 0
                local _addGolde = tonumber( data.addGold ) or 0
                cell._item[i]._goldNum:setText( _addGolde )
                if _payNum == 0 and _giveGold > 0 then
                    cell._item[i]._noteBg:setVisible( true )
                    cell._item[i]._note:setString(zc.lang("presented") .. _giveGold)
                end
            end
            cell._item[i]._money:setPositionX(cell._item[i]._cellBg:getContentSize().width*0.5)
            local price = zc.getGtMoneyFlag().. zc.changeGtMoney(data.price)
            if _status == 0 then
                cell._item[i]._money:setText( price )
            else
                cell._item[i]._money:setText(LANGUAGE_SHOP.bought)
            end
            cell._item[i]._btn:setTouchEndedCall(function()
                local _tips = zc.lang("is_or_not_buy") .. zc.getGtMoneyFlag() .. zc.changeGtMoney(data.price) .. " " .. zc.lang("buy") .. tostring(data.desc)
                local _pGive = tonumber(data.giveGold) or 0
                if _payNum > 0 then
                    _pGive = 0
                end
                if _pGive > 0 then
                    _tips = _tips .. "(" .. zc.lang("presented") .. _pGive .. zc.lang("gold") .. ")"
                end

                if _status ~= 0 then
                    local _pop = ZCConfirmDialog:createWithParams({
                        title = zc.lang("prompt"),
                        msg = zc.lang("right_now_have_buy") .. "“" .. zc.changeGtMoney(data.desc) .. "”，" .. zc.lang("is_or_not_to_get") .. "？",
                        showDi = true,
                        isHide = false,
                        rightCallback = function()
                            LayerManager.removeLayout(true)
                            zc.createActivityPop({idx = 10})
                        end
                    })
                    self:addChild( _pop, 10)
                else
                    zc.createBuyPop({
                        tip = _tips,
                        isRecharge = true,
                        special = {
                            {
                                begin = 5,
                                length = #price - 2,
                                color = display.COLOR_YELLOW,
                            }
                        },
                        callback = function( isAliPay, isWeixin )
                            data.isAliPay = isAliPay
                            data.isWeixin = isWeixin

                            --充值类型：1普通、2月卡、3热卖礼包
                            local _type = data["type"] or 1
                            local params = {
                                data = data,
                                goodsType = _type,
                            }
                            zc.recharge(params)

                        end
                    })
                end
            end)
        else
            cell._item[i]._cellBg:setVisible( false )
        end
    end
end

-- 构造vip界面需要的数据
function RechargePop:buildVipData()
    self._vipStatus = {}
    local statusStr = tostring( PlayerData.info.vipItems )
    for i = 1, #statusStr do
        local status = string.sub( statusStr, i, i )
        self._vipStatus[tostring( #statusStr - i )] = tonumber( status ) == 1
    end
end
-- 根据index刷新界面
function RechargePop:refreshUI()
    if self._pageIndex == 1 then
        -- 特权
        self._title:setTexture( "res/Main/vip/vip_title.png" )
        self._rechargeBtn:setText( LANGUAGE_RECHARGE.recharge_space )


        if not self._vipFlag then
            -- 特权
            self:initVip()
        end

        self._vipCtn:setVisible( true )
        self._vipTableview:reloadData()
        local curVipLevel = tonumber( PlayerData.info.vip or 0 ) or 0
        self._vipTableview:scrollToCell( curVipLevel )

        if self._rechargeFlag then
            self._rechargeCtn:setVisible( false )
        end
    elseif self._pageIndex == 2 then
        if APP_REVIEW or APP_SERVER == 2 then
            zc.tipInfo(zc.lang("tips_recharge_unopen"))
            return
        end
        -- 充值
        self._title:setTexture( "res/Main/vip/recharge_title.png" )
        self._rechargeBtn:setText( LANGUAGE_RECHARGE.right_space )

        if self._vipFlag then
            self._vipCtn:setVisible( false )
        end
        self._payInfo = PlayerData:getBaseInfoByTag("firstPayGold") or {}
        if type(self._payInfo) ~= "table" then
            self._payInfo = {}
        end
        if not self._rechargeFlag then
            -- 充值
            self:initRecharge()
        end
        self._rechargeCtn:setVisible( true )
        self._rechargeTableview:reloadData()
    end
end
-- 刷新玩家vip信息
function RechargePop:refreshInfo()
    local curVipLevel = tonumber( PlayerData.info.vip or 0 ) or 0
    if curVipLevel < self._vipMax then
        -- 没到最高级
        -- 当前等级
        self._curVipNum:setString( curVipLevel )
        -- 经验
        local rechargedNum = tonumber( PlayerData.resourcesInfo.rechargeGold or 0 ) or 0
        local rechargingNum = tonumber( self._vipLevelList[tostring( curVipLevel + 1 )].gold or 0 ) or 0
        self._expBar:runAction(
            cc.ProgressTo:create( 0.2, rechargingNum == 0 and 100 or rechargedNum/rechargingNum*100 )
        )
        self._expNum:setText( rechargedNum.."/"..rechargingNum )
        -- 已达到最高等级
        self._topVip:setVisible( false )
        -- 再充值
        self._nextVipText:setVisible( true )
        self._nextVipIcon:setVisible( true )
        self._nextVipNum:setVisible( true )
        self._nextVipNum:setText( rechargingNum - rechargedNum )
        -- 可升级至
        self._upToText:setVisible( true )
        -- self._upToIcon:setVisible( true )
        self._upToNum:setVisible( true )
        local _str = APP_REVIEW and zc.lang("vip") or "V"
        self._upToNum:setText( _str .. ( curVipLevel + 1 ) )
    else
        -- vip最高级
        -- 当前等级
        self._curVipNum:setString( self._vipMax )
        -- 经验
        local rechargedNum = tonumber( PlayerData.resourcesInfo.rechargeGold or 0 ) or 0
        local rechargingNum = tonumber( self._vipLevelList[tostring( self._vipMax )].gold or 0 ) or 0
        self._expBar:runAction(
            cc.ProgressTo:create( 0.2, rechargingNum == 0 and 100 or rechargedNum/rechargingNum*100 )
        )
        self._expNum:setText( rechargedNum.."/"..rechargingNum )
        -- 已达到最高等级
        self._topVip:setVisible( true )
        -- 再充值
        self._nextVipText:setVisible( false )
        self._nextVipIcon:setVisible( false )
        self._nextVipNum:setVisible( false )
        -- 可升级至
        self._upToText:setVisible( false )
        -- self._upToIcon:setVisible( false )
        self._upToNum:setVisible( false )
    end
end
--充值成功，socket回调
function RechargePop:rechargeSuccess(_data)
    local _data = _data or {}
    if zc.getPop("Buy") then
        LayerManager.removeLayout(true)
    end
    zc.tipInfo(zc.lang("tips_recharge_success"))
    local _successData = _data.data --如果是充值月卡、终身卡刷新界面，其它不用
    if _successData then
        local _id = tonumber(_successData.itemId) or 0
        if _id == 7 or _id == 8 then
            local _stateId = _id == 7 and "1" or "2"
            self._rechargeStatusData["status"][_stateId] = 1
            self._rechargeTableview:reloadData()
        end
    end
end
return RechargePop