--[[
    武将属性界面
    唐实聪
    2016.4.20
    2016.8.18重做
]]
local RoleAttributeLayer = class("RoleAttributeLayer", function()
    local layer = cc.Sprite:create()
    layer:setContentSize( 629, 539 )
    return layer
end)

function RoleAttributeLayer:create( params )
    return RoleAttributeLayer.new( params )
end

function RoleAttributeLayer:ctor( params )
    self:initData()
    self:initUI()
    self:refreshHero( params )
    self:preload()

    --新手引导
    performWithDelay(self, function()
        self:addGuideFunc(self._weaponBtn)
    end, 0.1)

    local function onNodeEvent(event)
        if "enter" == event then
            self:onEnter()
        elseif "cleanup" == event then
            self:onCleanup()
        end
    end
    self:registerScriptHandler(onNodeEvent)

    -- 刷新装备
    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_ROLE_REFRESHEQUIP,
        callback = function()
            -- 战斗力变化
            -- self:onFightChange( self._heroData )
            zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 5}})
            self._fightNum:setString( self._heroData.fighting )
            self:refreshEquip()
            self:guideFunc()
        end,
    })
end

function RoleAttributeLayer:onEnter()
    if not self:isVisible() then
        return
    end
    -- 顶部信息栏
    LayerManager.getTopInfoLayer():setPopInfo( "RoleAttributeLayer" )

    if self._init then
        self:refreshWeaponRedDot()
        self:refreshEquipRedDot()
        zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_REFRESH_ROLE_POP})
    else
        self._init = true
    end
end

function RoleAttributeLayer:onCleanup()
    self._exist = false
    zc.removeEventListener( CUSTOM_EVENT.EVENT_ROLE_REFRESHEQUIP )
end

function RoleAttributeLayer:initData()
    self._equipPos = {
        1, 5, 2, 3, 6, 4
    }

    self._armatureX = 232
    self._armatureY = 64

    local _size = self:getContentSize()
    self._width = _size.width
    self._height = _size.height

    self._exist = true
end

function RoleAttributeLayer:initUI()
    -- 背景
    local _bg = cc.Sprite:create( "res/Main/role/common/role_bg.png" )
    _bg:setPosition( self._width/2, self._height/2 )
    self:addChild( _bg )

    local _middleX = 307

    -- 武将阴影层
    local _shadowHeroWidth = 567
    local _shadowHeroHeight = 320
    local _shadowHero = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    _shadowHero:setContentSize( _shadowHeroWidth, _shadowHeroHeight )
    _shadowHero:setAnchorPoint( 0.5, 0 )
    _shadowHero:setPosition( _middleX, self._height - 373 )
    _bg:addChild( _shadowHero )
    self._shadowHero = _shadowHero

    -- 顶部
    local _topBg = cc.Sprite:create( "res/Main/role/common/top_bg.jpg" )
    _topBg:setAnchorPoint( 0.5, 1 )
    local _topBgPos = cc.p( _middleX, self._height - 5 )
    _topBgPos = _bg:convertToWorldSpace( _topBgPos )
    _topBgPos = _shadowHero:convertToNodeSpace( _topBgPos )
    _topBg:setPosition( _topBgPos )
    _shadowHero:addChild( _topBg )
    local _topBgSize = _topBg:getContentSize()
    local _topBgWidth = _topBgSize.width
    local _topBgHeight = _topBgSize.height
    _topBg:setScaleX( 594/_topBgWidth )

    -- 名字
    local _nameBg = ccui.Scale9Sprite:create( cc.rect( 12, 11, 14, 10 ), "res/Main/role/common/name_bg.png" )
    _nameBg:setContentSize( 408, 30 )
    _nameBg:setPosition( _topBgWidth/2, _topBgHeight/2 )
    _topBg:addChild( _nameBg )
    local _name = zc.createRichLabel({
        fontSize = 23,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 245, 163 ),
    })
    _name:setPosition( _topBgWidth/2, _topBgHeight/2 )
    _topBg:addChild( _name )
    self._name = _name

    -- 武器图标
    local _weaponIconBg = cc.Sprite:create( "res/Main/role/common/weapon_icon_bg.png" )
    _weaponIconBg:setAnchorPoint( 0, 0 )
    _weaponIconBg:setPosition( 0, 0 )
    _topBg:addChild( _weaponIconBg )
    local _weaponIcon = cc.Sprite:create()
    _weaponIcon:setPosition( _weaponIconBg:getContentSize().width/2 + 2, -10 )
    _weaponIconBg:addChild( _weaponIcon )
    self._weaponIcon = _weaponIcon

    -- 属性
    local _attrBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/exclamation_u.png",
        selectedFile = "res/Main/common/button/exclamation_d.png",
        needSwallow = false,
        touchScale = 0.9,
        pos = cc.p( _topBgWidth - 23, _topBgHeight/2 ),
        endCallback = function()
            zc.createHeroInfoPop({id = self._id, showHero = not self._isMainRole})
        end,
    })
    _topBg:addChild( _attrBtn )

    -- 称号
    local _selectTitle = zc.createPushButton({
        normalFile = "res/Main/role/attribute/title_u.png",
        selectedFile = "res/Main/role/attribute/title_d.png",
        touchSize = cc.size(100,100),
        needSwallow = false,
        touchScale = 0.9,
        pos = cc.p( 390, _nameBg:getContentSize().height/2 ),
        endCallback = function()
            zc.sendHttp({
                apiName = "Chenghao_get",
                successCallback = function (net_data)
                    local function refresh()
                        local _nameText = zc.getLevelTipShow()..self._heroData.level.." "..PlayerData.info.userName
                        local _newAdvance = tonumber(self._heroData.newAdvance) or 0
                        if _newAdvance > 0 then
                            _nameText = _nameText .. "+" .. _newAdvance
                        end
                        self._name:setString( _nameText.."  [color=ffe400ff]< "..zc.getGodNameById( PlayerData:getBaseInfoByTag( "godName" ) ).." >[/color]" )
                    end
                    net_data.callback = refresh
                    zc.createSourcePop("RoleTitlePop", "src/layer/role/RoleTitlePop.lua", net_data)
                end
            })
        end,
    })
    _nameBg:addChild( _selectTitle )
    self._selectTitle = _selectTitle

    -- 光
    local _spine = zc.getSpine( "jsxxyxg" )
    _spine:setPosition( self._armatureX, self._armatureY + 105 )
    _spine:playAction( "animation", true )
    _shadowHero:addChild( _spine )

    -- 武将
    local _heroBtn = zc.createPushButton({
        touchSize = cc.size( 200, 210 ),
        pos = cc.p( self._armatureX, self._armatureY + 105 ),
        endCallback = function()
            local _action = zc.random(1, 3)
            if self._heroAction and self._heroAction == _action then
                if _action < 3 then
                    _action = _action + 1
                else 
                   _action = 1 
                end
            end
            self._heroAction = _action
            local _actions = {"atk3", "atk", "atk0"}
            if self._heroArmature then
                self._heroArmature:getAnimation():play( _actions[_action], -1, 0 )
            end
        end
    })
    _shadowHero:addChild( _heroBtn )
    
    -- 战斗力
    local _fightBg = cc.Sprite:create( "res/Main/role/common/fight_bg.png" )
    _fightBg:setAnchorPoint( 0.5, 0 )
    _fightBg:setPosition( self._armatureX, 0 )
    _shadowHero:addChild( _fightBg, 2 )
    local _fightNum = zc.createFntLabel({
        fnt = "res/Main/common/fnt/fight_change.fnt",
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 90, _fightBg:getContentSize().height/2 ),
        addwidth = -14,
    })
    _fightNum:setScale( 0.7 )
    _fightBg:addChild( _fightNum )
    self._fightNum = _fightNum

    -- 阵营
    local _camp = cc.Sprite:create()
    _camp:setAnchorPoint( 0, 0 )
    _camp:setPosition( 0, 0 )
    _shadowHero:addChild( _camp )
    self._camp = _camp

    -- 兵器
    local _weaponBg = cc.Sprite:create()
    _weaponBg:setPosition( _shadowHeroWidth - 74, 190 )
    _shadowHero:addChild( _weaponBg )
    self._weaponBg = _weaponBg
    local _weaponBgBtn = zc.createPushButton({
        touchSize = cc.size( 146, 221 ),
        pos = cc.p( _weaponBg:getPosition() ),
        endCallback = function()
            local weaponPop = requires( "src/layer/role/RoleWeaponPop.lua" ):create({
                id = self._id,
                isMainRole = self._isMainRole,
                callback = function( _animation )
                    self:changeWeapon( _animation )
                end
            })
            if weaponPop._exist then
                LayerManager.addNode( weaponPop, {isPop = true})
            else
                local tipPop = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    leftText =  zc.lang("qianwang") .. zc.lang("weapon_copy"),
                    rightText = zc.lang("qianwang") .. zc.lang("main_line"),
                    msg = zc.lang("tips_challenge_mainline_or_weaponcopy_can_get_is_go"),
                    leftCallback = function()
                        zc.createWeaponCopy()
                    end,
                    rightCallback = function()
                        zc.toReceiveRewardsView("72|0")
                    end,
                    showDi = true,
                })
                tipPop._isRemoveLayout = true
                LayerManager.addNode( tipPop, {isPop = true} )
            end
        end
    })
    _shadowHero:addChild( _weaponBgBtn )
    local _weaponBtn = zc.createCommomBtn({
        tag = 1,
        btnText = zc.lang("replace_2"),
        pos = cc.p( _shadowHeroWidth - 85, 42 ),
        endCallback = function()
            --新手引导
            self:guideFunc()

            local weaponPop = requires( "src/layer/role/RoleWeaponPop.lua" ):create({
                id = self._id,
                isMainRole = self._isMainRole,
                callback = function( _animation )
                    self:changeWeapon( _animation )
                end
            })
            if weaponPop._exist then
                LayerManager.addNode( weaponPop, {isPop = true})
            else
                --引导出错
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_5019 then
                    getGuideManager():setNextGID(GuideKey.KEY_5020)
                    self:guideFunc()
                    return
                end
                local tipPop = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    leftVisible = false,
                    rightText = zc.lang("qianwang") .. zc.lang("weapon_copy"),
                    msg = zc.lang("tips_challenge_eaponcopy_can_get_is_go"),
                    rightCallback = function()
                        zc.createWeaponCopy()
                    end,
                    showDi = true,
                })
                tipPop._isRemoveLayout = true
                LayerManager.addNode( tipPop, {isPop = true} )
            end
        end
    })
    _shadowHero:addChild( _weaponBtn )
    self._weaponBtn = _weaponBtn
    -- 武器图片
    local _weaponSp = cc.Sprite:create()
    self._weaponSp = _weaponSp
    -- stencil
    local stencil = cc.Node:create()
    stencil:setAnchorPoint( 0, 0 )
    stencil:setPosition( 0, 5 )
    local _stencil = cc.Sprite:create( "res/Main/role/attribute/weaponBg_main.png" )
    _stencil:setAnchorPoint( 0, 0 )
    _stencil:setPosition( 0, 0 )
    stencil:addChild( _stencil )
    -- clippingNode
    local clippingNode = cc.ClippingNode:create()
    clippingNode:addChild( _weaponSp )
    clippingNode:setStencil( stencil )
    clippingNode:setInverted( false )
    clippingNode:setAlphaThreshold( 0 )
    _weaponBg:addChild( clippingNode )
    -- 渐变
    local _weaponTopSp = cc.Sprite:create( "res/Main/role/attribute/opacity.png" )
    _weaponTopSp:setAnchorPoint( 0, 0 )
    _weaponTopSp:setPosition( 0, 0 )
    _weaponBg:addChild( _weaponTopSp )
    self._weaponTopSp = _weaponTopSp
    -- 添加红点
    local _redPoint = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint:setAnchorPoint( 1, 1 )
    _redPoint:setPosition( _weaponBtn:getContentSize().width, _weaponBtn:getContentSize().height )
    _redPoint:setVisible( false )
    _weaponBtn:addChild( _redPoint )
    _weaponBtn._redPoint = _redPoint

    -- 装备阴影层
    local _shadowEquipWidth = 567
    local _shadowEquipHeight = 112
    local _shadowEquip = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    _shadowEquip:setContentSize( _shadowEquipWidth, _shadowEquipHeight )
    _shadowEquip:setPosition( _middleX, 100 )
    _bg:addChild( _shadowEquip )
    self._equip = {}
    for i = 1, 6 do
        local _posX = _shadowEquipWidth/2 - 315 + 90*i
        local _equipIconBg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
        _equipIconBg:setContentSize( 88, 88 )
        _equipIconBg:setPosition( _posX, _shadowEquipHeight/2 )
        _shadowEquip:addChild( _equipIconBg )
        local _equipIcon = zc.createIconByData({
            data = {
                mainType=1,
                type=1,
                id=1,
            },
            pos = cc.p( _posX, _shadowEquipHeight/2 ),
        })
        _shadowEquip:addChild( _equipIcon )
        _equipIcon:setScale( 0.7 )
        -- 添加红点
        local _redDot = cc.Sprite:create( "res/Main/common/common_red_point.png" )
        _redDot:setAnchorPoint( 1, 1 )
        _redDot:setPosition( _equipIcon:getContentSize().width, _equipIcon:getContentSize().height )
        _redDot:setVisible( false )
        _equipIcon:addChild( _redDot )
        _equipIcon._redDot = _redDot
        self._equip[i] = _equipIcon
    end

    local _frame = ccui.Scale9Sprite:create( cc.rect( 16, 0, 32, 511 ), "res/Main/common/frame.png" )
    _frame:setContentSize( 611, 513 )
    _frame:setAnchorPoint( 0, 1 )
    local _framePos = cc.p( 2, self._height )
    _framePos = _bg:convertToWorldSpace( _framePos )
    _framePos = _shadowHero:convertToNodeSpace( _framePos )
    _frame:setPosition( _framePos )
    _shadowHero:addChild( _frame )
end
-- 创建武将
function RoleAttributeLayer:createHero( _changeWeapon )
    if self._heroArmature then
        self._heroArmature:removeFromParent()
        self._heroArmature = nil
    end
    local _armature = zc.battle.createHeroArmature({
        fileName = self._heroData.modelId,
        heroDataWeaponId = self._weaponData and self._weaponData.weaponId or 0,
        async = true,
        asyncCallback = function( _armature_ , fileName , num )
            if self._exist and _armature_ then
                zc.soldierChangeWeapon( _armature_, self._weaponData and self._weaponData.weaponId or 0 )
                if _changeWeapon then
                    _armature_:getAnimation():play("change2_done")
                else
                    _armature_:getAnimation():play("idle")
                end
                local function animationEvent(armatureBack,movementType,movementID)
                    if movementType == ccs.MovementEventType.complete then
                        armatureBack:getAnimation():play("idle")
                    end
                end
                _armature_:getAnimation():setMovementEventCallFunc(animationEvent)
            end
        end
    })
    _armature:setPosition( self._armatureX, self._armatureY )
    _armature:setScaleX( 1.2 )
    _armature:setScaleY( 1.2 )
    self._shadowHero:addChild( _armature, 1 )
    self._heroArmature = _armature
    self._record[#self._record + 1] = {
        self._heroData.modelId, self._weaponData and self._weaponData.weaponId or 0,
    }
end
-- 更换武器刷新人物
function RoleAttributeLayer:changeWeapon( _animation )
    -- 兵器数据
    self._weaponData = PlayerData:getWeaponsInfoById( self._id )
    
    if self._isMainRole then
        --主角换兵器，红点刷新
        PlayerData:checkGodWeaponRedDotState()
        -- 男女主角需要特殊处理，换模型
        local function _refresh()
            self:createHero( true )
            zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_MAINROLE_CHANGE})
            self:refreshWeapon()
        end
        if _animation then
            getGuideManager():addMaskLayer()
            local _heroArmature = self._heroArmature
            _heroArmature:getAnimation():play("change_start")
            _heroArmature:setColor( cc.c3b(255,255,255) )
            local _armature = zc.battle.createBattleEffect({fileName = "change_2" , actName = "change_start" , autoRemove = true})
            _armature:setPosition( self._armatureX, self._armatureY )
            self._shadowHero:addChild( _armature, 2 )
            _heroArmature:getAnimation():setFrameEventCallFunc(function(bone, frameName)
                if frameName == "change2" then
                    _refresh()
                    --新手引导
                    performWithDelay(self, function ()
                        self:guideFunc()
                        getGuideManager():removeMaskLayer()
                    end, 1.5)
                end
            end)
        else
            _refresh()
        end
    else
        local function _refresh()
            self:refreshWeapon()
        end
        if _animation then
            getGuideManager():addMaskLayer()
            local _heroArmature = self._heroArmature
            _heroArmature:getAnimation():play("change",-1,0)
            local _bone = _heroArmature:getBone("change")
            if tolua.isnull(_bone) then
                -- zc.tipInfo("没有change骨骼")
                _refresh()
                --新手引导
                performWithDelay(self, function ()
                    self:guideFunc()
                    getGuideManager():removeMaskLayer()
                end, 1.5)
                return
            end
            _heroArmature:getAnimation():setFrameEventCallFunc(function(bone, frameName)
                if frameName == "change" then
                    local _armature = zc.battle.createBattleEffect({fileName = "change" , actName = "change" , autoRemove = true})
                    _bone:addDisplay(_armature, 0)
                    _bone:changeDisplayWithIndex( 0, true )
                    _bone:getDisplayRenderNode():setCascadeOpacityEnabled( false )
                    _bone:setOpacity( 255 )
                    _refresh()
                    --新手引导
                    performWithDelay(self, function ()
                        self:guideFunc()
                        getGuideManager():removeMaskLayer()
                    end, 1.5)
                end
            end)
        else
            _refresh()
        end
    end
end
function RoleAttributeLayer:preload()
    zc.battle.createBattleEffect({fileName = "change", actName = "change", async = true})
end
-- 更换武器刷新
function RoleAttributeLayer:refreshWeapon()
    -- 战斗力变化
    self:onFightChange( self._heroData )
    -- 人物换武器
    if self._weaponData then
        zc.soldierChangeWeapon( self._heroArmature, self._weaponData.weaponId )
    else
        self:createHero()
    end
    self:refreshWeaponUI()

    self:refreshWeaponRedDot()

    zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 5}})
end
-- 刷新武器相关ui
function RoleAttributeLayer:refreshWeaponUI()
    -- 兵器图标
    local _weaponType = 1
    if self._isMainRole then
        -- 主角
        _weaponType = tonumber( self._weaponData.type ) or 1
    else
        _weaponType = tonumber( self._heroList.weaponType ) or 1
    end
    self._weaponIcon:setTexture( "res/Main/role/common/weapon_icon_".._weaponType..".png" )
    
    self._weaponSp:removeAllChildren()
    self._weaponSp:setOpacity( 255 )
    if self._weaponData then
        self._weaponSp:setTexture( "res/Main/weapon/weaponImage/"..( self._weaponData.iconId or 1 )..".png" )
        zc.showWeaponEffect( self._weaponSp, self._weaponData.weaponId )
        if self._isMainRole then
            self._weaponBtn:setText(zc.lang("strength"))
        else
            if zc.getFunctionStatus( 29 ) then
                -- 洗练开启
                self._weaponBtn:setText(zc.lang("smithy_clear"))
            else
                -- 洗练未开启
                self._weaponBtn:setText(zc.lang("replace"))
            end
        end
        -- 位置
        if _weaponType == 1 then
            self._weaponSp:setAnchorPoint( 0, 0.5 )
            self._weaponSp:setPosition( 68, 167 )
            self._weaponSp:setRotation( 90 )
            self._weaponTopSp:setVisible( true )
            if not zc.checkFileExist("res/Main/weapon/weaponImage/"..( self._weaponData.iconId or 1 )..".png") then
                self._weaponSp:setPosition( 68, 10 )
            end
        elseif _weaponType == 2 or _weaponType == 4 then
            self._weaponSp:setAnchorPoint( 0.5, 0.5 )
            self._weaponSp:setPosition( 68, 95 )
            self._weaponSp:setRotation( 90 )
            self._weaponTopSp:setVisible( false )
        else
            self._weaponSp:setAnchorPoint( 0.5, 0.5 )
            self._weaponSp:setPosition( 68, 95 )
            self._weaponSp:setRotation( 0 )
            self._weaponTopSp:setVisible( false )
        end
    else
        self._weaponSp:setTexture( "res/Main/role/attribute/unequip.png" )
        self._weaponSp:setAnchorPoint( 0.5, 0.5 )
        self._weaponSp:setPosition( 63, 80 )
        self._weaponSp:setRotation( 0 )
        self._weaponBtn:setText(zc.lang("equip"))
    end
end
-- 战斗力变化响应
function RoleAttributeLayer:onFightChange( data )
    zc.numChangeAnimation({
        label = self._fightNum,
        pos = cc.p( self._fightNum:getContentSize().width/2, 20 ),
        callback = function()
            self._fightNum:setString( data.fighting )
        end
    })
end

-- 更换武将刷新
function RoleAttributeLayer:refreshHero( params )
    self:refreshHeroData( params )

    self:refreshHeroUI()
end
function RoleAttributeLayer:refreshHeroData( params )
    -- 数据
    self._id = tonumber( params.id ) or 1

    -- 武将数据
    self._heroData = PlayerData:getGeneralInfoById( self._id )

    -- 武将信息，静态表，用来显示资质和阵营和兵器图标
    self._heroList = gameData.getDataFromCacheWithPrimaryKey("hero", self._heroData.heroId)

    -- 兵器数据
    self._weaponData = PlayerData:getWeaponsInfoById( self._id )

    -- 是否是主角
    local _mainRoleId = tonumber( PlayerData.info.heroId ) or 0
    self._isMainRole = _mainRoleId == self._id

    self._record = params.record
end
function RoleAttributeLayer:refreshHeroUI()
    -- 名字
    local _nameText = zc.getLevelTipShow()..self._heroData.level.." "..( self._isMainRole and PlayerData.info.userName or  self._heroData.name )
    local _reincarnate = tonumber( self._heroData.reincarnate ) or 0
    if _reincarnate > 0 then
        _nameText = _reincarnate.. zc.lang("turn") .._nameText
    end
    local _newAdvance = tonumber(self._heroData.newAdvance) or 0
    if _newAdvance > 0 then
        _nameText = _nameText .. "+" .. _newAdvance
    end
    local _titleText = self._heroData.title
    self._name:setString( _nameText.."  [color=ffe400ff]< ".._titleText.." >[/color]" )
    if self._isMainRole then
        self._selectTitle:setVisible( true )
    else
        self._selectTitle:setVisible( false )
    end
    -- 星级
    zc.createHeroStar( self._shadowHero, self._heroData.star, cc.p( 32, 277 ) )
    -- 战斗力
    self._fightNum:setString( self._heroData.fighting )
    -- 阵营
    self._camp:setTexture( "res/Main/role/camp_"..self._heroList.camp..".png" )
    -- 武器
    local _weaponBgPath = ""
    if self._isMainRole then
        -- 神兵
        _weaponBgPath = "res/Main/role/attribute/weaponBg_main.png"
    else
        -- 兵器
        _weaponBgPath = "res/Main/role/attribute/weaponBg_hero.png"
    end
    self._weaponBg:setTexture( _weaponBgPath )
    
    self:refreshWeaponUI()
    -- 武将
    self:createHero()

    self:refreshEquip()
end
-- 刷新六件装备
function RoleAttributeLayer:refreshEquip()
    -- 装备
    for i, v in ipairs( self._equip ) do
        local _data = PlayerData:getEquipInfoByHeroIdAndPos( self._id, self._equipPos[i] )
        if _data then
            zc.updateIconByData(v, {
                data = {
                    mainType=zc.mainTypeEquip,
                    type=_data.equipmentId,
                    id=_data.equipmentId,
                    level=zc.getLevelTipShow().._data.strengthenLevel,
                },
                showLevel = true,
                listener = function()
                    local _currentGID = getGuideManager():getCurrentGID()
                    if inArray(_currentGID, GuideGroup.BTN_SELECT_EQUIP) then
                        zc.setGuideFuncNextStep(_currentGID, false)
                        getGuideManager():addMaskLayer()
                    end
                    zc.createRoleEquipPop({id = self._id, pos = self._equipPos[i]})
                end
            })
            v:setVisible( true )
        else
            v:setVisible( false )
        end
    end
    self:refreshEquipRedDot()
end
-- 刷新装备的红点
function RoleAttributeLayer:refreshEquipRedDot()
    local _heroLevel = tonumber( self._heroData.level ) or 0
    for i, v in ipairs( self._equip ) do
        local _data = PlayerData:getEquipInfoByHeroIdAndPos( self._id, self._equipPos[i] )
        if _data then
            local _flag = zc.getEquipStrengthenStatus( _data, _heroLevel )
            if not _flag then
                _flag = zc.getEquipAdvanceStatus( _data )
            end
            v._redDot:setVisible( _flag )
        end
    end
end


---新手引导 
function RoleAttributeLayer:addGuideFunc(btn)
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_5018 and self._heroData.heroId == GuideHeroId.KEY_5018 then
        if self._weaponData then
            getGuideManager():setCurrentGID(GuideKey.KEY_5023)
            self:guideFunc()
            return
        end
        getGuideManager():setObjTarget(btn)
        getGuideManager():startGuide()
    end
end

--新手引导点击装备响应
function RoleAttributeLayer:guideFunc()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_5018 then 
        getGuideManager():setNextGID(_currentGID)
    elseif _currentGID == GuideKey.KEY_5023 then
        self:getParent():onEnter()
    elseif inArray(_currentGID, GuideGroup.BTN_SELECT_EQUIP) then
        local _guideBtn = self._equip[1]
        getGuideManager():setObjTarget(_guideBtn)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_5037 then
        local function _callBack()
            self:getParent():onEnter()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    end
end

function RoleAttributeLayer:refreshWeaponRedDot()
    if self._isMainRole then
        self._weaponBtn._redPoint:setVisible( PlayerData:getGodWeaponRedDotState() )
    else
        if zc.getChangeWeaponRedDotStatus({ self._heroData }) then
            self._weaponBtn._redPoint:setVisible( true )
        elseif PlayerData:checkCanClearWeaponsByHeroId( self._heroData.id ) then
            self._weaponBtn._redPoint:setVisible( true )
        else
            self._weaponBtn._redPoint:setVisible( false )
        end
    end
end


return RoleAttributeLayer