--[[
	装备弹窗
	唐实聪
	2016.8.12
]]
local RoleEquipPop = class("RoleEquipPop", function()
	return ZCPopLayer:create()
end)

function RoleEquipPop:create( params )
	return RoleEquipPop.new( params )
end

function RoleEquipPop:ctor( params )
	self:initData( params )
	self:initUI()
    self:refreshAdvanceRedDot()
    self:show(true, function()
        -- 设置顶部信息
        local _top = LayerManager.getTopInfoLayer()
        _top:setPopInfo( "RoleEquipPop" )
        local _root = LayerManager.getCurRootLayer()
        _root:reorderChild( _top, _top:getLocalZOrder() )
    end)
    self:setHideCallback(function()
        -- 设置顶部信息
        local _top = LayerManager.getTopInfoLayer()
        _top:setPopInfo( "RoleAttributeLayer" )
    end)
    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_REFRESH_FORM_SWEEP,
        callback = function()
            if self._type == 2 then
                self:refreshAdvanceConsume()
                self:refreshAdvanceRedDot()
            end
        end,
    })
    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_REFRESH_ROLE_POP,
        callback = function()
            if self._type == 1 then
                self:refreshStrengthenConsume()
            else
                self:refreshAdvanceConsume()
            end
            self:refreshAdvanceRedDot()
        end
    })
end

function RoleEquipPop:onCleanup()
    zc.removeEventListener( CUSTOM_EVENT.EVENT_REFRESH_FORM_SWEEP )
    zc.removeEventListener( CUSTOM_EVENT.EVENT_REFRESH_ROLE_POP )
    zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLE_REFRESHEQUIP})
end

-- 处理数据
function RoleEquipPop:initData( params )
    self._id = tonumber( params.id ) or 0
    local _pos = params.pos or 0

    self._heroData = PlayerData:getGeneralInfoById( self._id )
    self._equipData = PlayerData:getEquipInfoByHeroIdAndPos( self._id, _pos )
    self._equipStaticData = gameData.getDataFromCacheWithPrimaryKey("equip", self._equipData.equipmentId)

    self._type = tonumber( params.type ) or 1

	local _size = self:getContentSize()
	self._width = _size.width
	self._height = _size.height
end
-- 初始化界面
function RoleEquipPop:initUI()
    cc.SpriteFrameCache:getInstance():addSpriteFrames("res/Main/home/homeUI.plist", "res/Main/home/homeUI.pvr.ccz")

    -- 左
	self:initLeftLayer()
    self:refreshLeftLayer()
    -- 右
    if self._type == 1 then
        self:initStrengthenLayer()
        self:refreshStrengthenLayer()
    elseif self._type == 2 then
        self:initAdvanceLayer()
        self:refreshAdvanceLayer()
    end

    self:refreshGemIcon( self._equipData )
end

-- 创建左侧弹窗
function RoleEquipPop:initLeftLayer()
	if self._leftLayer then
		return
	end

	-- 背景
	local _bgWidth = 373
	local _bgHeight = 575 + 31
    local _bg = zc.createNormalPop({
        tag = 1,
        titleTag = 1,
        height = _bgHeight,
        showSide = false,
    })
	_bg:setPosition( self._width/2 - 238, self._height/2 - 30 )
	self:addContent( _bg )
	self._leftLayer = _bg

	-- 顶部
	local _topBgWidth = _bgWidth - 26
	local _topBgHeight = 130 + 15
    local _topBg = zc.createGeneralPopScale({
        width = _topBgWidth,
        height = _topBgHeight,
    })
	_topBg:setPosition( _bgWidth/2, _bgHeight - 152 )
	_bg:addChild( _topBg, 1 )
    -- 背景
    local _iconBg = cc.Sprite:create( "res/Main/common/popBg/bgFlower.png" )
    _iconBg:setPosition( 70, _topBgHeight*0.5 )
    _iconBg:setScale( 0.7 )
    _topBg:addChild( _iconBg )
	-- 装备
	local _equip = zc.createIconByData({
        data = {
            mainType = zc.mainTypeEquip,
            type = 1,
            id = 1,
            quality = 1,
        },
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( _iconBg:getPosition() ), 
    })
    _equip:setScale( 0.7 )
    _topBg:addChild( _equip )
    _bg._equip = _equip
    -- 名字背景
    local _nameBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
	_nameBg:setPosition( 240, _topBgHeight*0.5 + 20 )
	_topBg:addChild( _nameBg )
    -- 名字
    local _name = zc.createLabel({
        fontSize = 20,
        pos = cc.p( _nameBg:getContentSize().width/2, _nameBg:getContentSize().height/2 ),
        outLine = true,
        pixel = 1.5,
    })
    _nameBg:addChild( _name )
    _bg._name = _name
    -- 强化等级背景
    local _levelBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
    _levelBg:setPosition( 240, _topBgHeight*0.5 - 20 )
    _topBg:addChild( _levelBg )
    -- 强化等级
    local _level = zc.createLabel({
        fontSize = 20,
        pos = cc.p( _levelBg:getContentSize().width/2, _levelBg:getContentSize().height/2 ),
        outLine = true,
        pixel = 1.5,
    })
    _levelBg:addChild( _level )
    _bg._level = _level

	-- 底部
	local _bottomBgWidth = _bgWidth - 26
	local _bottomBgHeight = 360
	local _bottomBg = zc.createGeneralPopScale({
        tag = 3,
        width = _bottomBgWidth,
        height = _bottomBgHeight,
    })
	_bottomBg:setAnchorPoint( 0.5, 0 )
	_bottomBg:setPosition( _bgWidth/2, 15 )
	_bg:addChild( _bottomBg )

	-- 基础属性背景
	local _baseAttrBgWidth = _bottomBgWidth - 18
	local _baseAttrBgHeight = 255
	local _baseAttrBg = zc.createGeneralPopScale({
        tag = 2,
        width = _baseAttrBgWidth,
        height = _baseAttrBgHeight,
    })
	_baseAttrBg:setAnchorPoint( 0.5, 1 )
	_baseAttrBg:setPosition( _bottomBgWidth/2, _bottomBgHeight - 10 )
	_bottomBg:addChild( _baseAttrBg )

    local _baseAttrScrollview = zc.createScrollview({
        pos = cc.p( 0, 0 ),
        size = cc.size( _baseAttrBgWidth, _baseAttrBgHeight ),
        touchEnable = true,
        bounceEnable = true,
        dir = ccui.ScrollViewDir.vertical,
    })
    _baseAttrBg:addChild( _baseAttrScrollview )
    _bg._baseAttrScrollview = _baseAttrScrollview

    self:createGemIcon( _baseAttrScrollview, _baseAttrBgWidth )

    -- 基础属性标题
    local _baseAttrTitle = cc.Sprite:create( "res/Main/role/equip/baseAttr.png" )
    _baseAttrTitle:setPosition( _baseAttrBgWidth/2, _baseAttrBgHeight - 20 )
    _baseAttrScrollview:addChild( _baseAttrTitle )
    _bg._baseAttrTitle = _baseAttrTitle
    local _baseAttrTitleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
    _baseAttrTitleLeft:setAnchorPoint( 1, 0.5 )
    _baseAttrTitleLeft:setPosition( 0, _baseAttrTitle:getContentSize().height/2 )
    _baseAttrTitle:addChild( _baseAttrTitleLeft )
    local _baseAttrTitleRight = cc.Sprite:create( "res/Main/common/lace.png" )
    _baseAttrTitleRight:setAnchorPoint( 0, 0.5 )
    _baseAttrTitleRight:setPosition( _baseAttrTitle:getContentSize().width, _baseAttrTitle:getContentSize().height/2 )
    _baseAttrTitleRight:setFlippedX( true )
    _baseAttrTitle:addChild( _baseAttrTitleRight )
	-- 基础属性
	_bg._baseAttrLabel = {}
	local _baseAttrLineHeight = 30
	for i = 1, 3 do
        -- 基础属性
        local _attrText = zc.createLabel({
            fontSize = 18,
            ttf = zc.getFont( 1 ),
            pos = cc.p( 24, _baseAttrBgHeight - 30 - i*_baseAttrLineHeight ),
            outLine = true,
            color = cc.c3b(230,224,163),
        })
        _attrText:setAnchorPoint( 0, 0.5 )
        _baseAttrScrollview:addChild( _attrText )
        local _attrNum = zc.createLabel({
            fontSize = 18,
            ttf = zc.getFont( 1 ),
            pos = cc.p( 120, _attrText:getPositionY() ),
            outLine = true,
        })
        _attrNum:setAnchorPoint( 0, 0.5 )
        _baseAttrScrollview:addChild( _attrNum )
        local _attrAddNum = zc.createLabel({
            fontSize = 18,
            ttf = zc.getFont( 1 ),
            pos = cc.p( 250, _attrText:getPositionY() ),
            outLine = true,
            color = cc.c3b(42,255,0),
        })
        _attrAddNum:setAnchorPoint( 1, 0.5 )
        _baseAttrScrollview:addChild( _attrAddNum )
        _bg._baseAttrLabel[i] = {
            _attrText = _attrText,
            _attrNum = _attrNum,
            _attrAddNum = _attrAddNum,
        }
    end

    -- 强化
    local _strengthenBtn = zc.createCommomBtn({
		tag = 1,
        text = zc.lang("strength_2"),
        pos = cc.p( 87, 45 ),
        endCallback = function()
            if self._type ~= 1 then
                self:initStrengthenLayer()
                self:refreshStrengthenLayer()
                self._strengthenLayer:setVisible( true )
                self._strengthenLayer:setLocalZOrder( 1 )
                if self._advanceLayer then
                    self._advanceLayer:setVisible( false )
                    self._advanceLayer:setLocalZOrder( 0 )
                end
                self._type = 1
            end
    	end
	})
	_bottomBg:addChild( _strengthenBtn )
	_bg._strengthenBtn = _strengthenBtn
    -- 添加红点
    local _redPoint_strengthen = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint_strengthen:setAnchorPoint( 1, 1 )
    _redPoint_strengthen:setPosition( _strengthenBtn:getContentSize().width + 5, _strengthenBtn:getContentSize().height + 5 )
    _redPoint_strengthen:setVisible( false )
    _strengthenBtn:addChild( _redPoint_strengthen )
    _strengthenBtn._redPoint = _redPoint_strengthen
    -- 进阶
    local _advanceBtn = zc.createCommomBtn({
		tag = 2,
        text = zc.lang("advanced_2"),
        pos = cc.p( _bottomBgWidth - 87, 45 ),
        endCallback = function()
            if self._type ~= 2 then
                self:initAdvanceLayer()
                self:refreshAdvanceLayer()
                self._advanceLayer:setVisible( true )
                self._advanceLayer:setLocalZOrder( 1 )
                if self._strengthenLayer then
                    self._strengthenLayer:setVisible( false )
                    self._strengthenLayer:setLocalZOrder( 0 )
                end
                self._type = 2
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_5034 then
                    zc.setGuideFuncNextStep(_currentGID, false)
                    self:addGuide()
                end
            end
    	end
	})
	_bottomBg:addChild( _advanceBtn )
	_bg._advanceBtn = _advanceBtn
    self._advanceBtn = _advanceBtn
    -- 添加红点
    local _redPoint_advance = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint_advance:setAnchorPoint( 1, 1 )
    _redPoint_advance:setPosition( _advanceBtn:getContentSize().width, _advanceBtn:getContentSize().height )
    _redPoint_advance:setVisible( false )
    _advanceBtn:addChild( _redPoint_advance )
    _advanceBtn._redPoint = _redPoint_advance
    -- 吞噬触摸，动画时防止切换
    local _swallow = zc.createPushButton({
        touchSize = cc.size( _bgWidth, _bgHeight ),
        pos = cc.p( _bgWidth/2, _bgHeight/2 ),
        needSwallow = true,
    })
    _swallow:setEnable( false )
    _bg:addChild( _swallow, 2 )
    _bg._swallow = _swallow
end
-- 刷新左侧弹窗
function RoleEquipPop:refreshLeftLayer()
	local _bg = self._leftLayer
	if not _bg then
		return
	end
    local _data = self._equipData
    local _static = self._equipStaticData
    local _level = tonumber( _data.strengthenLevel ) or 0

    local _info = zc.updateIconByData(_bg._equip, {
        data = {
            mainType=zc.mainTypeEquip,
            type=_data.equipmentId,
            id=_data.equipmentId,
        },
    })

    _bg._name:setText( _info.name )
    local _levelMax = 0
    local _levelMaxList = gameData.getDataFromCache( "equip_strengthen", { needQuality = _data.advanceLevel } )
    for k, v in pairs( _levelMaxList ) do
        local _levelTmp = tonumber( v.id ) or 0
        _levelMax = math.max( _levelMax, _levelTmp )
    end
    _bg._level:setText( zc.lang("strength_level") .. zc.lang("up_limit") .. ":  " .. zc.getLevelTipShow().._levelMax )

    local _showData = {}
	for i = 1, 3 do
        local _effectId = tonumber( _data["effectId"..i] ) or 0
        local _effectValue = tonumber( _static["value"..i] ) or 0
        if _effectId ~= 0 and _effectValue ~= 0 then
            local _name = zc.getEquipAttriNameByEffectType( _effectId, true )
            local _oriValue = zc.getAttributeNumById( _effectId, _effectValue )
            local _addText = ""
            if _level > 0 then
                local _value = tonumber( _static["effectValue"..i] ) or 0
                local _addValue = zc.getAttributeNumById( _effectId, _value*_level )
                _addText = "+".._addValue
            end
            _showData[#_showData + 1] = {
                _name,
                _oriValue,
                _addText,
            }
        end
    end

    local _baseAttrLineHeight = 30
    local _height = ( #_showData )*_baseAttrLineHeight + 35 + 85
    local _innerSize = _bg._baseAttrScrollview:getInnerContainerSize()
    _bg._baseAttrScrollview:setInnerContainerSize( cc.size( _innerSize.width, _height ) )
    local _outerSize = _bg._baseAttrScrollview:getContentSize()
    _height = _height < _outerSize.height and _outerSize.height or _height
    -- 设置位置
    _height = _height - 45
    for i, _iconBg in ipairs( self._gemIcon ) do
        _iconBg:setPositionY( _height )
    end
    _height = _height - 40
    _height = _height - 17
    _bg._baseAttrTitle:setPositionY( _height )
    _height = _height - 18
    for i, v in ipairs( _bg._baseAttrLabel ) do
        local __data = _showData[i]
        if __data then
            _height = _height - _baseAttrLineHeight/2
            v._attrText:setString( __data[1] )
            v._attrText:setVisible( true )
            v._attrText:setPositionY( _height )
            v._attrNum:setString( __data[2] )
            v._attrNum:setVisible( true )
            v._attrNum:setPositionY( _height )
            v._attrAddNum:setString( __data[3] )
            v._attrAddNum:setVisible( true )
            v._attrAddNum:setPositionY( _height )
            _height = _height - _baseAttrLineHeight/2
        else
            v._attrText:setVisible( false )
            v._attrNum:setVisible( false )
            v._attrAddNum:setVisible( false )
        end
    end
	-- _bg._strengthenBtn
	-- _bg._advanceBtn
	-- _bg._inlayBtn
	-- _bg._changeBtn
end


-- 创建强化弹窗
function RoleEquipPop:initStrengthenLayer()
	if self._strengthenLayer then
		return
	end
    -- 下层背景
    local _bgWidth = 496
    local _bgHeight = 475 + 31
    local _bg = zc.createNormalPop({
        width = _bgWidth,
        height = _bgHeight,
        showSide = false,
    })
    _bg:setPosition( self._width/2 + 210, self._height/2 )
    self:addContent( _bg )
    self._strengthenLayer = _bg

    local _equipPosY = _bgHeight - 130
	-- 装备
    local _equipCircle = zc.getSpine( "jsxxyxg" )
    _equipCircle:setPosition( _bgWidth/2, _equipPosY )
    _equipCircle:playAction( "animation", true )
    _equipCircle:setScale( 0.9 )
    _bg:addChild( _equipCircle )
    local _equipBg = ccui.Scale9Sprite:create( cc.rect( 20, 20, 78, 81 ), "res/Main/role/fetter/fetterItemBg.png" )
    _equipBg:setPosition( _equipCircle:getPosition() )
    _bg:addChild( _equipBg )
	local _equip = zc.createIconByData({
        data = {
            mainType = zc.mainTypeEquip,
            type = 1,
            id = 1,
            quality = 1,
        },
        ap = cc.p( 0.5, 0.5 ),
        pos = cc.p( _equipCircle:getPosition() ),
    })
    _equip:setScale( 0.86 )
    _bg:addChild( _equip )
    _bg._equip = _equip
    local _equip_arrow_l = cc.Sprite:create( "res/Main/role/equip/arrow_1.png" )
    _equip_arrow_l:setPosition( _equipCircle:getPositionX() - 105, _equipCircle:getPositionY() )
    _bg:addChild( _equip_arrow_l )
    local _equip_arrow_r = cc.Sprite:create( "res/Main/role/equip/arrow_1.png" )
    _equip_arrow_r:setPosition( _equipCircle:getPositionX() + 105, _equipCircle:getPositionY() )
    _equip_arrow_r:setFlippedX( true )
    _bg:addChild( _equip_arrow_r )

    -- 底部
    local _bottomBgWidth = _bgWidth - 26
    local _bottomBgHeight = 260
    local _bottomBg = zc.createGeneralPopScale({
        tag = 3,
        width = _bottomBgWidth,
        height = _bottomBgHeight,
    })
    _bottomBg:setAnchorPoint( 0.5, 0 )
    _bottomBg:setPosition( _bgWidth/2, 15 )
    _bg:addChild( _bottomBg )

    local _attrLineHeight = 30

    -- 属性背景
    _bg._attrLabel = {}
    -- 箭头
    _bg._arrow = {}

    local _title = {
        zc.lang("curr_property"), zc.lang("next_level_property1"),
    }
    for i = 1, 2 do
        local _attrBgWidth = ( _bottomBgWidth - 36 )/2
        local _attrBgHeight = 154
        local _attrBg = zc.createGeneralPopScale({
            tag = 2,
            width = _attrBgWidth,
            height = _attrBgHeight,
        })
        _attrBg:setAnchorPoint( 2 - i, 1 )
        _attrBg:setPosition( _bottomBgWidth/2 + 6*( 2*i - 3 ), _bottomBgHeight - 10 )
        _bottomBg:addChild( _attrBg )

        -- 属性标题背景
        local _attrTitle = zc.createLabel({
            text = _title[i],
            fontSize = 20,
            color = cc.c3b(53, 39, 18),
            pos = cc.p( _attrBgWidth/2, _attrBgHeight - 30 ),
        })
        _attrBg:addChild( _attrTitle )
        local _attrTitleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleLeft:setAnchorPoint( 1, 0.5 )
        _attrTitleLeft:setPosition( _attrTitle:getPositionX() - _attrTitle:getContentSize().width/2, _attrTitle:getPositionY() )
        _attrBg:addChild( _attrTitleLeft )
        local _attrTitleRight = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleRight:setAnchorPoint( 0, 0.5 )
        _attrTitleRight:setPosition( _attrTitle:getPositionX() + _attrTitle:getContentSize().width/2, _attrTitle:getPositionY() )
        _attrTitleRight:setFlippedX( true )
        _attrBg:addChild( _attrTitleRight )
        -- 属性
        _bg._attrLabel[i] = {}
        for j = 1, 3 do
            -- 属性
            if i == 1 then
                -- 属性
                local _attrText = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 20, _attrBgHeight - 30 - j*_attrLineHeight ),
                    outLine = true,
                    color = cc.c3b(230,224,163),
                })
                _attrText:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrText )
                local _attrNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 120, _attrText:getPositionY() ),
                    outLine = true,
                })
                _attrNum:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrNum )
                _bg._attrLabel[i][j] = {
                    _attrText = _attrText,
                    _attrNum = _attrNum,
                }
            elseif i == 2 then
                -- 属性名
                local _attrText = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 20, _attrBgHeight - 30 - j*_attrLineHeight ),
                    outLine = true,
                    color = cc.c3b(230,224,163),
                })
                _attrText:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrText )
                -- 属性值
                local _attrNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 80, _attrText:getPositionY() ),
                    outLine = true,
                })
                _attrNum:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrNum )
                -- 增加数字
                local _attrAddNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( _attrBgWidth - 30, _attrText:getPositionY() ),
                    outLine = true,
                    color = cc.c3b(42,255,0),
                })
                _attrAddNum:setAnchorPoint( 1, 0.5 )
                _attrBg:addChild( _attrAddNum )
                -- 箭头
                local _arrow = cc.Sprite:create( "res/Main/common/arrow_green.png" )
                _arrow:setPosition( _attrBgWidth - 15, _attrText:getPositionY() )
                _arrow:setRotation( -90 )
                _attrBg:addChild( _arrow )

                _bg._attrLabel[i][j] = {
                    _attrText = _attrText,
                    _attrNum = _attrNum,
                    _attrAddNum = _attrAddNum,
                    _arrow = _arrow,
                }
            end
        end
    end

    -- 强化一次
    -- 消耗
    local _consumeSp_one = cc.Sprite:create( zc.getImgByType( 2 ) )
    _consumeSp_one:setAnchorPoint( 0, 0.5 )
    _consumeSp_one:setPosition( 23, 75 )
    _bottomBg:addChild( _consumeSp_one )
    _bg._consumeSp_one = _consumeSp_one
    local _consumeNum_one = zc.createLabel({
    	fontSize = 22,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 40, 20 ),
        outLine = true,
	})
    _consumeSp_one:addChild( _consumeNum_one )
    _bg._consumeNum_one = _consumeNum_one
    -- 按钮
    local _btn_one = zc.createCommomBtn({
		tag = 2,
		text = zc.lang("strength") .. "1" .. zc.lang("ci"),
        pos = cc.p( _bottomBgWidth - 124, 35 ),
        endCallback = function()
            zc.sendHttp({
                apiName = "Equipment_strengthen",
                params = {
                    equipmentId=self._equipData.id,
                    type=1,
                },
                successCallback = function( result )
                    self:strengthenResult( result, 1 )
                end
            })
    	end
	})
	_bottomBg:addChild( _btn_one )
    self._btn_one = _btn_one
    -- 按钮
    local _btn_five = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("strength") .. "5" .. zc.lang("ci"),
        pos = cc.p( 124, 35 ),
        endCallback = function()
            zc.sendHttp({
                apiName = "Equipment_strengthen",
                params = {
                    equipmentId=self._equipData.id,
                    type=2,
                },
                successCallback = function( result )
                    self:strengthenResult( result, 2 )
                end
            })
    	end
	})
	_bottomBg:addChild( _btn_five )
    self._btn_five = _btn_five

    -- 底
    local _tipBgWidth = 340
    local _tipBgHeight = 33
    local _tipBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
    _tipBg:setContentSize( _tipBgWidth, _tipBgHeight )
    _tipBg:setPosition( _bottomBgWidth/2, 45 )
    _bottomBg:addChild( _tipBg )
    _bg._tipBg = _tipBg
    local _tipSp = zc.getSprite({
        src = "home_icon_info.png",
        plist = true,
        pos = cc.p( 15, _tipBgHeight/2 ),
        scale = 0.5,
    })
    _tipBg:addChild( _tipSp )
    _bg._tipSp = _tipSp
    local _tipLabel = zc.createRichLabel({
        fontSize = 22,
        pos = cc.p( 60, _tipBg:getContentSize().height/2 ),
    })
    _tipLabel:enableStroke(display.COLOR_BLACK, 0.2)
    _tipBg:addChild( _tipLabel )
    _tipLabel:setAnchorPoint( 0, 0.5 )
    _bg._tipLabel = _tipLabel
end
-- 刷新强化弹窗
function RoleEquipPop:refreshStrengthenLayer()
	local _bg = self._strengthenLayer
	if not _bg then
		return
	end

    local _data = self._equipData
    local _static = self._equipStaticData
    local _level = tonumber( _data.strengthenLevel ) or 0

    zc.updateIconByData(_bg._equip, {
        data = {
            mainType=zc.mainTypeEquip,
            type=_data.equipmentId,
            id=_data.equipmentId,
            level=zc.getLevelTipShow().._data.strengthenLevel,
        },
        showLevel = true,
    })
    do
        local _index = 1
        _bg._attrLabel[1][_index]._attrText:setString(zc.lang("level") .. ":" )
        _bg._attrLabel[1][_index]._attrText:setVisible( true )
        _bg._attrLabel[1][_index]._attrNum:setString( _level )
        _bg._attrLabel[1][_index]._attrNum:setVisible( true )

        _bg._attrLabel[2][_index]._attrText:setString( zc.lang("level") .. ":" )
        _bg._attrLabel[2][_index]._attrText:setVisible( true )
        _bg._attrLabel[2][_index]._attrNum:setString( _level + 1 )
        _bg._attrLabel[2][_index]._attrNum:setVisible( true )
        _bg._attrLabel[2][_index]._attrAddNum:setString( "+1" )
        _bg._attrLabel[2][_index]._attrAddNum:setVisible( true )
        _bg._attrLabel[2][_index]._arrow:setVisible( true )
    end
    for i = 1, 2 do
        local _index = i + 1
        local _effectId = tonumber( _data["effectId"..i] ) or 0
        local _effectValue = tonumber( _static["value"..i] ) or 0
        if _effectId ~= 0 and _effectValue ~= 0 then
            local _name = zc.getEquipAttriNameByEffectType( _effectId, true )

            local _value = tonumber( _static["effectValue"..i] ) or 0

            local _curValue = zc.getAttributeNumById( _effectId, _effectValue + _value*_level )
            local _nxtValue = zc.getAttributeNumById( _effectId, _effectValue + _value*( _level + 1 ) )
            
            _bg._attrLabel[1][_index]._attrText:setString( _name )
            _bg._attrLabel[1][_index]._attrText:setVisible( true )
            _bg._attrLabel[1][_index]._attrNum:setString( _curValue )
            _bg._attrLabel[1][_index]._attrNum:setVisible( true )

            _bg._attrLabel[2][_index]._attrText:setString( _name )
            _bg._attrLabel[2][_index]._attrText:setVisible( true )
            _bg._attrLabel[2][_index]._attrNum:setString( _nxtValue )
            _bg._attrLabel[2][_index]._attrNum:setVisible( true )
            _bg._attrLabel[2][_index]._attrAddNum:setString( "+".._value  )
            _bg._attrLabel[2][_index]._attrAddNum:setVisible( true )
            _bg._attrLabel[2][_index]._arrow:setVisible( true )
        else
            _bg._attrLabel[1][_index]._attrText:setVisible( false )
            _bg._attrLabel[1][_index]._attrNum:setVisible( false )
            _bg._attrLabel[2][_index]._attrText:setVisible( false )
            _bg._attrLabel[2][_index]._attrNum:setVisible( false )
            _bg._attrLabel[2][_index]._arrow:setVisible( false )
        end
    end
    self:refreshStrengthenConsume()
end
function RoleEquipPop:refreshStrengthenConsume()
    local _bg = self._strengthenLayer
    if not _bg then
        return
    end
    local _data = self._equipData
    -- dump(_data,"_data")
    local _level = tonumber( _data.strengthenLevel ) or 0
    _level = _level + 1
    local _advance = tonumber( _data.advanceLevel ) or 0
    local _consumeData = gameData.getDataFromCacheWithPrimaryKey( "equip_strengthen", _level )
    -- dump(_consumeData,"_consumeData")
    local _needAdvance = tonumber( _consumeData.needQuality ) or 0
    if _advance < _needAdvance then
        -- 需要进阶
        _bg._tipLabel:setString( "[color=ff746548]" .. zc.lang("advance_to") .. "[color=ffff3644]".. LANGUAGE_get_advance_color_text( _needAdvance ).. zc.lang("quality") .. "[/color]" .. zc.lang("can_goon_strength") .. "[/color]" )
        _bg._tipBg:setVisible( true )
        _bg._consumeSp_one:setVisible( false )
        self._btn_one:setVisible( false )
        self._btn_five:setVisible( false )
    else
        -- 可以强化
        _bg._tipBg:setVisible( false )
        _bg._consumeSp_one:setVisible( true )
        self._btn_one:setVisible( true )
        self._btn_five:setVisible( true )
        local _myMoney = zc.getNumByTypeId( 1, 2 )
        local _needMoney = tonumber( _consumeData.needMoney1 ) or 0
        _bg._consumeNum_one:setText( _needMoney )
        if _myMoney >= _needMoney then
            _bg._consumeNum_one:setColor( display.COLOR_WHITE )
        else
            _bg._consumeNum_one:setColor( zc.COLOR_RED )
        end
        _bg._consumeSp_one:setPositionX( self._btn_one:getPositionX() - ( _bg._consumeSp_one:getContentSize().width + _bg._consumeNum_one:getContentSize().width )/2 )
    end
end
-- 创建进阶弹窗
function RoleEquipPop:initAdvanceLayer()
	if self._advanceLayer then
		return
	end
    -- 下层背景
    local _bgWidth = 496
    local _bgHeight = 575 + 31
    local _bg = zc.createNormalPop({
        width = _bgWidth,
        height = _bgHeight,
        showSide = false,
    })
    _bg:setPosition( self._width/2 + 210, self._height/2 - 30 )
    self:addContent( _bg )
    self._advanceLayer = _bg

    local _equipPosY = _bgHeight - 130

	-- icon
    _bg._equipBg = {}
    _bg._equipIconBg = {}
    _bg._equip = {}
    _bg._equipAdvanceBg = {}
    _bg._equipAdvance = {}
    for i = 1, 2 do
        local _equipPosX = _bgWidth/2 + 113*( 2*i - 3 )
        -- 花
        local _equipBg = cc.Sprite:create( "res/Main/common/popBg/bgFlower.png" )
        _equipBg:setPosition( _equipPosX, _equipPosY + 10 )
        _equipBg:setScale( 0.9 )
        _bg:addChild( _equipBg )
        _bg._equipBg[i] = _equipBg
        -- iconBg
        local _equipIconBg = cc.Sprite:create( "res/Main/common/popBg/di_2.png" )
        _equipIconBg:setPosition( _equipPosX, _equipPosY + 10 )
        _equipIconBg:setScale( 1.2 )
        _bg:addChild( _equipIconBg )
        _bg._equipIconBg[i] = _equipIconBg
        -- icon
        local _equip = zc.createIconByData({
            data = {
                mainType = zc.mainTypeEquip,
                type = 1,
                id = 1,
                quality = 1,
            },
            pos = cc.p( _equipPosX, _equipPosY + 13 ), 
        })
        _equip:setScale( 0.8 )
        _bg:addChild( _equip )
        _bg._equip[i] = _equip
        -- equipAdvanceBg
        local _equipAdvanceBgWidth = 100
        local _equipAdvanceBgHeight = 32
        local _equipAdvanceBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
        _equipAdvanceBg:setContentSize( _equipAdvanceBgWidth, _equipAdvanceBgHeight )
        _equipAdvanceBg:setPosition( _equipPosX, _equipPosY - 60 )
        _bg:addChild( _equipAdvanceBg )
        _bg._equipAdvanceBg[i] = _equipAdvanceBg
        -- equipAdvance
        local _equipAdvance = zc.createLabel({
            fontSize = 20,
            pos = cc.p( _equipAdvanceBgWidth/2, _equipAdvanceBgHeight/2 ),
            outLine = true,
        })
        _equipAdvanceBg:addChild( _equipAdvance )
        _bg._equipAdvance[i] = _equipAdvance
    end
    -- 箭头
    local _arrow = cc.Sprite:create( "res/Main/role/equip/arrow_2.png" )
    _arrow:setPosition( _bgWidth/2, _equipPosY )
    _bg:addChild( _arrow )
    _bg._arrow = _arrow

    -- 属性背景
    local _bottomBgWidth = _bgWidth - 26
    local _bottomBgHeight = 311
    local _bottomBg = zc.createGeneralPopScale({
        tag = 3,
        width = _bottomBgWidth,
        height = _bottomBgHeight,
    })
    _bottomBg:setAnchorPoint( 0.5, 0 )
    _bottomBg:setPosition( _bgWidth/2, 85 )
    _bg:addChild( _bottomBg )

    local _attrLineHeight = 25
    -- 属性背景
    _bg._attrLabel = {}

    local _title = {
        zc.lang("curr_property"), zc.lang("next_level_property1"),
    }
    _bg._attrBg = {}
    for i = 1, 2 do
        local _attrBgWidth = ( _bottomBgWidth - 36 )/2
        local _attrBgHeight = 110
        local _attrBg = zc.createGeneralPopScale({
            tag = 2,
            width = _attrBgWidth,
            height = _attrBgHeight,
        })
        _attrBg:setAnchorPoint( 2 - i, 1 )
        _attrBg:setPosition( _bottomBgWidth/2 + 6*( 2*i - 3 ), _bottomBgHeight - 10 )
        _bottomBg:addChild( _attrBg )
        _bg._attrBg[i] = _attrBg

        -- 属性标题背景
        local _attrTitle = zc.createLabel({
            text = _title[i],
            fontSize = 20,
            color = cc.c3b(53, 39, 18),
            pos = cc.p( _attrBgWidth/2, _attrBgHeight - 30 ),
        })
        _attrBg:addChild( _attrTitle )
        local _attrTitleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleLeft:setAnchorPoint( 1, 0.5 )
        _attrTitleLeft:setPosition( _attrTitle:getPositionX() - _attrTitle:getContentSize().width/2, _attrTitle:getPositionY() )
        _attrBg:addChild( _attrTitleLeft )
        local _attrTitleRight = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleRight:setAnchorPoint( 0, 0.5 )
        _attrTitleRight:setPosition( _attrTitle:getPositionX() + _attrTitle:getContentSize().width/2, _attrTitle:getPositionY() )
        _attrTitleRight:setFlippedX( true )
        _attrBg:addChild( _attrTitleRight )
        -- 属性
        _bg._attrLabel[i] = {}
        for j = 1, 3 do
            if i == 1 then
                -- 属性
                local _attrText = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 20, _attrBgHeight - 30 - j*_attrLineHeight ),
                    outLine = true,
                    color = cc.c3b(230,224,163),
                })
                _attrText:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrText )
                local _attrNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 120, _attrText:getPositionY() ),
                    outLine = true,
                })
                _attrNum:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrNum )
                _bg._attrLabel[i][j] = {
                    _attrText = _attrText,
                    _attrNum = _attrNum,
                }
            elseif i == 2 then
                -- 属性名
                local _attrText = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 20, _attrBgHeight - 30 - j*_attrLineHeight ),
                    outLine = true,
                    color = cc.c3b(230,224,163),
                })
                _attrText:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrText )
                -- 属性值
                local _attrNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( 80, _attrText:getPositionY() ),
                    outLine = true,
                })
                _attrNum:setAnchorPoint( 0, 0.5 )
                _attrBg:addChild( _attrNum )
                -- 增加数字
                local _attrAddNum = zc.createLabel({
                    fontSize = 18,
                    ttf = zc.getFont( 1 ),
                    pos = cc.p( _attrBgWidth - 30, _attrText:getPositionY() ),
                    outLine = true,
                    color = cc.c3b(42,255,0),
                })
                _attrAddNum:setAnchorPoint( 1, 0.5 )
                _attrBg:addChild( _attrAddNum )
                -- 箭头
                local _arrow = cc.Sprite:create( "res/Main/common/arrow_green.png" )
                _arrow:setPosition( _attrBgWidth - 15, _attrText:getPositionY() )
                _arrow:setRotation( -90 )
                _attrBg:addChild( _arrow )

                _bg._attrLabel[i][j] = {
                    _attrText = _attrText,
                    _attrNum = _attrNum,
                    _attrAddNum = _attrAddNum,
                    _arrow = _arrow,
                }
            end
        end
    end

    -- 消耗材料
    local _consumeBgWidth = _bottomBgWidth - 18
    local _consumeBgHeight = 170
	local _consumeBg = zc.createGeneralPopScale({
        tag = 2,
        width = _consumeBgWidth,
        height = _consumeBgHeight,
    })
	_consumeBg:setAnchorPoint( 0.5, 0 )
	_consumeBg:setPosition( _bottomBgWidth/2, 10 )
	_bottomBg:addChild( _consumeBg )
	-- 消耗材料
    _bg._consumeIcon = {}
    local _iconWidth = 86
    for i = 1, 8 do
        local _icon = zc.createIconByData({
            data = {
                mainType=1,
                type=1,
                id=1,
            },
        })
        local _posX = ( _consumeBgWidth - _iconWidth*4 )/2 + _iconWidth/2*( 2*( ( i - 1 )%4 ) + 1 )
        local _posY = 205 - 80*( math.ceil( i/4 ) )
        _icon:setPosition( _posX, _posY )
        _icon:setScale( 0.65 )
        _consumeBg:addChild( _icon )
        _bg._consumeIcon[i] = _icon
    end
    local _advanceMax = zc.createLabel({
        text = zc.lang("achieve_to_max_level"),
        fontSize = 22,
        color = zc.COLOR_RED,
        pos = cc.p( _consumeBgWidth/2, _consumeBgHeight/2 ),
        outLine = true,
    })
    _consumeBg:addChild( _advanceMax )
    _bg._advanceMax = _advanceMax

    -- 按钮
    local _btn = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("advanced"),
        pos = cc.p( _bottomBgWidth/2, 45 ),
        endCallback = function()
            zc.sendHttp({
                apiName = "Equipment_advanced",
                params = {
                    equipmentId=self._equipData.id,
                },
                successCallback = function( result )
                    self:advanceResult( result )
                end
            })
    	end
	})
	_bg:addChild( _btn )
	_bg._btn = _btn
    self._advanceDoBtn = _btn
end
-- 刷新进阶弹窗
function RoleEquipPop:refreshAdvanceLayer()
	local _bg = self._advanceLayer
	if not _bg then
		return
	end

    local _data = self._equipData
    local _static = self._equipStaticData
    local _advance = tonumber( _data.advanceLevel ) or 0
    local _level = tonumber( _data.strengthenLevel ) or 0
    local _advanceStaticData = gameData.getDataFromCacheWithPrimaryKey("equip_advanced", self._equipData.equipmentId)
    if next(_advanceStaticData) then
        -- 可以继续进阶
        local _nxtAdvanceId = tonumber( _advanceStaticData.newId ) or 1
        local _nxtStatic = gameData.getDataFromCacheWithPrimaryKey("equip", _nxtAdvanceId)

        local _id = {
            _data.equipmentId, _nxtAdvanceId
        }
        local _curName = ""
        for i = 1, 2 do
            local _info = zc.updateIconByData(_bg._equip[i], {
                data = {
                    mainType=zc.mainTypeEquip,
                    type=_id[i],
                    id=_id[i],
                    level=zc.getLevelTipShow().._data.strengthenLevel,
                },
                showLevel = true,
            })
            _bg._equipAdvance[i]:setText( _info.name )
            local _color = zc.getColorByQuality( _info.star )
            _bg._equipAdvance[i]:setColor( _color )
            if i == 1 then
                _curName = _info.name
            end
        end

        for i = 1, 3 do
            local _index = i
            local _effectId = tonumber( _data["effectId"..i] ) or 0
            local _effectValue = tonumber( _static["value"..i] ) or 0
            if _effectId ~= 0 and _effectValue ~= 0 then
                -- 当前属性
                local _name = zc.getEquipAttriNameByEffectType( _effectId, true )
                local _value = tonumber( _static["effectValue"..i] ) or 0
                local _curValue = zc.getAttributeNumById( _effectId, _effectValue + _value*_level )

                _effectValue = tonumber( _nxtStatic["value"..i] ) or 0
                _value = tonumber( _nxtStatic["effectValue"..i] ) or 0
                local _nxtValue = zc.getAttributeNumById( _effectId, _effectValue + _value*_level )

                _bg._attrLabel[1][_index]._attrText:setString( _name )
                _bg._attrLabel[1][_index]._attrText:setVisible( true )
                _bg._attrLabel[1][_index]._attrNum:setString( _curValue )
                _bg._attrLabel[1][_index]._attrNum:setVisible( true )

                _bg._attrLabel[2][_index]._attrText:setString( _name )
                _bg._attrLabel[2][_index]._attrText:setVisible( true )
                _bg._attrLabel[2][_index]._attrNum:setString( _nxtValue )
                _bg._attrLabel[2][_index]._attrNum:setVisible( true )
                _bg._attrLabel[2][_index]._attrAddNum:setString( "+"..( _nxtValue - _curValue ) )
                _bg._attrLabel[2][_index]._attrAddNum:setVisible( true )
                _bg._attrLabel[2][_index]._arrow:setVisible( true )
            else
                _bg._attrLabel[1][_index]._attrText:setVisible( false )
                _bg._attrLabel[1][_index]._attrNum:setVisible( false )
                _bg._attrLabel[2][_index]._attrText:setVisible( false )
                _bg._attrLabel[2][_index]._attrNum:setVisible( false )
                _bg._attrLabel[2][_index]._arrow:setVisible( false )
            end
        end

        self:refreshAdvanceConsume()
        _bg._btn:setEnable( true )
        _bg._advanceMax:setVisible( false )
    else
        local _bgWidth = _bg:getContentSize().width
        -- 进阶至最高
        _bg._equipBg[1]:setPositionX( _bgWidth/2 )
        _bg._equipIconBg[1]:setPositionX( _bgWidth/2 )
        _bg._equip[1]:setPositionX( _bgWidth/2 )
        _bg._equipAdvanceBg[1]:setPositionX( _bgWidth/2 )
        local _info = zc.updateIconByData(_bg._equip[1], {
            data = {
                mainType=zc.mainTypeEquip,
                type=_data.equipmentId,
                id=_data.equipmentId,
                level=zc.getLevelTipShow().._data.strengthenLevel,
            },
            showLevel = true,
        })
        _bg._equipAdvance[1]:setText( _info.name )
        local _color = zc.getColorByQuality( _info.star )
        _bg._equipAdvance[1]:setColor( _color )

        _bg._equipBg[2]:setVisible( false )
        _bg._equipIconBg[2]:setVisible( false )
        _bg._equip[2]:setVisible( false )
        _bg._equipAdvanceBg[2]:setVisible( false )

        _bg._arrow:setVisible( false )

        _bg._attrBg[1]:setAnchorPoint( 0.5, 1 )
        _bg._attrBg[1]:setPositionX( ( _bgWidth - 26 )/2 )
        for i = 1, 3 do
            local _index = i
            local _effectId = tonumber( _data["effectId"..i] ) or 0
            local _effectValue = tonumber( _data["effectValue"..i] ) or 0
            if _effectId ~= 0 and _effectValue ~= 0 then
                -- 当前属性
                local _name = zc.getEquipAttriNameByEffectType( _effectId, true )
                local _value = tonumber( _static["effectValue"..i] ) or 0
                local _curValue = zc.getAttributeNumById( _effectId, _effectValue + _value*_level )

                _bg._attrLabel[1][_index]._attrText:setString( _name )
                _bg._attrLabel[1][_index]._attrText:setVisible( true )
                _bg._attrLabel[1][_index]._attrNum:setString( _curValue )
                _bg._attrLabel[1][_index]._attrNum:setVisible( true )
            else
                _bg._attrLabel[1][_index]._attrText:setVisible( false )
                _bg._attrLabel[1][_index]._attrNum:setVisible( false )
            end
        end
        _bg._attrBg[2]:setVisible( false )

        self:refreshAdvanceConsume()
        _bg._btn:setEnable( false )
        _bg._advanceMax:setVisible( true )
    end
end
-- 刷新进阶消耗
function RoleEquipPop:refreshAdvanceConsume()
    local _bg = self._advanceLayer
    if not _bg then
        return
    end
    local _advanceStaticData = gameData.getDataFromCacheWithPrimaryKey("equip_advanced", self._equipData.equipmentId)
    local _num = 0
    local _test = ""
    for i = 1, 8 do
        local _icon = _bg._consumeIcon[i]
        _icon:setVisible( false )
        local _stuff = _advanceStaticData["stuff"..i]
        if _stuff then
            _stuff = tostring( _stuff )
            if _stuff ~= "" then
                local _stuffs = string.split( _stuff, "|" )
                if #_stuffs == 3 then
                    -- dump(_stuffs,"_stuffs")
                    _test = _test.._stuff.."00,"
                    zc.updateIconByData(_icon, {
                        data = {
                            mainType=_stuffs[1],
                            type=_stuffs[2],
                            id=_stuffs[2],
                        },
                        attrLabel = {
                            now=zc.getNumByTypeId( _stuffs[1], _stuffs[2] ),
                            need=_stuffs[3],
                        },
                        listener = function()
                            zc.createItemSynthesisPop({
                                itemType=_stuffs[1],
                                itemId=_stuffs[2],
                                costNum=_stuffs[3],
                            })
                        end
                    })
                    _icon:setVisible( true )
                    _num = _num + 1
                end
            end
        end
    end
    print("~~~~~~~~~_test=",_test)
    if _num <= 4 then
        -- 一排
        for i = 1, 8 do
            local _icon = _bg._consumeIcon[i]
            _icon:setPositionY( 85 )
        end
    else
        for i = 1, 8 do
            local _icon = _bg._consumeIcon[i]
            _icon:setPositionY( 205 - 80*( math.ceil( i/4 ) ) )
        end
    end
end

function RoleEquipPop:onEnter()
    performWithDelay(self, function()
        getGuideManager():removeMaskLayer()
        self:addGuide()
    end, 0.3)
end

function RoleEquipPop:showLevelUp( addLevel, bobLevel )
    if not self._strengthenLayer then
        return
    end
    local _level = 0
    for k, v in pairs( addLevel ) do
        _level = _level + tonumber( v )
    end
    if _level <= 0 then
        return
    end
    -- 暴击等级
    local _flag = tonumber( bobLevel ) or 0

    local _levelUp = cc.Sprite:create()
    local _width = 192
    local _height = 48
    if _flag ~= 0 then
        -- 有暴击
        _height = 96
        local _sp_1 = cc.Sprite:create( "res/Main/role/equip/sp_1.png" )
        _sp_1:setAnchorPoint( 0, 1 )
        _sp_1:setPosition( 0, _height )
        _levelUp:addChild( _sp_1 )
    end
    _levelUp:setContentSize( _width, _height )
    
    local _sp_2 = cc.Sprite:create( "res/Main/role/equip/sp_2.png" )
    _sp_2:setAnchorPoint( 0, 0 )
    _sp_2:setPosition( 0, 0 )
    _levelUp:addChild( _sp_2 )
    local _num = zc.createFntLabel({
        fnt = "res/image/battle/font/YellowBlood.fnt",
        text = _level,
        pos = cc.p( 118, 30 ),
        addwidth = -6,
    })
    _levelUp:addChild( _num )
    local _sp_3 = cc.Sprite:create( "res/Main/role/equip/sp_3.png" )
    _sp_3:setAnchorPoint( 1, 0 )
    _sp_3:setPosition( _width, 0 )
    _levelUp:addChild( _sp_3 )

    local _pos = cc.p( self._strengthenLayer._equip:getPosition() )
    _levelUp:setPosition( _pos )
    self._strengthenLayer:addChild( _levelUp, 6 )
    _levelUp:setCascadeOpacityEnabled( true )
    _levelUp:runAction(
        cc.Sequence:create(
            cc.Spawn:create(
                cc.MoveBy:create( 1, cc.p( 0, 110 ) ),
                cc.FadeTo:create( 1, 0 )
            ),
            cc.RemoveSelf:create()
        )
    )
    musicManager.playEffect( zc.effect.equipStrengthenCrit )
end
-- 装备强化结果
function RoleEquipPop:strengthenResult( result, index )
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_5025 
      or _currentGID == GuideKey.KEY_5029 then
        zc.setGuideFuncNextStep(_currentGID)
        getGuideManager():addMaskLayer()
    end

    self._leftLayer._swallow:setEnable( true )
    
    PlayerData:updateGeneralInfo( result.heroInfo )
    PlayerData:updataData( result )
    PlayerData:updateEquip( result.equipments )
    -- 刷新装备红点
    zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
    self._equipData = result.equipments
    musicManager.playEffect( zc.effect.equipStrengthen )

    local _bg = self._strengthenLayer

    local _spine = zc.createSpine({
        fileName = "qianghua_jinjie",
        actName = "animation2",
        loop = false,
        needInit = false,
        autoRemove = true,
        removeCallback = function()
            getGuideManager():removeMaskLayer()
            self:showLevelUp( result.addLevel, result.bobLevel )
            self:refreshLeftLayer()
            self:refreshStrengthenLayer()
            self:refreshAdvanceRedDot()
            self:addGuide()
            self._leftLayer._swallow:setEnable( false )
        end
    })
    _spine:setScale( 3 )

    local _pos = cc.p( _bg._equip:getPosition() )
    _spine:setPosition( _pos )
    self._strengthenLayer:addChild( _spine, 6 )
end
-- 装备进阶结果
function RoleEquipPop:advanceResult( result )
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_5035 then
        zc.setGuideFuncNextStep(_currentGID)
        getGuideManager():addMaskLayer()
    end

    self._leftLayer._swallow:setEnable( true )

    PlayerData:updateGeneralInfo( result.heroInfo )
    PlayerData:updataData( result )
    PlayerData:updateEquip( result.equipments )
    zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
    self._equipData = result.equipments
    musicManager.playEffect( zc.effect.equipAdvance )

    local _bg = self._advanceLayer
    
    -- 飞
    local _beginPoss = {}
    for i, v in ipairs( _bg._consumeIcon  ) do
        if v:isVisible() then
            local _pos = v:convertToWorldSpaceAR( cc.p( 0, 0 ) )
            _beginPoss[#_beginPoss + 1] = _bg:convertToNodeSpace( _pos )
        end
    end
    local _endPos = cc.p( _bg._equip[1]:getPosition() )

    for i, _beginPos in ipairs( _beginPoss ) do
        local _particle = cc.ParticleSystemQuad:create("res/Main/role/equip/jinjie/jinjie.plist")
        _particle:setPosition( _beginPos )
        _particle:setAutoRemoveOnFinish( true )

        _bg:addChild( _particle, 6 )
        
        if i == #_beginPoss then
            -- 最后一个
            _particle:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( i*0.15 ),
                    cc.MoveTo:create( 1, _endPos ),
                    cc.RemoveSelf:create(),
                    cc.CallFunc:create(
                        function()
                            local __spine = zc.createSpine({
                                fileName = "qianghua_jinjie",
                                actName = "animation2",
                                loop = false,
                                needInit = false,
                                autoRemove = true,
                                removeCallback = function()
                                    getGuideManager():removeMaskLayer()
                                    self:refreshLeftLayer()
                                    self:refreshGemIcon( self._equipData )
                                    self:refreshAdvanceLayer()
                                    self:refreshAdvanceRedDot()
                                    self:addGuide()
                                    self._leftLayer._swallow:setEnable( false )
                                end
                            })
                            __spine:setScale( 3 )
                            __spine:setPosition( _endPos )
                            _bg:addChild( __spine, 6 )
                        end
                    )
                )
            )
        else
            _particle:runAction(
                cc.Sequence:create(
                    cc.DelayTime:create( i*0.15 ),
                    cc.MoveTo:create( 1, _endPos ),
                    cc.RemoveSelf:create()
                )
            )
        end
    end
end

-- 刷新装备进阶红点
function RoleEquipPop:refreshAdvanceRedDot()
    local _flag = zc.getEquipAdvanceStatus( self._equipData )
    self._leftLayer._advanceBtn._redPoint:setVisible( _flag )
end

function RoleEquipPop:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_5025 then
        local _strengthenLevel = tonumber(self._equipData.strengthenLevel) or 0
        if _strengthenLevel >= 2 then
            getGuideManager():setCurrentGID(GuideKey.KEY_5029)
            self:addGuide()
        else
            getGuideManager():setObjTarget(self._btn_one)
            getGuideManager():startGuide()
        end
    elseif _currentGID == GuideKey.KEY_5029 then
        local _strengthenLevel = tonumber(self._equipData.strengthenLevel) or 0
        if _strengthenLevel >= 5 then
            getGuideManager():setCurrentGID(GuideKey.KEY_5033)
            self:addGuide()
        else
            getGuideManager():setObjTarget(self._btn_five)
            getGuideManager():startGuide()
        end
    elseif _currentGID == GuideKey.KEY_5033 then
        local function _callBack()
            self:addGuide()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_5034 then
        local _advanceLevel = tonumber(self._equipData.advanceLevel) or 0
        if _advanceLevel >= 1 then
            getGuideManager():setCurrentGID(GuideKey.KEY_5036)
            self:addGuide()
        else
            getGuideManager():setObjTarget(self._advanceBtn)
            getGuideManager():startGuide()
        end
    elseif _currentGID == GuideKey.KEY_5035 then
        if tonumber(self._equipData.advanceLevel) ~= 0 then
            zc.setGuideFuncNextStep(_currentGID)
            self:addGuide()
            return
        end
        getGuideManager():setObjTarget(self._advanceDoBtn)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_5036 then
        local _sprite = zc.createSprite()
        _sprite:setContentSize(100, 100)
        local _btn = zc.createPushButton({
            normalNode = _sprite,
            needSwallow = false,
            ap = cc.p(1, 1),
            touchSize = cc.size(100, 100),
            pos = cc.p(zc.width - 50, zc.height - 50),
            endCallback = function()
                local _currentGID = getGuideManager():getCurrentGID()
                zc.setGuideFuncNextStep(_currentGID)
                zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLE_REFRESHEQUIP})
            end
        })
        self:addChild(_btn, 100)
        getGuideManager():setObjTarget(_btn)
        getGuideManager():startGuide()
    end
end

function RoleEquipPop:createGemIcon( ctn, width )
    self._gemIcon = {}
    local _unlockText = {
        LANGUAGE_get_advance_color_text(1),
        LANGUAGE_get_advance_color_text(2),
        LANGUAGE_get_advance_color_text(4),
        LANGUAGE_get_advance_color_text(5),
    }
    local _side = 10
    local _dif = ( width - _side*2 )/4
    for i = 1, 4 do
        local _iconBgWidth = 70
        local _iconBgHeight = 70
        local _iconBg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
        _iconBg:setContentSize( _iconBgWidth, _iconBgHeight )
        _iconBg:setPosition( _dif*( i - 0.5 ) + _side, 0 )
        ctn:addChild( _iconBg )
        local _posX = _iconBgWidth/2
        local _posY = _iconBgHeight/2
        -- icon
        local _icon = zc.createIconByData({
            data = {
                mainType=zc.mainTypeGem,
                type=1,
                id=1,
            },
            pos = cc.p( _posX, _posY ),
        })
        _icon:setScale( 0.53 )
        _iconBg:addChild( _icon )
        _iconBg._icon = _icon
        -- 背景
        local _iconBtm = cc.Sprite:create( "res/Main/hero/hero_item1.png" )
        _iconBtm:setPosition( _posX, _posY )
        _iconBtm:setScale( 0.53 )
        _iconBg:addChild( _iconBtm )
        _iconBg._iconBtm = _iconBtm
        -- 锁
        local _lock = cc.Sprite:create( "res/Main/drillField/drillField_head_sock.png" )
        _lock:setPosition( _posX, _posY )
        _lock:setScale( 0.53 )
        _iconBg:addChild( _lock )
        _iconBg._lock = _lock
        -- 锁文字
        local _lockLabel = zc.createLabel({
            text = _unlockText[i],
            fontSize = 16,
            ttf = zc.getFont(1),
            pos = cc.p( _posX, _posY - 20),
            outLine = true,
        })
        _iconBg:addChild( _lockLabel )
        _iconBg._lockLabel = _lockLabel

        self._gemIcon[i] = _iconBg
    end
end

function RoleEquipPop:refreshGemIcon( equipData )
    for i, _iconBg in ipairs( self._gemIcon ) do
        local _key = "gemId"..i
        local _id = tonumber( equipData[_key] ) or 0
        local _gemData = PlayerData:getGemInfoById( _id )
        if _gemData then
            -- 有宝石
            _iconBg._icon:setVisible( true )
            zc.updateIconByData(_iconBg._icon, {
                data = {
                    mainType=zc.mainTypeGem,
                    type=_gemData.gemId,
                    id=_gemData.gemId,
                    level=zc.getLevelTipShow().._gemData.level,
                },
                showLevel = true,
            })
            _iconBg._iconBtm:setVisible( false )
            _iconBg._lock:setVisible( false )
            _iconBg._lockLabel:setVisible( false )
        else
            local _quality = gameData.getDataFromCacheWithPrimaryKey("equip", equipData.equipmentId).quality or 0
            if zc.getGemPosStatus( _quality, i ) then
                -- 已解锁
                _iconBg._icon:setVisible( false )
                _iconBg._iconBtm:setVisible( true )
                _iconBg._lock:setVisible( false )
                _iconBg._lockLabel:setVisible( false )
                local can_inlay = zc.createSprite("res/Main/role/gem/can_inlay.png")
                can_inlay:setScale(0.8)
                can_inlay:setPosition(_iconBg:getContentSize().width/2, _iconBg:getContentSize().width/2-2)
                _iconBg:addChild(can_inlay)
                can_inlay:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeOut:create(1.2),cc.FadeIn:create(1.2))))
            else
                -- 未解锁
                _iconBg._icon:setVisible( false )
                _iconBg._iconBtm:setVisible( true )
                _iconBg._lock:setVisible( true )
                _iconBg._lockLabel:setVisible( true )
            end
        end
    end
end

return RoleEquipPop