--[[
FileName        RoleFetterLayer.lua
ProjectName     HJ2
Created by wangming on 16-10-20 地域羁绊弹窗
]]
local RoleFettersRegionalPop = class("RoleFettersRegionalPop", function()
    return ZCPopLayer:create()
end)

function RoleFettersRegionalPop:create( params )
    return RoleFettersRegionalPop.new(params)
end

function RoleFettersRegionalPop:ctor( params )
	self._region = params.region
	self._callback = params.callback
	self._nowIdx = 1

	self:initDatas()
	self:initUI()
	self:freshCountNum()
    self:show()
end

function RoleFettersRegionalPop:onCleanup()
	if self._callback then
		self._callback()
	end
end

function RoleFettersRegionalPop:initDatas()
	self._regionalDbInfo = PlayerData:getOneFetterRegionalInfosByRegionId(self._region)
	self._haveCount = 0
	for k,v in pairs(self._regionalDbInfo) do
		local _status = tonumber(v.status) or 0
		if _status == 1 then
			self._haveCount = self._haveCount + 1
		end
	end

	table.sort(self._regionalDbInfo, function( a, b )
		if not a or not b then
			return false
		end
		local _awardA = tonumber(a.award) or 0
		local _awardB = tonumber(b.award) or 0
		if _awardA ~= _awardB then
			if _awardA == 0 then
				return false
			elseif _awardB == 0 then
				return true
			elseif _awardA == 1 then
				return true
			elseif _awardB == 1 then
				return false
			end
		end
		local _statusA = tonumber(a.status) or 0
		local _statusB = tonumber(b.status) or 0
		if _statusA ~= _statusB then
			return _statusA == 1
		end
		local _fettersIdA = tonumber(a.rank) or 0
		local _fettersIdB = tonumber(b.rank) or 0
		return _fettersIdA < _fettersIdB
	end)
end

function RoleFettersRegionalPop:initUI()
	local _bg = zc.createNormalPop({
        tag = 1,
        titleSrc = "res/Main/common/tipTitle/jiban.png",
        width = 440,
        height = 525,
        bianZOrder = 1
    })
    _bg:setPosition(zc.width*0.5, zc.height*0.5)
    self:addContent(_bg)
    self.bg = _bg
	local _bgSize = _bg:getContentSize()

	--top
    local _countDiSize = cc.size(130, 33)
    local _countDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _countDiSize)
    _countDi:setAnchorPoint(1, 1)
    _countDi:setPosition(_bgSize.width - 25, _bgSize.height - 50)
    _bg:addChild(_countDi)

    local _countTibLab = zc.createLabel({
    	text = zc.lang("collect") .. "：",
    	fontSize = 20,
    	ap = cc.p(0, 0.5),
    	color = cc.c3b(210, 196, 125),
    	pos = cc.p(5, _countDiSize.height*0.5),
	})
	_countDi:addChild(_countTibLab)

    local _countNumLab = zc.createLabel({
    	text = "0/0",
    	fontSize = 20,
    	ap = cc.p(1, 0.5),
    	pos = cc.p(_countDiSize.width - 5, _countDiSize.height*0.5),
	})
	_countDi:addChild(_countNumLab)
	self._countNumLab = _countNumLab

	--bottom
    local _leftBtn = zc.createCommomBtn({
		tag = 5,
		text = zc.lang("preview_2"),
		fontSize = 28,
		pos = cc.p(_bgSize.width*0.3, 40),
		scale = 0.7,
		endCallback = function()
			local _fetterData = self._regionalDbInfo[self._nowIdx]
			if not _fetterData then
				return
			end
			zc.createSourcePop("RoleFetterAttr", "src/layer/role/RoleFetterAttrPop.lua", {fetterData = _fetterData})
		end,
	})
	_bg:addChild(_leftBtn)
	self._leftBtn = _leftBtn

	local _rightBtn = zc.createCommomBtn({
		tag = 3,
		text = zc.lang("upgrade_2"),
		fontSize = 28,
		scale = 0.7,
		pos = cc.p(_bgSize.width*0.7, _leftBtn:getPositionY()),
		endCallback = function()
			local _fetterData = self._regionalDbInfo[self._nowIdx]
			if not _fetterData then
				return
			end
			local _award = tonumber(_fetterData.award) or 1
			if _award ~= 2 then
				return
			end
			local _upgradData = _fetterData.upgradeInfo or {}
			if next(_upgradData) == nil then
				return
			end
			local _nextLevelInfo = _fetterData.nextLevelInfo or {}
			if next(_nextLevelInfo) == nil then
				zc.tipInfo(zc.lang("max_level"))
				return
			end

			local _middleNode = cc.Node:create()

			local _totleDiSize = cc.size(200, 145)
			local _valueDiSize = cc.size(_totleDiSize.width*0.9, 33)
		    local _leftDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _totleDiSize)
		    _leftDi:setAnchorPoint(1, 0.5)
		    _leftDi:setPosition(-10, -15)
		    _middleNode:addChild(_leftDi)
		    local _leftTip = zc.createLabel({
		    	text = zc.lang("curr_level") .. "：",
		    	fontSize = 24,
		    	ap = cc.p(0, 0),
		    	pos = cc.p(10, _totleDiSize.height + 5),
		    	color = cc.c3b(110, 39, 2)
	    	})
	    	_leftDi:addChild(_leftTip)

	    	local _leftNums = {}
	    	for i=1, 3 do
				local _effId = tonumber(_upgradData["effectId" .. i]) or 0
				if _effId ~= 0 then
	                local _valueDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _valueDiSize)
	                _valueDi:setPosition(_totleDiSize.width*0.5, _totleDiSize.height*0.2 + _totleDiSize.height*0.3*(3-i))
	                _leftDi:addChild(_valueDi)

	                local _typeLab = zc.createRichLabel({
	                	text = LANGUAGE_getAttributeTextById(_effId) .. "：",
	                    fontSize = 18,
	                    anchor = cc.p(0, 0.5),
	                    pos = cc.p(5, _valueDiSize.height*0.5),
	                })
	                _typeLab:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
	                _valueDi:addChild(_typeLab)

		            local _num = tonumber(_upgradData["effectValue" .. i]) or 0
	                _leftNums[i] = _num
	                local _valueLab = zc.createLabel({
	                	text = zc.getAttributeNumById(_effId, _num),
	                    fontSize = 18,
	                    ap = cc.p(1, 0.5),
	                    pos = cc.p(_valueDiSize.width - 5, _valueDiSize.height*0.5),
	                })
	                _valueDi:addChild(_valueLab)
				end
			end

		    local _rightDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _totleDiSize)
		    _rightDi:setAnchorPoint(0, 0.5)
		    _rightDi:setPosition(10, _leftDi:getPositionY())
		    _middleNode:addChild(_rightDi)
		    local _rightTip = zc.createLabel({
		    	text = zc.lang("next_level_deng") .. "：",
		    	fontSize = 24,
		    	ap = cc.p(0, 0),
		    	pos = cc.p(_leftTip:getPosition()),
		    	color = cc.c3b(110, 39, 2)
	    	})
	    	_rightDi:addChild(_rightTip)

			for i=1, 3 do
				local _effId = tonumber(_nextLevelInfo["effectId" .. i]) or 0
				if _effId ~= 0 then
	                local _valueDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _valueDiSize)
	                _valueDi:setPosition(_totleDiSize.width*0.5, _totleDiSize.height*0.2 + _totleDiSize.height*0.3*(3-i))
	                _rightDi:addChild(_valueDi)

	                local _typeLab = zc.createRichLabel({
	                	text = LANGUAGE_getAttributeTextById(_effId) .. "：",
	                    fontSize = 18,
	                    anchor = cc.p(0, 0.5),
	                    pos = cc.p(5, _valueDiSize.height*0.5),
	                })
	                _typeLab:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
	                _valueDi:addChild(_typeLab)

		            local _num = tonumber(_nextLevelInfo["effectValue" .. i]) or 0
	                local _valueLab = zc.createLabel({
	                	text = _num,--"+" .. _num,
	                    fontSize = 18,
	                    ap = cc.p(1, 0.5),
	                    color = display.COLOR_GREEN,
	                    pos = cc.p(_valueDiSize.width - 5, _valueDiSize.height*0.5),
	                })
	                _valueDi:addChild(_valueLab)
				end
			end

	    	local _costInfo = string.split(_upgradData.stuff, "|")
	    	local _costLab = zc.createRichLabel({
	    		text = ("[image=" .. zc.getImgByType(_costInfo[2]) .. " offsety=-10][/image]" .. _costInfo[3]),
	    		anchor = cc.p(0.5, 1),
	    		color = cc.c3b(110, 39, 2),
	    		pos = cc.p(119, -13),
	    		fontSize = 22,
	    	})
	    	_rightDi:addChild(_costLab)

			local comfirm = ZCConfirmDialog:createWithParams({
                contentNode = _middleNode,
                titleSrc = "res/Main/common/tipTitle/shengji.png",
                showDi = true,
                rightCallback = function()
                	zc.sendHttp({
						apiName = "RegionalFetters_levelUp",
						params = {id = _fetterData.id},
						successCallback = function( backData )
				        	PlayerData:updataData(backData)
				        	local _regionFettersInfo = backData.regionFettersInfo or {}
				        	if next(_regionFettersInfo) ~= nil then
					        	PlayerData:updateOneFetterRegionalInfoById(_fetterData.id, _regionFettersInfo)
					        	for k,v in pairs(_regionFettersInfo) do
					        		_fetterData[k] = v
					        	end
					        	self._regionalDbInfo[self._nowIdx] = _fetterData
					        end
				        	self._tableView:reloadDataAndScrollToCurrentCell()
				        	self._tableCellTouched(self._tableView)
				        	zc.tipInfo(zc.lang("upgrade_success") .. "！")
						end
					})
                end
            })
            self:addChild(comfirm, 5)
		end,
	})
	_bg:addChild(_rightBtn)
	self._rightBtn = _rightBtn

	--middle

	local _tableSize = cc.size(408, 330)
	self._tableSize = _tableSize
	local _middleDi = zc.createGeneralPopScale({
        tag = 3,
        width = _tableSize.width,
        height = _tableSize.height,
    })
    _middleDi:setAnchorPoint(0.5, 0)
    _middleDi:setPosition(_bgSize.width*0.5, 75)
    _bg:addChild(_middleDi)

	local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
    _tableView:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    _tableView:setBounceable(true)
    _tableView:setInertia(false)
    _tableView:setAutoAlign(true)
    _tableView:setDelegate()
    _tableView:setPosition(0, 0)
    _middleDi:addChild(_tableView)

    local _cellSize = cc.size(_tableSize.width, 155)
    local _partY = 5

    local function numberOfCellsInTableView( table )
        return #self._regionalDbInfo
    end

    local function cellSizeForTable( table, idx )
    	if idx == 0 or idx == numberOfCellsInTableView(table) - 1 then
			return _cellSize.height + _partY, _cellSize.width
    	end
        return _cellSize.height, _cellSize.width  
    end
    
    local function tableCellAtIndex( table, idx )
        local _cell = table:dequeueCell()
        if _cell == nil then
            _cell = zc.ZCTableViewCell:new()
        
        	local _size = cc.size(388, 143)
            local _di = zc.createGeneralPopScale({
		        tag = 2,
		        width = _size.width,
		        height = _size.height,
		    })
		    _di:setPosition(_cellSize.width*0.5, _cellSize.height*0.5)
            _cell:addChild(_di)

            local _node = cc.Node:create()
            _node:setContentSize(_size)
            _di:addChild(_node)
            _cell.di = _di
            _cell.diNode = _node
		end

        local _index = idx + 1
		if _index == numberOfCellsInTableView(table) then
			_cell.di:setPositionY(_cellSize.height*0.5 + _partY)
		else
			_cell.di:setPositionY(_cellSize.height*0.5)
		end
        self:dealWithCell(_cell, _index)
        return _cell
    end

    local function tableCellTouched( table, cell )
    	if cell then
	    	for i=0, numberOfCellsInTableView(table) - 1 do
				local _cell = table:cellAtIndex(i)
				if _cell and _cell.diNode and _cell.diNode.selected then
					if _cell == cell then
						_cell.diNode.selected:setVisible(true)
						self._nowIdx = i + 1
					else
						_cell.diNode.selected:setVisible(false)
					end
				end
			end
		end
		local _fetterData = self._regionalDbInfo[self._nowIdx]
		if not _fetterData then
			return
		end

		local _award = tonumber(_fetterData.award) or 0
		self._rightBtn:setEnable(_award == 2)
    end
    self._tableCellTouched = tableCellTouched

    _tableView:registerScriptHandler(numberOfCellsInTableView,zctech.NUMBER_OF_CELLS_IN_TABLEVIEW)  
    _tableView:registerScriptHandler(cellSizeForTable,zctech.TABLECELL_SIZE_FOR_INDEX)
    _tableView:registerScriptHandler(tableCellAtIndex,zctech.TABLECELL_SIZE_AT_INDEX)
    _tableView:registerScriptHandler(tableCellTouched, cc.TABLECELL_TOUCHED)
	    
    self._tableView = _tableView
    _tableView:reloadData()

    tableCellTouched(_tableView)
end

function RoleFettersRegionalPop:dealWithCell( cell, index )
	local di = cell.diNode
	local _fetterData = self._regionalDbInfo[index] or {}
	local _fetterDb = gameData.getDataFromCacheWithPrimaryKey("region_fetters", _fetterData.fettersId)
	local _diSize = di:getContentSize()

	local _cellImg = di.cellImg
	local _typeImg = di.typeImg
	local _leftLaceImg = di.leftLaceImg
	local _rightLaceImg = di.rightLaceImg
	local _heroScrollView = di.heroScrollView
	local _rewardBtn = di.rewardBtn
	local _valueDi = di.valueDi
	local _selected = di.selected
	if not di.isInit then
		di.isInit = true

		_cellImg = zc.getSprite({
	        pos = cc.p(_diSize.width*0.5, _diSize.height*0.5),
	    })
	    di:addChild(_cellImg)
	    di.cellImg = _cellImg

		_typeImg = zc.getSprite({
	        pos = cc.p(_diSize.width*0.5, _diSize.height - 25),
	    })
	    di:addChild(_typeImg)
	    di.typeImg = _typeImg

	    _leftLaceImg = zc.getSprite({
	        src = "res/Main/common/lace.png",
	        ap = cc.p(1, 0.5),
	        pos = cc.p(_typeImg:getPositionX() - 10, _typeImg:getPositionY()),
	    })
	    di:addChild(_leftLaceImg)
	    di.leftLaceImg = _leftLaceImg

	    _rightLaceImg = zc.getSprite({
	        src = "res/Main/common/lace.png",
	        ap = cc.p(1, 0.5),
	        pos = cc.p(_typeImg:getPositionX() + 10, _typeImg:getPositionY()),
	    })
	    _rightLaceImg:setScaleX(-1)
	    di:addChild(_rightLaceImg)
	   	di.rightLaceImg = _rightLaceImg

	   	local _scrollviewSize = cc.size(250, 80)
		_heroScrollView = zc.createScrollview({
	        pos = cc.p(5, 10),
	        size = _scrollviewSize,
	        innerSize = _scrollviewSize,
	    })
	    _heroScrollView:setSwallowTouches(false)
	    di:addChild(_heroScrollView)
	    di.heroScrollView = _heroScrollView

	    _rewardBtn = zc.createPushButton({
	    	normalFile = "res/Main/role/fetter/rewardBtn_canGet.png",
	    	-- disableFile = "res/Main/role/fetter/rewardBtn_unGet.png",
	    	pos = cc.p(_diSize.width - 60, 55),
	    	endCallback = function() end
	    })
	    di:addChild(_rewardBtn)
	    di.rewardBtn = _rewardBtn

	    local _valueDiSize = cc.size(130, 82)
	    _valueDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _valueDiSize)
	    _valueDi:setPosition(_rewardBtn:getPositionX() - 10, _rewardBtn:getPositionY())
	    di:addChild(_valueDi)
	    di.valueDi = _valueDi
		for i=1, 3 do
			local _valueTip = zc.createLabel({
				fontSize = 18,
				ap = cc.p(0, 0.5),
				color = cc.c3b(213, 193, 132),
				pos = cc.p(5, _valueDiSize.height*0.2 + _valueDiSize.height*0.3*(3-i))
			})
			_valueDi:addChild(_valueTip)
			_valueDi["valueTip" .. i] = _valueTip
			local _valueNum = zc.createLabel({
				fontSize = 18,
				ap = cc.p(1, 0.5),
				color = display.COLOR_GREEN,
				pos = cc.p(_valueDiSize.width - 5, _valueTip:getPositionY())
			})
			_valueDi:addChild(_valueNum)
			_valueDi["valueNum" .. i] = _valueNum
		end

	   _selected = zc.getSprite({
		   	src = "res/Main/role/fetter/selected.png",
	        pos = cc.p(_diSize.width*0.5, _diSize.height*0.5),
	    })
	    di:addChild(_selected, 1)
	    di.selected = _selected
	end

	if self._nowIdx == index then
		_selected:setVisible(true)
	else
		_selected:setVisible(false)
	end

	local _status = tonumber(_fetterData.status) or 0
	local _award = tonumber(_fetterData.award) or 0
	local _level = tonumber(_fetterData.level) or 1
	if _status ~= 0 then
		_cellImg:setVisible(true)
		_cellImg:setTexture("res/Main/role/fetter/cellDi" .. _level .. ".png")
		_typeImg:setTexture("res/Main/role/fetter/cellLevel" .. _level .. ".png")
	else
		_cellImg:setVisible(false)
		_typeImg:setTexture("res/Main/role/fetter/unOpen.png")
	end
	if _award ~= 2 then
		_rewardBtn:setVisible(true)
		local _flag = _status ~= 0
		local _normal = _rewardBtn:getStateNormal()
		_normal:setTexture(_flag and "res/Main/role/fetter/rewardBtn_canGet.png" or "res/Main/role/fetter/rewardBtn_unGet.png")
		_valueDi:setVisible(false)
		
		_rewardBtn:setTouchEndedCall(function()
			local _pos = self._tableView:getContentOffset()
			local _nowY = cell:getPositionY() + _pos.y
			if _nowY < -30 or _nowY > self._tableSize.height - 50 then
				return
			end
			zc.createSourcePop("RoleFettersRegionalRewardPop", "src/layer/role/RoleFettersRegionalRewardPop.lua", {
				data = _fetterData,
				callback = function( backData )
					backData.noAnimation = true
		        	PlayerData:updataData(backData)
		        	local _regionFettersInfo = backData.regionFettersInfo or {}
		        	if next(_regionFettersInfo) ~= nil then
			        	PlayerData:updateOneFetterRegionalInfoById(_fetterData.id, _regionFettersInfo)
			        	for k,v in pairs(_regionFettersInfo) do
			        		_fetterData[k] = v
			        	end
			        	self._regionalDbInfo[index] = _fetterData
			        end

		        	zc.createShowReward(backData)
		        	self._tableView:reloadDataAndScrollToCurrentCell()
		        	self._tableCellTouched(self._tableView)
				end
			})
		end)
	else
		_rewardBtn:setVisible(false)
		_valueDi:setVisible(true)
		local _upgradData = _fetterData.upgradeInfo or {}
		for i=1, 3 do
			local _tipLab = _valueDi["valueTip" .. i]
			local _numLab = _valueDi["valueNum" .. i]
			local _effId = tonumber(_upgradData["effectId" .. i]) or 0
			if _effId == 0 then
				_tipLab:setVisible(false)
				_numLab:setVisible(false)
			else
				local _num = tonumber(_upgradData["effectValue" .. i]) or 0
				_tipLab:setVisible(true)
				_numLab:setVisible(true)
				_tipLab:setString(LANGUAGE_getAttributeTextById(_effId) .. "：")
				_numLab:setString("+" .. zc.getAttributeNumById(_effId, _num))
			end
		end
	end

	_leftLaceImg:setPositionX(_typeImg:getPositionX() - _typeImg:getContentSize().width*0.5 - 10)
	_rightLaceImg:setPositionX(_typeImg:getPositionX() + _typeImg:getContentSize().width*0.5 + 10)
	
	local _x, _y, _width, _scale = 40, 40, 80, 0.6
	_heroScrollView:removeAllChildren()

	local _count = 0
	for i=1, 5 do
		local _heroId = tonumber(_fetterDb["hero" ..i]) or 0
		local _haveHero = tonumber(_fetterData["heroId" ..i]) or 0
		if _heroId ~= 0 then
			_count = _count + 1
			local _data = {
				mainType = zc.mainTypeSoldier,
				type = 1,
				id = _heroId,
			}
			local _icon = zc.createIconByData({
				data = _data,
				listener = function()
					local _pos = self._tableView:getContentOffset()
					local _nowY = cell:getPositionY() + _pos.y
					if _nowY < -30 or _nowY > self._tableSize.height - 50 then
						return
					end
					local _heroData = PlayerData:getGeneralInfoByHeroId(_heroId) or {}
					zc.createHeroInfoPop({
						id = _heroData.id,
						heroId = _heroId, 
						showHero = true
					})
				end
			})
			_heroScrollView:addChild(_icon)
			_heroScrollView["icon" .. i] = _icon

		    zc.doFuncForAllChild(_icon, function( child )
		        zc.setGray(child, _haveHero == 0)
		    end)
			_icon:setPosition(_x, _y)
			_icon:setScale(_scale)
			_x = _x + _width
		end
	end
	local _innerSize = _heroScrollView:getInnerContainerSize()
	local _innerNewWidth = _count*_width + 5
	if _innerNewWidth > _heroScrollView:getContentSize().width then
		_innerSize.width = _innerNewWidth
		_heroScrollView:setInnerContainerSize(_innerSize)
	end
end

function RoleFettersRegionalPop:freshCountNum()
	self._haveCount = self._haveCount > #self._regionalDbInfo and #self._regionalDbInfo or self._haveCount
	self._countNumLab:setString(self._haveCount .. "/" ..#self._regionalDbInfo)
end


return RoleFettersRegionalPop