--[[
	兵器弹窗
	唐实聪
	2016.4.27
	红点规则：主角：已装备的兵器可强化，武将：有可装备的兵器或者已装备的兵器可洗练
]]
local RoleWeaponPop = class("RoleWeaponPop", function()
	return ZCPopLayer:create()
end)

function RoleWeaponPop:create( params )
	return self.new( params )
end

function RoleWeaponPop:ctor( params )
	self:initData( params )
	self:initUI()
end

-- 处理数据
function RoleWeaponPop:initData( params )
	self._id = params.id or 1
	-- 武将数据
	self._heroData = PlayerData:getGeneralInfoById( self._id )
	-- 获取主角heroId
	self._isMain = false
	if tonumber(PlayerData.info.heroId) == tonumber(self._heroData.id) then
		self._isMain = true
	end
	-- dump(PlayerData.info, "heh")
	-- dump(self._heroData, "self._heroData:")
	-- print("PlayerData.info.heroId:"..PlayerData.info.heroId.."==="..self._heroData.heroId)
	-- 兵器数据，已穿戴的兵器
	self._weaponData = PlayerData:getWeaponsInfoById( self._id )
	-- 兵器数据，要显示的兵器，不一定是穿戴的兵器
	self._weaponShowData = self._weaponData
	self._isMainRole = params.isMainRole



	-- 兵器列表
	self._weaponList = {}
	-- 获取当前英雄所使用的兵器类型
	local heroList = gameData.getDataFromCacheWithPrimaryKey("hero", self._heroData.heroId)
	local heroType = ""
	if heroList then
		heroType = tostring( heroList.weaponType or 0 )
	else
		heroType = "0"
	end
	self._heroType = {}
	for i, v in ipairs( string.split( heroType, "|" ) ) do
		local typeValue = tonumber( v )
		if typeValue then
			self._heroType[tostring( typeValue )] = true
		end
	end
	-- 武将名字数据
	self._heroNameList = {}
	for i, v in ipairs( PlayerData:getGeneralInfo() ) do
		self._heroNameList[tostring( v.id )] = v.name
	end


	self._callback = params.callback

	self._exist = true

	local _size = self:getContentSize()
	self._width = _size.width
	self._height = _size.height
end
-- 初始化界面
function RoleWeaponPop:initUI()
	-- 判断显示类型，1：显示信息界面，2：显示列表界面，3：都显示
	if self._weaponData then
		self:initInfoLayer()
		self:buildInfoData()
		self:refreshInfoLayer()
		self:showListLayer()
		self:show()
	else
		self:buildListData()
		if #self._weaponList == 0 then
			self._exist = false
		else
			self:initListLayer()
			self:refreshListLayer()
			self:show()
		end
	end
end

-- 创建信息弹窗
function RoleWeaponPop:initInfoLayer()
	-- 背景
	local _bgWidth = 384
	local _bgHeight = 569 + 31
    local _bg = zc.createNormalPop({
        tag = 1,
        titleTag = 1,
        height = _bgHeight,
        showSide = false,
    })
	_bg:setPosition( self._width/2, self._height/2 )
	self:addContent( _bg )
	self._infoLayer = _bg
	-- 吞噬cellbtn的点击事件层
	local _swallow = zc.createPushButton({
		touchSize = cc.size( _bgWidth, _bgHeight ),
		pos = cc.p( _bgWidth/2, _bgHeight/2 ),
		needSwallow = true,
	})
	_bg:addChild( _swallow )

	-- 顶部
	local _topBgWidth = _bgWidth - 36
	local _topBgHeight = 130 + 15
    local _topBg = zc.createGeneralPopScale({
        width = _topBgWidth,
        height = _topBgHeight,
    })
	_topBg:setPosition( _bgWidth/2 - 8, _bgHeight - 152 )
	_bg:addChild( _topBg, 1 )
    -- 背景
    local _iconBg = cc.Sprite:create( "res/Main/common/popBg/bgFlower.png" )
    _iconBg:setPosition( 70, _topBgHeight*0.5 )
    _iconBg:setScale( 0.7 )
    _topBg:addChild( _iconBg )
	local _weapon = zc.createIconByData({
        data = {
            mainType = zc.mainTypeWeapon,
            type = 1,
            id = 1,
            quality = 1,
        },
        ap = cc.p( 0, 0 ),
        pos = cc.p( 53, 53 ), 
    })
	_weapon:setPosition( _iconBg:getPosition() )
	_weapon:setScale( 0.8 )
	_topBg:addChild( _weapon )
	self._weapon = _weapon

	-- 名字背景
    local _nameBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
	_nameBg:setPosition( 240, _topBgHeight*0.5 + 20 )
	_topBg:addChild( _nameBg )
    -- 名字
    local _name = zc.createLabel({
        fontSize = 20,
        ttf = zc.getFont( 1 ),
        pos = cc.p( _nameBg:getContentSize().width/2, _nameBg:getContentSize().height/2 ),
        outLine = true,
        pixel = 1.5,
    })
    _nameBg:addChild( _name )
    self._name = _name
    -- 需求等级背景
    local _needLevelBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
    _needLevelBg:setPosition( 240, _topBgHeight*0.5 - 20 )
    _topBg:addChild( _needLevelBg )
    -- 需求等级
    local _needLevel = zc.createLabel({
        fontSize = 20,
        ttf = zc.getFont( 1 ),
        color = zc.COLOR_RED,
        pos = cc.p( _needLevelBg:getContentSize().width/2, _needLevelBg:getContentSize().height/2 ),
        outLine = true,
        pixel = 1.5,
    })
    _needLevelBg:addChild( _needLevel )
    self._needLevel = _needLevel

    -- 底部
	local _bottomBgWidth = _bgWidth - 36
	self._bottomBgWidth = _bottomBgWidth
	local _bottomBgHeight = 354
	local _bottomBg = zc.createGeneralPopScale({
        tag = 3,
        width = _bottomBgWidth,
        height = _bottomBgHeight,
    })
	_bottomBg:setAnchorPoint( 0.5, 0 )
	_bottomBg:setPosition( _bgWidth/2 - 8, 15 )
	_bg:addChild( _bottomBg )

	-- 属性背景
	local _attrBgWidth = _bottomBgWidth - 18
	local _attrBgHeight = 275
	local _attrBg = zc.createGeneralPopScale({
        tag = 2,
        width = _attrBgWidth,
        height = _attrBgHeight,
    })
	_attrBg:setAnchorPoint( 0.5, 1 )
	_attrBg:setPosition( _bottomBgWidth/2, _bottomBgHeight - 10 )
	_bottomBg:addChild( _attrBg )

	-- 属性标题
	local _attrTitlePath = {
		"res/Main/role/equip/baseAttr.png",
		"res/Main/role/equip/addAttr.png",
	}
	local _attrScrollview = zc.createScrollview({
	    pos = cc.p( 0, 0 ),
	    size = cc.size( _attrBgWidth, _attrBgHeight ),
	    touchEnable = true,
	    bounceEnable = true,
	    dir = ccui.ScrollViewDir.vertical,
	})
	_attrBg:addChild( _attrScrollview )
	self._attrScrollview = _attrScrollview
	self._attrTitle = {}
	self._attrLabel = {}
	for i = 1, 2 do
	    local _attrTitle = cc.Sprite:create( _attrTitlePath[i] )
	    _attrTitle:setPosition( _attrBgWidth/2, _attrBgHeight - 20 )
	    _attrScrollview:addChild( _attrTitle )
	    self._attrTitle[i] = _attrTitle
        local _attrTitleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleLeft:setAnchorPoint( 1, 0.5 )
        _attrTitleLeft:setPosition( 0, _attrTitle:getContentSize().height/2 )
        _attrTitle:addChild( _attrTitleLeft )
        local _attrTitleRight = cc.Sprite:create( "res/Main/common/lace.png" )
        _attrTitleRight:setAnchorPoint( 0, 0.5 )
        _attrTitleRight:setPosition( _attrTitle:getContentSize().width, _attrTitle:getContentSize().height/2 )
        _attrTitleRight:setFlippedX( true )
        _attrTitle:addChild( _attrTitleRight )
		-- 基础属性
		self._attrLabel[i] = {}
		local _attrLineHeight = 30
		for j = 1, 6 do
	        -- 属性
	        local _attrText = zc.createLabel({
	            fontSize = 18,
	            pos = cc.p( 15, _attrBgHeight - 30 - i*_attrLineHeight ),
	            outLine = true,
	            color = cc.c3b(230,224,163),
	        })
	        _attrText:setAnchorPoint( 0, 0.5 )
	        _attrScrollview:addChild( _attrText )
	        local _attrNum = zc.createLabel({
	            fontSize = 18,
	            pos = cc.p( 100, _attrText:getPositionY() ),
	            outLine = true,
	        })
	        _attrNum:setAnchorPoint( 0, 0.5 )
	        _attrScrollview:addChild( _attrNum )
	        local _mastery = zc.createLabel({
	            fontSize = 18,
	            pos = cc.p( 175, _attrText:getPositionY() ),
	            outLine = true,
	            color = cc.c3b(42,255,0),
	        })
	        _mastery:setAnchorPoint( 0, 0.5 )
	        _attrScrollview:addChild( _mastery )
	        self._attrLabel[i][j] = {
	            _attrText = _attrText,
	            _attrNum = _attrNum,
	            _mastery = _mastery,
	        }
	    end
	end
	self:createGemIcon( _attrScrollview, _attrBgWidth )

    -- 左按钮，强化
    local _leftBtn = zc.createCommomBtn({
		tag = 2,
		text = "",
        pos = cc.p( 85, 34 ),
        endCallback = function()
        	--新手引导
        	self:guideFunc()
        	self:clickLeftBtn()
    	end
	})
	_bottomBg:addChild( _leftBtn )
	self._leftBtn = _leftBtn
	if self._isMainRole then
		_leftBtn:setText( zc.lang("strength") )
	else
		_leftBtn:setText( zc.lang("smithy_clear") )
	end
    -- 添加红点
    local _redPoint_l = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint_l:setAnchorPoint( 1, 1 )
    _redPoint_l:setPosition( _leftBtn:getContentSize().width + 5, _leftBtn:getContentSize().height + 5 )
    _redPoint_l:setVisible( false )
    _leftBtn:addChild( _redPoint_l )
    _leftBtn._redPoint = _redPoint_l
	-- 右按钮，卸下，装备
    local _rightBtn = zc.createCommomBtn({
        tag = 1,
        pos = cc.p( _bottomBgWidth - 85, 34 ),
        text = "",
        endCallback = function()
        	self:clickRightBtn()
    	end
	})
	_bottomBg:addChild( _rightBtn )
	self._rightBtn = _rightBtn
    -- 添加红点
    local _redPoint_r = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint_r:setAnchorPoint( 1, 1 )
    _redPoint_r:setPosition( _leftBtn:getContentSize().width + 5, _leftBtn:getContentSize().height + 5 )
    _redPoint_r:setVisible( false )
    _rightBtn:addChild( _redPoint_r )
    _rightBtn._redPoint = _redPoint_r
end
-- 点击左边按钮响应
function RoleWeaponPop:clickLeftBtn()
    -- 兵器强化
    local smithyInfo = PlayerData:getHouseInfoByHouseId(11)
    if smithyInfo then
		if self._isMainRole then
			-- 神兵
			local _id = self._weaponShowData.id
			self:hide()
			zc.createSmithGodWeaponLayer({id=_id})
		else
			-- 强化
			-- local _id = self._weaponShowData.id
			local _id = self._id
			self:hide()
			-- zc.createSmithCastingLayer({gotoId = _id})
			zc.createSmithClearLayer({id = _id})
		end
    else
        zc.tipInfo(zc.lang("tips_please_build_smithy"))
    end
end
-- 点击右边按钮响应
function RoleWeaponPop:clickRightBtn()
	if self._rightBtn._type then
	    -- 装备
        local _needLevel = tonumber( self._weaponShowData.needLevel ) or 0
        local _needReincarnate = tonumber( self._weaponShowData.needReincarnate ) or 0
        local _level = tonumber( self._heroData.level ) or 0
        local _reincarnate = tonumber( self._heroData.reincarnate ) or 0
	    if ( _reincarnate > _needReincarnate ) or ( _reincarnate == _needReincarnate and _level >= _needLevel ) then
	    	-- 获取花费
		    local consume_price = gameData.getDataFromCache("consume_price", {type = 70})
		    local cost = tonumber(consume_price.price)
		    local _currentGID = getGuideManager():getCurrentGID()
			if _currentGID == GuideKey.KEY_5019 or _currentGID == GuideKey.KEY_5020 then
				zc.sendHttp({
			    	apiName = "Weapon_equip",
			    	params = {heroId = self._id,weaponId = self._weaponShowData.id},
			    	successCallback = function(data)
		            	--新手引导
		            	self:guideFunc()
		            	PlayerData:updateWeaponsByHeroIdAndWeaponId(self._id,self._weaponShowData.id)
	                	PlayerData:updateWeaponsInfoById(data.weaponEtt)
	                	PlayerData:updataData(data)
	                	PlayerData:setGeneralInfoById(self._id, data.hero)
	                	musicManager.playEffect( zc.effect.weaponOn )
		            	-- self:refresh()
		            	-- 主角换装需要换模型
		            	if self._isMainRole then
		            		PlayerData:setMainRole()
		            		zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_CHANGE_USER_HEAD})
		            	end
		            	if self._callback then
		            		self._callback( true )
		            	end
		            	self:hide({noAction = true})
						-- 刷新总览红点
						zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
		            end,
		        	})
				return
			end
			if self._isMain == true then
			    local confirm =  ZCConfirmDialog:createWithParams({
	                    title = zc.lang("prompt"),
	                    msg = string.format(zc.lang("change_shenbing_tip"), cost),
	                    showDi = true,
	                    leftVisible = false,
	                    rightCallback = function()
	                    	print("heroID 是多少："..self._weaponShowData.id)
	                        zc.sendHttp({
						    	apiName = "Weapon_equip",
						    	params = {heroId = self._id,weaponId = self._weaponShowData.id},
						    	successCallback = function(data)
					            	--新手引导
					            	self:guideFunc()
					            	PlayerData:updateWeaponsByHeroIdAndWeaponId(self._id,self._weaponShowData.id)
				                	PlayerData:updateWeaponsInfoById(data.weaponEtt)
				                	PlayerData:updataData(data)
				                	PlayerData:setGeneralInfoById(self._id, data.hero)
				                	musicManager.playEffect( zc.effect.weaponOn )
					            	-- self:refresh()
					            	-- 主角换装需要换模型
					            	if self._isMainRole then
					            		PlayerData:setMainRole()
					            		zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_CHANGE_USER_HEAD})
					            	end
					            	if self._callback then
					            		self._callback( true )
					            	end
					            	self:hide({noAction = true})
									-- 刷新总览红点
									zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
					            end,
					        })
	                    end
	                })
	            cc.Director:getInstance():getRunningScene():addChild(confirm, 11)
	        else
	        	zc.sendHttp({
			    	apiName = "Weapon_equip",
			    	params = {heroId = self._id,weaponId = self._weaponShowData.id},
			    	successCallback = function(data)
		            	--新手引导
		            	self:guideFunc()
		            	PlayerData:updateWeaponsByHeroIdAndWeaponId(self._id,self._weaponShowData.id)
	                	PlayerData:updateWeaponsInfoById(data.weaponEtt)
	                	PlayerData:updataData(data)
	                	PlayerData:setGeneralInfoById(self._id, data.hero)
	                	musicManager.playEffect( zc.effect.weaponOn )
		            	-- self:refresh()
		            	-- 主角换装需要换模型
		            	if self._isMainRole then
		            		PlayerData:setMainRole()
		            		zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_CHANGE_USER_HEAD})
		            	end
		            	if self._callback then
		            		self._callback( true )
		            	end
		            	self:hide({noAction = true})
						-- 刷新总览红点
						zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
		            end,
		        })
        	end
		else
			zc.tipInfo( zc.lang("level_unenough") )
		end
	else
	    -- 兵器卸下
	    zc.sendHttp({
	    	apiName = "Weapon_unload",
	    	params = {heroId = self._id},
	    	successCallback = function(data) 
                PlayerData:setGeneralInfoById(self._id, data.hero)
                PlayerData:updateWeaponsInfoById(data.weaponEtt)
                PlayerData:updataData(data)
	            PlayerData:checkSmithBookState()
            	musicManager.playEffect( zc.effect.weaponOff )
	            self:showListLayer()
	            self:refresh()
	            if self._callback then
	        		self._callback()
	        	end
				-- 刷新总览红点
				zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
	        end,
		})
	end
end

-- 构造属性数据
function RoleWeaponPop:buildInfoData()
	-- 当前属性
	self._curAttrData = {}
	-- 极限属性
	self._maxAttrData = {}

	local _weaponData = self._weaponShowData
	for i = 1, 6 do
		if _weaponData["effectId"..i] and tonumber( _weaponData["effectId"..i] ) ~= 0 then
			-- 需要去表里查询兵器效果
			local curEffectData = _weaponData["effectInfo"..i]
			local curAttrType = tonumber( curEffectData.effectId ) or 0
			if curAttrType ~= 0 then
				local curAttr = zc.getEquipAttriNameByEffectType( curAttrType, true )
				local curNum = zc.getAttributeNumById( curAttrType, _weaponData["effectValue"..i] or 0 )
				self._curAttrData[#self._curAttrData + 1] = {
					text = curAttr,
					num = curNum,
					key = curAttrType,
				}
			end
		end
		if _weaponData["teffectId"..i] and tonumber( _weaponData["teffectId"..i] ) ~= 0 then
			local maxAttrType = tonumber(_weaponData["teffectId"..i])
			if maxAttrType ~= 0 then
				local maxAttr = zc.getEquipAttriNameByEffectType( maxAttrType, true )
				local maxNum = zc.getAttributeNumById( maxAttrType, _weaponData["teffectValue"..i] or 0 )
				local maxColor = zc.getColorByQuality( _weaponData["teffectColor"..i] )
				self._maxAttrData[#self._maxAttrData + 1] = {
					text = maxAttr,
					num = maxNum,
					color = maxColor,
					quality = tonumber( _weaponData["teffectColor"..i] ) or 0,
					key = maxAttrType,
				}
			end
		end
	end
	table.sort(self._maxAttrData, function( a, b )
		return a.quality > b.quality
	end)

end
-- 刷新信息弹窗
function RoleWeaponPop:refreshInfoLayer()
	local _weaponData = self._weaponShowData
	-- 图标
	zc.updateIconByData(self._weapon, {
        data = {
            mainType = zc.mainTypeWeapon,
            type = _weaponData.weaponId,
            id = _weaponData.weaponId,
            quality = 1,
            level = zc.getLevelTipShow()..zc.getWeaponLevel( _weaponData.id ),
        },
        showLevel = true,
    })
    -- 需求等级
    local _text = ""
    local _needReincarnate = tonumber( _weaponData.needReincarnate ) or 0
    if _needReincarnate > 0 then
    	_text = zc.lang("need_level") .. ": ".._needReincarnate..zc.lang("turn").._weaponData.needLevel..zc.lang("level_1")
    else
    	_text = zc.lang("need_level") .. ": " .. zc.getLevelTipShow() .._weaponData.needLevel..zc.lang("level_1")
    end
    self._needLevel:setText( _text )
    -- 名字
    local _name = _weaponData.name
    local _grade = tonumber(_weaponData.grade) or 0
    if _grade > 0 then
    	_name = _name .. " +" .. _grade
    end
    self._name:setText( _name )
    local _attrData = {
    	self._curAttrData,
    	self._maxAttrData,
	}
    -- 属性
	local _attrLineHeight = 30
    local _height = ( #self._curAttrData + #self._maxAttrData )*_attrLineHeight + 35*2 + 85
    local _innerSize = self._attrScrollview:getInnerContainerSize()
    self._attrScrollview:setInnerContainerSize( cc.size( _innerSize.width, _height ) )
    local _outerSize = self._attrScrollview:getContentSize()
    _height = _height < _outerSize.height and _outerSize.height or _height
    self:refreshGemIcon( _weaponData, _height )
    _height = _height - 85
    for i, v in ipairs( self._attrLabel ) do
    	_height = _height - 17
    	self._attrTitle[i]:setPositionY( _height )
    	_height = _height - 18
    	local _flag = false
    	for j, u in ipairs( v ) do
    		local _data = _attrData[i][j]
    		if _data then
    			_flag = true
	    		if _data.color then
	    			u._attrText:setColor( _data.color )
	    			u._attrText:setString( _data.text )
	    			u._attrNum:setColor( _data.color )
	    			u._attrNum:setString( _data.num )
	    		else
	    			-- u._attrText:setColor( display.COLOR_WHITE )
	    			u._attrText:setString( _data.text )
	    			-- u._attrNum:setColor( display.COLOR_WHITE )
	    			u._attrNum:setString( _data.num )
	    		end
	    		local _masteryValue = PlayerData:getSkilfulAddInfoByEffectId( i, _data.key , _weaponData.quality) or 0
	    		local _masteryText = ""
	    		if _masteryValue ~= 0 then
	    			_masteryText = "（" .. zc.lang("proficiency") .. "+".._masteryValue.."）"
	    		end
	    		u._mastery:setString( _masteryText )
				_height = _height - _attrLineHeight/2
	    		u._attrText:setPositionY( _height )
	    		u._attrNum:setPositionY( _height )
	    		u._mastery:setPositionY( _height )
				_height = _height - _attrLineHeight/2
	    		u._attrText:setVisible( true )
	    		u._attrNum:setVisible( true )
	    		u._mastery:setVisible( true )
	    	else
	    		u._attrText:setVisible( false )
	    		u._attrNum:setVisible( false )
	    		u._mastery:setVisible( false )
	    	end
    	end
    	if _flag then
    		self._attrTitle[i]:setVisible( true )
    	else
    		self._attrTitle[i]:setVisible( false )
    	end
    end
	-- 右按钮
	if not self._weaponData or tonumber( _weaponData.id or 0 ) ~= tonumber( self._weaponData.id or 0 ) then
		-- 没穿装备或者穿了装备，显示的装备不是穿的装备  -- 改为切换神兵
		local txt = self._isMain == true and zc.lang("change_shenbing") or  zc.lang("equip")
		self._rightBtn:setText( txt )
		self._rightBtn._type = true
		if self._isMainRole then
			self._leftBtn:setPosition( 85, 34 )
			self._rightBtn:setVisible( true )
			self._leftBtn._redPoint:setVisible( false )
			self._rightBtn._redPoint:setVisible( false )
		else
			self._leftBtn._redPoint:setVisible( false )
			self._rightBtn._redPoint:setVisible( false )
		end
	else
		self._rightBtn:setText( zc.lang("unload") )
		self._rightBtn._type = false
		if self._isMainRole then
			self._leftBtn:setPosition( self._bottomBgWidth/2, 34 )
			self._rightBtn:setVisible( false )
			self._leftBtn._redPoint:setVisible( PlayerData:getGodWeaponRedDotState() )
		else
			self._leftBtn:setPosition( 85, 34 )
			self._rightBtn:setVisible( true )
			self._leftBtn._redPoint:setVisible( PlayerData:checkCanClearWeaponsByHeroId( self._heroData.id ) )
			self._rightBtn._redPoint:setVisible( false )
		end
	end
end
-- 显示信息弹窗
function RoleWeaponPop:showInfoLayer()
	if not self._infoLayer then
		self._listLayer:setLocalZOrder( 2 )
		self:initInfoLayer()
		self:buildInfoData()
		self:refreshInfoLayer()
		self._listLayer:runAction(
			cc.EaseInOut:create(
				cc.MoveTo:create(
					0.5, cc.p( self._width/2 + 223, self._height/2 )
				), 2
			)
		)
		self._infoLayer:runAction(
			cc.EaseInOut:create(
				cc.MoveTo:create(
					0.5, cc.p( self._width/2 - 240, self._height/2 )
				), 2
			)
		)
		-- ---新手引导
		performWithDelay(self, function ()
			getGuideManager():removeMaskLayer()
			self:addGuide(self._rightBtn)
		end,0.5)
	end
end



-- 创建列表弹窗
function RoleWeaponPop:initListLayer()
	-- 背景
	local _bgWidth = 482
	local _bgHeight = 538
	local _bg = cc.Sprite:create()
	_bg:setContentSize( _bgWidth, _bgHeight )
	_bg:setPosition( self._width/2, self._height/2 )
	self:addContent( _bg )
	self._listLayer = _bg
	-- 吞噬cellbtn的点击事件层
	local _swallow = zc.createPushButton({
		touchSize = cc.size( _bgWidth, _bgHeight ),
		pos = cc.p( _bgWidth/2, _bgHeight/2 ),
		needSwallow = true,
	})
	_bg:addChild( _swallow )
	-- 下层背景
	local _bottomBg = zc.createNormalPop({
		width = _bgWidth + 32,
		height = _bgHeight + 60,
		showSide = false,
	})
	_bottomBg:setPosition( _bgWidth/2, _bgHeight/2 )
	_bg:addChild( _bottomBg )
	-- 上层背景
	local _topBg = cc.Sprite:create( "res/Main/common/popBg/di_4.png" )
	_topBg:setScaleX( _bgWidth/_topBg:getContentSize().width )
	_topBg:setScaleY( _bgHeight/_topBg:getContentSize().height )
	_topBg:setPosition( _bgWidth/2, _bgHeight/2 )
	_bg:addChild( _topBg )

	-- tableview
    local _weaponTableview = zc.ZCTableView:create( cc.size( _bgWidth, _bgHeight ) )
    _weaponTableview:setBounceable( true )
    _weaponTableview:setInertia( true )
    _weaponTableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    _weaponTableview:setPosition( 0, 0 )
    _weaponTableview:setDelegate()
    _weaponTableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local cellWidth = _bgWidth
    local cellHeight = 188
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildCell( cell, index, cellWidth, cellHeight )
        end
        self:updateCell( cell, index )

        return cell
    end
    local function numberOfCellsInTableView()
        return math.ceil( #self._weaponList/3 )
    end
    _weaponTableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    _weaponTableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    _weaponTableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    _bg:addChild( _weaponTableview )
    self._weaponTableview = _weaponTableview
end
-- 创建cell
function RoleWeaponPop:buildCell( cell, index, cellWidth, cellHeight )
	cell._item = {}
	for i = 1, 3 do
		-- cellBg
		local _cellBgWidth = 116
		local _cellBgHeight = 142
		local _cellBg = ccui.Scale9Sprite:create( cc.rect( 18, 23, 82, 75 ), "res/Main/role/fetter/fetterItemBg.png" )
		_cellBg:setContentSize( _cellBgWidth, _cellBgHeight )
		_cellBg:setPosition( cellWidth/6*( 2*i - 1 ), cellHeight/2 + 20 )
		cell:addChild( _cellBg )
		cell._item[i] = _cellBg
		-- 装备武将
		local _heroName = zc.createLabel({
	        fontSize = 20,
	        color = cc.c3b( 143, 125, 91 ),
	        pos = cc.p( _cellBgWidth/2, 23 ),
	        outLine = true,
	        pixel = 0.5,
		})
	    _cellBg:addChild( _heroName )
		_cellBg._heroName = _heroName
		-- 选中
		local _selected = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
	    _selected:setContentSize( _cellBgWidth + 4, _cellBgHeight + 4 )
	    _selected:setPosition( _cellBgWidth/2, _cellBgHeight/2 )
	    _cellBg:addChild( _selected )
		_cellBg._selected = _selected
		-- icon
		local _icon = zc.createIconByData({
	        data = {
	            mainType = zc.mainTypeWeapon,
	            type = 1,
	            id = 1,
	            quality = 1,
	        },
	        pos = cc.p( _cellBgWidth/2, _cellBgHeight - 57 ), 
	    })
	    _icon:setScale( 0.85 )
		_cellBg:addChild( _icon )
		_cellBg._icon = _icon
		-- 已装备
		local _equiped = cc.Sprite:create( "res/Main/role/attribute/equiped.png" )
		_equiped:setAnchorPoint( 0, 1 )
		_equiped:setPosition( -3, _cellBgHeight + 3 )
	    _cellBg:addChild( _equiped )
		_cellBg._equiped = _equiped
		-- 战力
	    local _fightBgWidth = 120
		local _fightBgHeight = 24
		local _fightBg = cc.Sprite:create( "res/Main/task/task_treasureBox_bg.png" )
	    _fightBg:setScaleX( _fightBgWidth/_fightBg:getContentSize().width )
	    _fightBg:setScaleY( _fightBgHeight/_fightBg:getContentSize().height )
		_fightBg:setPosition( _cellBgWidth/2, -15 )
		_cellBg:addChild( _fightBg )
	    local _fightSp = cc.Sprite:create( "res/Main/role/list/fight.png" )
	    _fightSp:setPosition( _fightBg:getPositionX() - _fightBg:getBoundingBox().width/2 + 10, _fightBg:getPositionY() )
		_cellBg:addChild( _fightSp )
		-- 战斗力数字
		local _fightNum = zc.createFntLabel({
	        fnt = "res/Main/common/fnt/fight_change.fnt",
	        pos = cc.p( _fightBg:getPositionX() + 5, _fightBg:getPositionY() ),
	        addwidth = -14,
	    })
	    _fightNum:setScale( 0.5 )
	    _cellBg:addChild( _fightNum )
		_cellBg._fightNum = _fightNum
		-- 按钮
		local _btn = zc.createPushButton({
			touchSize = cc.size( _cellBgWidth, _cellBgHeight ),
			pos = cc.p( _cellBgWidth/2, _cellBgHeight/2 ),
			needSwallow = false,
			needEnableWhenMoving = true,
			endCallback = function()
				local _cellIndex = 3*cell._index + i
				if _cellIndex ~= self._weaponIndex then
					if self._selectedCell then
						self._selectedCell._item[( self._weaponIndex - 1 )%3 + 1]._selected:setVisible( false )
					end
					self._weaponIndex = _cellIndex
					_cellBg._selected:setVisible( true )
					self._selectedCell = cell

					self._weaponShowData = self._weaponList[self._weaponIndex]
					if self._infoLayer then
						self:buildInfoData()
						self:refreshInfoLayer()
					else
						-- --新手引导
						self:guideFunc()
						self:showInfoLayer()
					end
				end
			end
		})
	    _cellBg:addChild( _btn )
	    _cellBg._btn = _btn
	end
end
-- 更新cell
function RoleWeaponPop:updateCell( cell, index )
	cell._index = index
	for i = 1, 3 do
		local _weaponIndex = index*3 + i
		local _data = self._weaponList[_weaponIndex]
		local _cellBg = cell._item[i]
		if _data then
			-- cellBg
			_cellBg:setVisible( true )
			if self._weaponIndex == _weaponIndex then
				_cellBg._selected:setVisible( true )
				self._selectedCell = cell
			else
				_cellBg._selected:setVisible( false )
			end
			-- icon
			zc.updateIconByData(_cellBg._icon, {
				data = {
		            mainType = zc.mainTypeWeapon,
		            type = 1,
		            id = _data.weaponId,
		            quality = 1,
		            grade = _data.grade,
		            level = zc.getLevelTipShow()..zc.getWeaponLevel( _data.id ),
		        },
		        showLevel = true,
			})
			-- fightNum
			_cellBg._fightNum:setString( _data.fight )
			-- heroName
			local _heroName = ""
			if _data.equiped then
				_heroName = _data.heroName
				if self._isMainRole and tostring( _data.heroId ) == tostring( PlayerData.info.heroId ) then
					if tonumber( PlayerData.info.seigniorId ) == 1 then
						_heroName = zc.lang("main_role")
					else
						_heroName = zc.lang("woman_role")
					end
				end
			else
				_heroName = zc.lang("empty")
			end
			_cellBg._heroName:setText( _heroName )
			-- equiped
			_cellBg._equiped:setVisible( _data.equiped )

			----新手引导
			if _weaponIndex == 1 then
				local _currentGID = getGuideManager():getCurrentGID()
				if _currentGID == GuideKey.KEY_5019 then
					if _cellBg._equiped:isVisible() then
						getGuideManager():setNextGID(GuideKey.KEY_OVER)
					else
						performWithDelay(self, function ()
							_cellBg._btn:setSwallowTouches(true)
							self:addGuide(_cellBg)
						end,0.3)
					end
				end
			end
		else
			_cellBg:setVisible( false )
		end
	end
end

-- 构造列表数据
function RoleWeaponPop:buildListData()
	-- 兵器列表数据，刷新info用
	self._weaponList = {}
	for i, v in ipairs( PlayerData:getWeaponsInfo() ) do
		if self._heroType[tostring( v.type )] then
			local data = nil
			-- 类型符合
			if self._isMainRole and tonumber( v.isUser ) == 1 then
				-- 主角
				data = clone( v )
			elseif not self._isMainRole and tonumber( v.isUser ) == 0 then
				-- 非主角
				data = clone( v )
			end
			if data then
				data.fight = zc.calculateCombatValue( data )
				local heroName = self._heroNameList[tostring( data.heroId or 0 )]
				if heroName then
					data.heroName = heroName
					data.equiped = true
				else
					data.equiped = false
				end
				self._weaponList[#self._weaponList + 1] = data
			end
		end
	end
	table.sort(self._weaponList, function( a, b )
		if a.equiped ~= b.equiped then
			return a.equiped
		elseif a.fight ~= b.fight then
			return a.fight > b.fight
		else
			return tonumber( a.id ) < tonumber( b.id )
		end
	end)
	-- dump( self._weaponList, "self._weaponList" )

	self._weaponIndex = 0
	if self._weaponShowData then
		-- 如果有显示的装备，从列表里查询显示装备的index
		for i, v in ipairs( self._weaponList ) do
			if tonumber( v.id ) == tonumber( self._weaponShowData.id ) then
				self._weaponIndex = i
			end
		end
	end
end
-- 刷新列表弹窗
function RoleWeaponPop:refreshListLayer()
	self._weaponTableview:reloadData()
end
-- 显示列表弹窗
function RoleWeaponPop:showListLayer()
	if not self._listLayer then
		self._infoLayer:setLocalZOrder( 2 )
		self:initListLayer()
		self:buildListData()
		self:refreshListLayer()
		self._infoLayer:runAction(
			cc.EaseInOut:create(
				cc.MoveTo:create(
					0.5, cc.p( self._width/2 - 240, self._height/2 )
				), 2
			)
		)
		self._listLayer:setVisible( false )
		self._listLayer:runAction(
			cc.Sequence:create(
				cc.DelayTime:create(
					0.1
				),
				cc.CallFunc:create(
					function()
						self._listLayer:setVisible( true )
					end
				),
				cc.EaseInOut:create(
					cc.MoveTo:create(
						0.4, cc.p( self._width/2 + 223, self._height/2 )
					), 2
				)
			)
		)
	end
end

function RoleWeaponPop:refresh()
	if self._listLayer then
		-- 刷新列表
		self:buildListData()
		self:refreshListLayer()
	end
	if self._infoLayer then
		-- 刷新信息数据
		self._weaponData = PlayerData:getWeaponsInfoById( self._id )
		if self._listLayer then
			-- 有列表直接从列表里取数据
			self._weaponShowData = self._weaponList[self._weaponIndex]
		else
			-- 没列表
			self._weaponShowData = self._weaponData
		end
		-- 刷新信息
		self:buildInfoData()
		self:refreshInfoLayer()
	end
end

--新手引导
function RoleWeaponPop:addGuide(btn)
	local _currentGID = getGuideManager():getCurrentGID()
	if _currentGID == GuideKey.KEY_5019
	 or _currentGID == GuideKey.KEY_5020
	  then
		getGuideManager():setObjTarget(btn) 
        getGuideManager():startGuide()
	end
end

--新手引导
function RoleWeaponPop:addGuide_1(btn)
end

--新手引导装备
function RoleWeaponPop:guideFunc()
	local _currentGID = getGuideManager():getCurrentGID()
	if _currentGID == GuideKey.KEY_5019 
		or _currentGID == GuideKey.KEY_5020 
	  then
		zc.setGuideFuncNextStep(_currentGID)
		if _currentGID == GuideKey.KEY_5019 then
			getGuideManager():addMaskLayer()
		end
	end
end

function RoleWeaponPop:createGemIcon( ctn, width )
	self._gemIcon = {}
	local _unlockText = {
        LANGUAGE_get_advance_color_text(1),
        LANGUAGE_get_advance_color_text(2),
        LANGUAGE_get_advance_color_text(4),
        LANGUAGE_get_advance_color_text(5),
    }
    local _side = 10
    local _dif = ( width - _side*2 )/4
	for i = 1, 4 do
		local _iconBgWidth = 70
		local _iconBgHeight = 70
		local _iconBg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
        _iconBg:setContentSize( _iconBgWidth, _iconBgHeight )
        _iconBg:setPosition( _dif*( i - 0.5 ) + _side, 0 )
        ctn:addChild( _iconBg )
        local _posX = _iconBgWidth/2
        local _posY = _iconBgHeight/2
        -- icon
        local _icon = zc.createIconByData({
            data = {
                mainType=zc.mainTypeGem,
                type=1,
                id=1,
            },
            pos = cc.p( _posX, _posY ),
        })
        _icon:setScale( 0.53 )
        _iconBg:addChild( _icon )
        _iconBg._icon = _icon
        -- 背景
        local _iconBtm = cc.Sprite:create( "res/Main/hero/hero_item1.png" )
        _iconBtm:setPosition( _posX, _posY )
        _iconBtm:setScale( 0.53 )
        _iconBg:addChild( _iconBtm )
        _iconBg._iconBtm = _iconBtm
        -- 锁
        local _lock = cc.Sprite:create( "res/Main/drillField/drillField_head_sock.png" )
        _lock:setPosition( _posX, _posY )
        _lock:setScale( 0.53 )
        _iconBg:addChild( _lock )
        _iconBg._lock = _lock
        -- 锁文字
        local _lockLabel = zc.createLabel({
            text = _unlockText[i],
            fontSize = 16,
            ttf = zc.getFont(1),
            pos = cc.p( _posX, _posY - 20),
            outLine = true,
		})
        _iconBg:addChild( _lockLabel )
        _iconBg._lockLabel = _lockLabel

		local can_inlay = zc.createSprite("res/Main/role/gem/can_inlay.png")
		can_inlay:setScale(0.8)
		can_inlay:setPosition(_iconBg:getContentSize().width/2, _iconBg:getContentSize().width/2-2)
		_iconBg:addChild(can_inlay)
		can_inlay:setVisible(false)
		_iconBg._can_inlay = can_inlay

        self._gemIcon[i] = _iconBg
	end
end

function RoleWeaponPop:refreshGemIcon( weaponData, height )
	for i, _iconBg in ipairs( self._gemIcon ) do
		_iconBg:setPositionY( height - 45 )
		local _key = "gemId"..i
		local _id = tonumber( weaponData[_key] ) or 0
		local _gemData = PlayerData:getGemInfoById( _id )
		local can_inlay_vis = false
		if _gemData then
			-- 有宝石
			_iconBg._icon:setVisible( true )
			zc.updateIconByData(_iconBg._icon, {
				data = {
					mainType=zc.mainTypeGem,
					type=_gemData.gemId,
					id=_gemData.gemId,
					level=zc.getLevelTipShow().._gemData.level,
				},
				showLevel = true,
			})
			_iconBg._iconBtm:setVisible( false )
			_iconBg._lock:setVisible( false )
			_iconBg._lockLabel:setVisible( false )
			-- _iconBg._plus:setVisible( false )
		else
			if zc.getGemPosStatus( weaponData.quality, i ) then
				-- 已解锁
				_iconBg._icon:setVisible( false )
				_iconBg._iconBtm:setVisible( true )
				_iconBg._lock:setVisible( false )
				_iconBg._lockLabel:setVisible( false )
				-- _iconBg._plus:setVisible( true )
				can_inlay_vis = true
			else
				-- 未解锁
				_iconBg._icon:setVisible( false )
				_iconBg._iconBtm:setVisible( true )
				_iconBg._lock:setVisible( true )
				_iconBg._lockLabel:setVisible( true )
				-- _iconBg._plus:setVisible( false )
			end
		end
		_iconBg._can_inlay:stopAllActions()
		if can_inlay_vis then
			_iconBg._can_inlay:setVisible(true)
			_iconBg._can_inlay:setOpacity(255)
			_iconBg._can_inlay:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeOut:create(1.2),cc.FadeIn:create(1.2))))
		else
			_iconBg._can_inlay:setVisible(false)
		end
	end
end


return RoleWeaponPop