--[[
    FileName: ItemSynthesisPop.lua
    Author: andong
    Date: 2016-03-17
    Purpose: 物品合成弹窗
]]
local ItemSynthesisPop = class( "ItemSynthesisPop", function ()
    return ZCPopLayer:create()
end)
function ItemSynthesisPop:create(params)
    return ItemSynthesisPop.new(params)
end
function ItemSynthesisPop:ctor(params)
    self:initData(params)
    self:initUI()
    self:createHeadItemList()
    self:show(false)
end

function ItemSynthesisPop:initData(params)
    print("ItemSynthesisPop:initData")
    dump(params)

    self._params = params
    self._callback = params.callback
    self._hideCallbcak = params.hidecallback
    self._itemType = params["itemType"]
    self._itemId = params["itemId"]
    self._costNum = params["costNum"] or 0
    --计算需要的数量
    local bagInfo = PlayerData:getBagInfoByID(self._itemId) or {}
    local _ownNum = bagInfo["num"] or 0
    local _needNum = tonumber(self._costNum) - tonumber(_ownNum) < 0 and 0 or tonumber(self._costNum) - tonumber(_ownNum)
    self._needNum = _needNum
    --掉落列表
    self._dropList = {}
    --点击列表
    self._itemList = {}
    local idx = #self._itemList + 1
    self._itemList[idx] = {}
    self._itemList[idx].itemId      = params["itemId"]
    self._itemList[idx].itemType    = params["itemType"]
    self._itemList[idx].needNum     = self._needNum --还需要的数量(只是在去扫荡的时候会用到)
    self._itemList[idx].costNum     = self._costNum --花费需要的数量
    self._itemList[idx].sysNum      = 1 --需要合成的数量

    self._guankaList = {}   -- 1,普通本，2精英本，3，一骑当千，4，武神塔

end
function ItemSynthesisPop:createHeadItemList(_is_one_key)
    if self._headInfoBg then
        self._headInfoBg:removeAllChildren()
    end
    local headSize = self._headInfoBg:getContentSize()

    for i = 1,#self._itemList do
        local _v = self._itemList[i]

        if i == 1 then
            local _mainHeroBg = zc.createSprite( "res/Main/role/fetter/heroBg.png" )
            _mainHeroBg:setPosition( headSize.width/2, headSize.height/2 - 35)
            self._headInfoBg:addChild( _mainHeroBg )
            _mainHeroBg:setScale(0.6)
        elseif i > 1 then
            local rightArrow = zc.createSprite("res/Main/common/arrow_right.png")
             rightArrow:setAnchorPoint(0.5, 0.5)
             rightArrow:setPosition(50+(i-1)*110-54, headSize.height/2)
             self._headInfoBg:addChild(rightArrow) 
             rightArrow:setScale(0.5)
        end
        local item = zc.createIconByData({
            data = {
                mainType = _v.itemType,
                type = _v.itemId,
                id = _v.itemId,
                quality = 1,
            }, 
            listener = function()
                if i < #self._itemList then
                    for j = #self._itemList, i+1,-1 do
                        self._itemList[j] = nil
                    end

                    self:createHeadItemList()
                end
            end,
            pos = cc.p(headSize.width/2, headSize.height/2 - 35), 
        })
        item:setScale(76/125)
        self._headInfoBg:addChild(item)

        if i == #self._itemList then
            -- local downArrow = zc.createSprite("res/Main/common/arrow_right.png")
            -- downArrow:setAnchorPoint(0.5, 0.5)
            -- downArrow:setPosition(item:getPositionX(), item:getPositionY()-50)
            -- self._headInfoBg:addChild(downArrow) 
            -- downArrow:setRotation(90)
            -- downArrow:setScale(0.5)
            local params = {id=_v["itemId"],itemType=_v["itemType"],sysNum=_v["sysNum"],needNum=_v["needNum"],costNum=_v["costNum"],_IS_ONE_KEY=_is_one_key}
            self:initSysthesisInfo(params)
        end
    end

    local leftArrow = zc.createImageView({src = "res/Main/role/equip/arrow_1.png"})
    leftArrow:setPosition(ccp(headSize.width/2 + 100, headSize.height/2 - 35))
    leftArrow:setScaleY(0.8)
    leftArrow:setScaleX(-1)
    self._headInfoBg:addChild(leftArrow)

    local rightArrow = zc.createImageView({src = "res/Main/role/equip/arrow_1.png"})
    rightArrow:setScaleY(0.8)
    rightArrow:setPosition(ccp(headSize.width/2 - 100, headSize.height/2 - 35))
    self._headInfoBg:addChild(rightArrow)

end

--检查合成信息
function ItemSynthesisPop:buildSynthesisData(params)
    local id = params.id
    if not id then
        return nil
    end
    local canSynthesisTable  = PlayerData:canSynthesis(id)
    return canSynthesisTable
end
function ItemSynthesisPop:buildDropAllData(params)
    local itemId = params.itemId
    local itemType = params.itemType
    if not itemId or not itemType then
        return
    end

    -- 判断物品类型
    self._dropList = {}

    if tonumber(itemType) == zc.mainTypeProp then
        local itemData = gameData.getDataFromCacheWithPrimaryKey("item", itemId)
        if table.nums( itemData ) > 0 then
            if itemData.source == 0 then
                return
            end
            
            if itemData.source == 1 then
                
                
            elseif itemData.source == 8 then
                if not self._guankaList[tostring(8)] then
                    self._guankaList[tostring(8)] = {}
                end

                -- 武神塔
                local tb = {
                    id = 1,
                    icon = "12",
                    name = zc.lang("cailiao_copy"),
                    status = zc.getFunctionStatus(23),
                    dropType = 8,
                    _type = 8,
                }
                table.insert(self._guankaList[tostring(8)], tb)
            elseif itemData.source == 10 then --神兵卷轴


            elseif type(itemData.source) == "string" then
                -- 副本掉落
                self:buildDropData(params, itemData)
            end
        end
    elseif itemType == zc.mainTypeGem then
        if not self._guankaList[tostring(8)] then
            self._guankaList[tostring(8)] = {}
        end

        -- 武神塔
        local tb = {
            id = 1,
            icon = "12",
            name = zc.lang("cailiao_copy"),
            status = zc.getFunctionStatus(23),
            dropType = 8,
        }
        table.insert(self._guankaList[tostring(8)], tb)
    end
end
-- 多人副本
function ItemSynthesisPop:buildMultiDropData(params)
    local itemId = params.itemId
    local itemType = params.itemType
    local needNum = params.needNum
    if not itemId or not itemType then
        return
    end
    -- 查找掉落数据
    local awardId = {}
    local _data = gameData.getDataFromCache("drop_award", {itemId = itemId, itemType = itemType})
    if next(_data) ~= nil then
        if _data.id then
            awardId[#awardId + 1] = tostring( _data.id )
        else
            for i, v in ipairs(_data) do
                awardId[#awardId + 1] = tostring( v.id )
            end
        end
    end
    -- 掉落途径数据
    if #awardId > 0 then
        -- 玩家关卡通关数据
        local tollgateList = PlayerData:getCopyInfo()
        -- 建筑等级
        local _houseInfo = PlayerData:getHouseInfoByHouseId(15) or {}
        local _level = tonumber( _houseInfo.level ) or 0
        -- 判断多人副本是否开启
        local _open = zc.getFunctionStatus( 19, false )
        for i, v in ipairs( gameData.getAllDataWithNoClone( "tollgateTeam" ) ) do
            -- 每一关的掉落
            local dropData = string.split( v.commonDrop, "," )
            local dropFlag = false
            for j, u in ipairs( awardId ) do
                -- 关卡掉落数据
                for k, w in ipairs( dropData ) do
                    if u == w then
                        dropFlag = true
                        break
                    end
                end
            end
            -- 如果掉落，检查这关是否可以打
            if dropFlag then
                local data = {
                    id = v.id,
                    icon = "wushenTower",
                    name = v.name,
                    dropType = 2,
                }
                if _open then
                    -- 多人副本开启
                    local _status = PlayerData:getCurTollGateStatus( v.activateId )
                    if _status == 2 and _level >= tonumber( v.houseLevel ) then
                        -- 已通关
                        data.status = true
                    else
                        -- 未通关
                        data.status = false
                    end
                else
                    -- 多人副本未开启
                    data.status = false
                end
                self._dropList[#self._dropList + 1] = data
            end
        end
    end
end
-- 检查副本或精英副本掉落
function ItemSynthesisPop:buildDropData(params, itemData)
    local itemId = params.itemId
    local itemType = params.itemType
    local needNum = params.needNum
    if not itemId or not itemType then
        return
    end
    
    -- 查找掉落数据
    local dropStr = itemData["source"] or ""
    local dropInfo = string.split(dropStr, ",")
    print("_type == 11")
    dump(dropInfo)
    self._dropList = {}
    local _typeToNation = {[2]=1,[3]=1,[4]=2} --2多人副本 3普通副本 4精英副本
    if dropInfo and next(dropInfo) then
        -- 玩家关卡通关数据
        local tollgateList = PlayerData:getCopyInfo()
        for i = 1, table.nums(dropInfo) do
            local dropData = string.split(dropInfo[i], "|")

            local _type = tonumber(dropData[1])
            local tollgateId = tonumber(dropData[2])

            local nationId = _typeToNation[_type]
            
            -- 副本类型
            local nationData = tollgateList[nationId] or {}

            if _type == 2 then --如果是多人副本
               
            elseif _type == 8 then 
                if not self._guankaList[tostring(_type)] then
                    self._guankaList[tostring(_type)] = {}
                end

                -- 武神塔
                local tb = {
                    id = 1,
                    icon = "12",
                    name = zc.lang("cailiao_copy"),
                    status = zc.getFunctionStatus(23),
                    dropType = 8,
                    _type = 8,
                }
                table.insert(self._guankaList[tostring(_type)], tb)
            elseif _type == 10 then

            elseif _type == 11 then
               
                if not self._guankaList[tostring(_type)] then
                    self._guankaList[tostring(_type)] = {}
                end
                -- 1018005

                 --tollgateId
                local tb = PlayerData:getDropInfo(tollgateId)
                tb._type = _type
                table.insert(self._guankaList[tostring(_type)],tb)
            else
                -- 章节
                local tollgeteInfo = gameData.getDataFromCacheWithPrimaryKey("tollgate", tollgateId)
                if tollgeteInfo and tollgeteInfo.chapterId then
                    local chapterId = tonumber( tollgeteInfo.chapterId )
                    local chapterData = nationData[chapterId] or {}
                    -- 关卡
                    local tollgateData = {}
                    for k, w in ipairs( chapterData["tollgates"] or {} ) do
                        if tonumber( w.tollgateId ) == tollgateId then
                            tollgateData = w
                            break
                        end
                    end
                    -- 状态
                    local status = tonumber( tollgateData["status"] ) or 0
                local star   = tonumber( tollgateData["star"] ) or 0
                    local data = {
                        id = tollgeteInfo.id,
                        icon = tollgeteInfo.icon,
                        name = tollgeteInfo.name,
                        chapterId = tollgeteInfo.chapterId,
                        nationId = nationId,
                        dropType = 0,
                        star = star,
                        _type = _type
                    }
                    if status == 2 then
                        -- 已通关
                        data.status = true
                    else
                        -- 未通关
                        data.status = false
                    end

                    if not self._guankaList[tostring(_type)] then
                        self._guankaList[tostring(_type)] = {}
                    end

                    table.insert(self._guankaList[tostring(_type)], data)
                end
            end
        end
    end
    
    --当前扫荡的目标物品
    self._itemType = itemType
    self._itemId = itemId
    self._needNum = needNum or 0
end

function ItemSynthesisPop:initUI()

    local popBg = zc.createNormalPop({
        tag = 1,
        titleTag = 1,
        showSide = false,
        height = 551,
        width = 400,
        bianZOrder = 0
    })
    popBg:setPosition(zc.width/2, zc.height/2)
    self:addContent(popBg)
    self._popBg = popBg
    self._popSize = cc.size(400,551)

    local headInfoBg = zc.createSprite()
    headInfoBg:setContentSize( cc.size(360, 110) )
    headInfoBg:setAnchorPoint(cc.p(0.5, 1))
    headInfoBg:setPosition(cc.p(self._popSize.width/2-2, self._popSize.height-40))
    popBg:addChild(headInfoBg, 100)
    self._headInfoBg = headInfoBg

    local middleBg = zc.createGeneralPopScale({
        tag = 3,
        width = 365,
        height = 355,
    })
    middleBg:setAnchorPoint(cc.p(0.5, 0))
    middleBg:setPosition(cc.p(self._popSize.width/2-2, 15))
    popBg:addChild(middleBg)
    self._middleBg = middleBg
end

--初始化合成界面
function ItemSynthesisPop:initSysthesisInfo(params)
    print("initSysthesisInfo")
    local itemType = tonumber(params.itemType)
    local canSynthesisTable
    if itemType == zc.mainTypeProp then
        canSynthesisTable  = self:buildSynthesisData(params)
    elseif itemType == zc.mainTypeGem then

    end

    if canSynthesisTable and canSynthesisTable["id"] then
        local itemInfo = gameData.getDataFromCacheWithPrimaryKey("item", params["id"])
        if not self._mySysBg then
            local sysSize = cc.size(self._middleBg:getContentSize().width-22, 262)
            local mySysBg = zc.createGeneralPopScale({
                tag = 2,
                width = sysSize.width,
                height = 262,
            })
            mySysBg:setAnchorPoint(cc.p(0.5, 1))
            mySysBg:setPosition(cc.p(self._middleBg:getContentSize().width/2, self._middleBg:getContentSize().height-8))
            self._middleBg:addChild(mySysBg)
            self._mySysBg = mySysBg
        end
        local mySysBg = self._mySysBg
        local mySysSize = mySysBg:getContentSize()
        mySysBg:removeAllChildren()

        if self._myTableBg then
            self._myTableBg:setVisible(false)
        end
        if self._middleBg then
            self._middleBg:setVisible(true)
        end

        local nameLab = zc.createLabel({
            text = itemInfo["name"],
            outLine = true,
            fontSize = 18,
            pos = cc.p(mySysSize.width/2, mySysSize.height-20),
            color = zc.getColorByQuality(itemInfo["color"]),
        })
        mySysBg:addChild(nameLab)

        local lace_left = zc.createSprite("res/Main/common/lace.png")
        lace_left:setAnchorPoint(1, 0.5)
        lace_left:setPosition(0, nameLab:getContentSize().height/2 )
        nameLab:addChild(lace_left)

        local lace_right = zc.createSprite("res/Main/common/lace.png")
        lace_right:setAnchorPoint(0, 0.5)
        lace_right:setPosition(nameLab:getContentSize().width+2, lace_left:getPositionY() )
        lace_right:setFlipX(true)
        nameLab:addChild(lace_right)


        --目标物品
        local itemBg = zc.createSprite("res/Main/common/item_bg.png")
        itemBg:setPosition(mySysSize.width/2, mySysSize.height-80)
        mySysBg:addChild(itemBg, 1)
        itemBg:setScale(85/108)
        local item = zc.createIconByData({
            data = {
                mainType =  zc.mainTypeProp,
                type = params["id"], 
                id = params["id"],
                quality = 1,
            }, 
            pos = cc.p(mySysSize.width/2, mySysSize.height-80)
        })
        item:setScale(80/125)  
        mySysBg:addChild(item, 1)
        self._targetItem = item
        local _ownNum = 0
        local _ownNumStr = ""
        local _color = display.COLOR_WHITE
        local _consumeNum = tonumber(params["costNum"])
        local bagInfo = PlayerData:getBagInfoByID(params["id"]) or {}
        _ownNum = bagInfo["num"] or 0
        _ownNumStr = _ownNum.."/".._consumeNum
        if _consumeNum <= 0 then
            _ownNumStr = _ownNum
        end
        if tonumber(_ownNum) < tonumber(_consumeNum) then
            _color = display.COLOR_RED
        end
        local costItemsmNum = zc.createLabel({
            text = _ownNumStr,
            fontSize = 26,
            ap = cc.p(1, 0.5),
            pos = cc.p(item:getContentSize().width-10, 17),
            outLine = true,
            color = _color,
            pixel = 1.3,
        })
        costItemsmNum:setName("costItemsmNum")
        item:addChild(costItemsmNum)

        if itemInfo.source and tonumber(itemInfo.source) ~= 0 then
            local scaleSize = cc.size(90, 50)
            local myScale9 = zc.getScaleNode("res/Main/common/img_empty.png", scaleSize)
            local getBtn = zc.createPushButton({
                normalNode = myScale9,
                needSwallow = false,
                anchor = cc.p(0.5, 0.5),
                pos = cc.p(item:getPositionX()+110, item:getPositionY()),
                endCallback = function() self:createGetInfo(params) end,
            })
            mySysBg:addChild(getBtn)
            local getLab = zc.createLabel({
                text = zc.lang("to_get"),
                outLine = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(0, getBtn:getContentSize().height/2 ),
                color = display.COLOR_BTNFONTYELLOW,
                pixel = 1.3
            })
            getBtn:addChild(getLab)
            local getLabLine = zc.createLabel({
                text = "______", 
                stroke = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(0, getLab:getPositionY()-3),
                color = display.COLOR_BTNFONTYELLOW,
                pixel = 1.3
            })
            getBtn:addChild(getLabLine)
            local getArrow = zc.createSprite("res/Main/synthesis/getImg.png")
            getArrow:setAnchorPoint(0, 0.5)
            getArrow:setPosition(getLab:getPositionX()+getLab:getContentSize().width, getLab:getPositionY()-1)
            getBtn:addChild(getArrow)
        end       

        --
        local line1 = zc.getScaleNode("res/Main/synthesis/line.jpg", cc.size(5, 47))
        line1:setPosition(cc.p(mySysSize.width/2, mySysSize.height-170+30))
        mySysBg:addChild(line1)
        -- local line2 = zc.getScaleNode("res/Main/synthesis/line.png", cc.size(220, 5))
        local line2 = zc.getScaleNode("res/Main/synthesis/line.jpg", cc.size(5, 220))
        line2:setPosition(cc.p(mySysSize.width/2, mySysSize.height-170+30))
        mySysBg:addChild(line2)
        line2:setRotation( 90 )
        local line3 = zc.getScaleNode("res/Main/synthesis/line.jpg", cc.size(5, 24))
        line3:setPosition(cc.p(mySysSize.width/2-110, mySysSize.height-183+30))
        mySysBg:addChild(line3)
        local line4 = zc.getScaleNode("res/Main/synthesis/line.jpg", cc.size(5, 24))
        line4:setPosition(cc.p(mySysSize.width/2+110, mySysSize.height-183+30))
        mySysBg:addChild(line4)

        --计算消耗
        local _consumeItem = {} --消耗的道具
        local _consumeRes = {} --消耗的物质
        for i = 1, 4 do
            local strId = "stuff"..i
            if canSynthesisTable[strId] and canSynthesisTable[strId] ~= 0 then
                local _v = string.split(canSynthesisTable[strId], "|")
                if _v and _v[2] then
                    if tonumber(_v[1]) == 1 then
                        local idx = #_consumeRes + 1
                        _consumeRes[idx] = {}
                        _consumeRes[idx].itemType = _v[1]
                        _consumeRes[idx].type = _v[2]
                        _consumeRes[idx].id  = _v[2]
                        _consumeRes[idx].num = _v[3]
                        _consumeRes[idx]["enougth"] = true --是否足够
                    elseif tonumber(_v[1]) == 4 then
                        local idx = #_consumeItem + 1
                        _consumeItem[idx] = {}
                        _consumeItem[idx].itemType = _v[1]
                        _consumeItem[idx].type = _v[2]
                        _consumeItem[idx].id  = _v[2]
                        _consumeItem[idx].num = _v[3]
                        _consumeItem[idx]["enougth"] = true
                    end
                end
            end
        end

        --消耗的材料
        self._showItem = {}
        for i = 1,3 do
            local dot = zc.createSprite("res/Main/synthesis/dot.png")
            dot:setPosition(mySysSize.width/2-(2-i)*110, mySysSize.height-170+30)
            mySysBg:addChild(dot)
            -- local itemBg = zc.createSprite("res/Main/smithy/shenbing/item_bg.png")
            local itemBg = zc.createSprite("res/Main/common/item_bg.png")
            itemBg:setAnchorPoint(0.5, 0.5)
            itemBg:setPosition(mySysSize.width/2-(2-i)*110, mySysSize.height-234+30)
            mySysBg:addChild(itemBg, 1)
            itemBg:setScale(85/108)

            if _consumeItem[i] then
                --消耗和拥有
                local _ownNum = 0
                local _color = display.COLOR_WHITE
                local _ownNumStr = ""
                local _needThisItemNum = 0 --这个物品需要的数量
                local _consumeNum = tonumber(_consumeItem[i]["num"])
                if tonumber(_consumeItem[i]["itemType"]) == 1 then
                    _ownNum = tonumber(PlayerData:getResourcesInfoById(_consumeItem[i]["type"]))
                    _ownNumStr = _consumeItem[i]["num"]
                elseif tonumber(_consumeItem[i]["itemType"]) == 4 then
                    local bagInfo = PlayerData:getBagInfoByID(_consumeItem[i]["id"]) or {}
                    _ownNum = tonumber(bagInfo["num"]) or 0
                    _ownNumStr = _ownNum.."/".._consumeItem[i]["num"]
                end
                if _ownNum < _consumeNum then
                    _color = display.COLOR_RED
                    _consumeItem[i]["enougth"] = false
                    _needThisItemNum = _consumeNum - _ownNum
                end

                local item, info= zc.createIconByData({
                    data = {
                        mainType =  _consumeItem[i]["itemType"],
                        type = _consumeItem[i]["id"],
                        id = _consumeItem[i]["id"],
                        quality = 1,
                    }, 
                    listener = function()

                        local idx = #self._itemList + 1
                        self._itemList[idx] = {}
                        self._itemList[idx].itemId = _consumeItem[i]["id"]
                        self._itemList[idx].itemType = _consumeItem[i]["itemType"]
                        self._itemList[idx].needNum = _needThisItemNum
                        self._itemList[idx].costNum = _consumeNum
                        self._itemList[idx].sysNum = 1

                        self:createHeadItemList()
                        
                    end,
                    pos = cc.p(itemBg:getPositionX(), itemBg:getPositionY())
                })
                item:setScale(80/125)
                mySysBg:addChild(item, 1)
                local costItemsmNum = zc.createLabel({
                    text = _ownNumStr,
                    fontSize = 26,
                    ap = cc.p(1, 0.5),
                    pos = cc.p(item:getContentSize().width-10, 17),
                    outLine = true,
                    color = _color,
                    pixel = 1.3,
                })
                costItemsmNum:setName("costItemsmNum")
                item:addChild(costItemsmNum, 10)

                self._showItem[#self._showItem+1] = itemBg


                --如果是一键合成
                if params._IS_ONE_KEY then
                    --需要合成该物品的数量
                    local needSysNum = tonumber(params["sysNum"]) * tonumber(_consumeItem[i]["num"])
                    if needSysNum == 0 then
                        needSysNum = tonumber(_consumeItem[i]["num"])
                    end
                    
                    if _ownNum < needSysNum then
                        local idx = #self._itemList + 1
                        self._itemList[idx] = {}
                        self._itemList[idx].itemId = _consumeItem[i]["id"]
                        self._itemList[idx].itemType = _consumeItem[i]["itemType"]
                        self._itemList[idx].needNum = _needThisItemNum
                        self._itemList[idx].sysNum = needSysNum-_ownNum
                        self._itemList[idx].costNum = _consumeNum

                        self:createHeadItemList(params._IS_ONE_KEY)
                    
                        do return end
                    end
                end
            end
        end
        --消耗的物质
        local _consumeResLab = zc.createLabel({
            text = zc.lang("compound_cost") .. "：",
            outLine = true,
            fontSize = 22,
            pos = cc.p(mySysSize.width/2 , -24),
            pixel = 1.3
        })
        mySysBg:addChild(_consumeResLab)
        --
        -- _consumeRes[2] = {id=1,num=100}
        local _consumeList = {}
        for i = 1, #_consumeRes do
            local _v = _consumeRes[i]
            local _resImg = zc.createSprite(zc.getImgByType(_v["id"]))
            _resImg:setAnchorPoint(0, 0.5)
            _resImg:setPosition(_consumeResLab:getPositionX()+_consumeResLab:getContentSize().width/2, _consumeResLab:getPositionY() )
            mySysBg:addChild(_resImg)
            _consumeList[#_consumeList+1] = _resImg
            local _ownNum = PlayerData:getResourcesInfoById(_v["id"]) or 0
            local _color = display.COLOR_WHITE
            if tonumber(_v["num"]) > _ownNum then
                _color = display.COLOR_RED
                _consumeRes[i]["enougth"] = false
            end
            local _resNum = zc.createLabel({
                text = _v["num"],
                stroke = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(_resImg:getPositionX()+_resImg:getContentSize().width, _resImg:getPositionY()),
                color = _color,
                pixel = 1.3
            })
            mySysBg:addChild(_resNum)
            _consumeList[#_consumeList+1] = _resNum
        end
        local _allWidth = 0 
        for i = 1, #_consumeList do
            _allWidth = _allWidth + _consumeList[i]:getContentSize().width
        end
        _consumeResLab:setPositionX(mySysSize.width/2-_allWidth/2)
        for i = 1, #_consumeList do
            if i == 1 then
                _consumeList[i]:setPositionX(_consumeResLab:getPositionX()+_consumeResLab:getContentSize().width/2)
            else
                _consumeList[i]:setPositionX(_consumeList[i-1]:getPositionX()+_consumeList[i-1]:getContentSize().width)
            end
        end
        if not next(_consumeList) then
            _consumeResLab:setVisible(false)
        end

        --设置按钮
        if params._IS_ONE_KEY then
            local touchParams = {
                conItem = _consumeItem,
                conRes = _consumeRes,
                needNum = params["needNum"],
                sysNum = params["sysNum"],
                costNum = params["costNum"],
                sysInfo = canSynthesisTable,
            }
            self:setOneKeyTouchState(touchParams)
        else
            local touchParams = {
                conItem = _consumeItem,
                conRes = _consumeRes,
                needNum = params["needNum"],
                sysInfo = canSynthesisTable,
            }
            self:setTouchState(touchParams)
        end

    else
        self:initTable()

        self:setTouchState()
        if self._myTableBg then
            self._myTableBg:setVisible(true)
        end
        if self._middleBg then
            self._middleBg:setVisible(false)
        end
        self:buildDropAllData({itemId=params["id"],itemType=params["itemType"],needNum=params["needNum"]})

        --排顺序
        -- self._guankaList

        print("self._guankaList")
        local tb = {}
        for k,v in pairs(self._guankaList) do
            tb[#tb + 1] = v
        end
        dump(tb)
        table.sort(tb,function(a,b) return a[1]._type < b[1]._type end)
        self._guankaList = tb
        -- dump(self._guankaList)

        self._myTable:reloadData()

        if table.nums(self._guankaList) == 0 then
            --神兵卷轴特殊处理，掉落给提示语
            local checkData = gameData.getDataFromCacheWithPrimaryKey("item", params["id"])
            if checkData and checkData.source and tonumber(checkData.source) == 10 then
                self._godWeaponGet:setVisible(true)
            else
                self._tipNoItemLab:setVisible(true)
            end
        else
            self._tipNoItemLab:setVisible(false)
            self._godWeaponGet:setVisible(false)
        end
    end
end

--设置按钮点击状态
function ItemSynthesisPop:setTouchState(params)
    local params = params or {}
    if not self._btnTouchBg then
        local touchSize = cc.size(self._middleBg:getContentSize().width, 80)
        -- local touchBg = zc.getScaleNode("res/Main/setting/scale9_1.png", touchSize)
        local touchBg = zc.createSprite()
        touchBg:setContentSize(touchSize)
        touchBg:setAnchorPoint(cc.p(0.5, 0))
        touchBg:setPosition(cc.p(self._popBg:getContentSize().width/2, 15))
        self._popBg:addChild(touchBg, 10)
        self._btnTouchBg = touchBg
    end
    local touchBg = self._btnTouchBg
    local touchSize = self._btnTouchBg:getContentSize()
    touchBg:removeAllChildren()


    local btnText = zc.lang("back_2")
    local btnType = 1 --1不能合成，只有掉落  2可以合成 3一键合成 4材料不足
    local trsSynthInfo = {} --合成信息
    local _consumeItem = params.conItem or {}
    local _consumeRes = params.conRes or {}
    local _sysInfo = params.sysInfo
    local _needNum = params.needNum or 1
    local _sysNum = params.sysNum or 1
    if _sysNum == 0 then
        _sysNum = 1
    end
    if params and params["sysInfo"] then --如果有合成信息先判断材料是否足够，足够直接合成，不足判断是否可以一键合成
        local _itemEnougth = true --材料是否足够
        local _resEnougth = true --资源是否足够
        for i = 1, #_consumeItem do
            if not _consumeItem[i]["enougth"] then
                _itemEnougth = false
                break
            end
        end
        for i = 1, #_consumeRes do
            if not _consumeRes[i]["enougth"] then
                _resEnougth = false
                break
            end
        end
        
        if _itemEnougth and _resEnougth then
            btnType = 2
            btnText = zc.lang("smith_synthesis")

            trsSynthInfo = PlayerData:canAKeySynthesis(_sysInfo, _sysNum, {})


        elseif _resEnougth and not _itemEnougth then
            --资源足够，材料不足，判断是否可以 一键合成
            trsSynthInfo = PlayerData:canAKeySynthesis(_sysInfo, _sysNum, {})
            local canAKeySynthesisFlag = true
            if trsSynthInfo and next(trsSynthInfo) then
                for i = 1, #trsSynthInfo do
                    for j = 1, 4 do
                        if trsSynthInfo[i]["stuff"..j] and tonumber(trsSynthInfo[i]["stuff"..j]) == -1 then 
                            canAKeySynthesisFlag = false
                            break
                        end
                    end
                end
            end                
            if canAKeySynthesisFlag then
                btnType = 3
                btnText = zc.lang("one_key_synthesis")
            else
                btnType = 4
                btnText = zc.lang("material_unenough") 
            end
        else
            btnType = 4
            btnText = zc.lang("material_unenough") 
        end

    end

    local backBtn = zc.createCommomBtn({
        tag =1,
        text = btnText,
        needSwallow = false,
        endCallback = function()
            -- self:hide()
            if btnType == 1 then
                if #self._itemList > 1 then
                    self._itemList[#self._itemList] = nil
                    self:createHeadItemList()
                elseif #self._itemList == 1 then
                    self:hide()
                end
            elseif btnType == 2 then
                --合成
                local paTrsSynthInfo
                paTrsSynthInfo = table.copy(trsSynthInfo)
                paTrsSynthInfo = zc.jsonencode(paTrsSynthInfo)
                zc.sendHttp({
                    apiName = "Bag_synthItem",
                    params = {synthInfo = paTrsSynthInfo},
                    successCallback = function (data)
                        self._changeItem = true --是否合成过，如果没有就不用刷新主界面
                        LayerManager.addShieldLayout(nil, 0.3)
                        PlayerData:updataData(data)
                        local _arr = {}
                        local _targetPosX = self._targetItem:getPositionX()
                        local _targetPosY = self._targetItem:getPositionY()
                        _arr[#_arr+1] = cc.CallFunc:create(function() 
                            for i = 1,#self._showItem do 
                                local _v = self._showItem[i]
                                local _nowPosX = _v:getPositionX()
                                local _nowPosY = _v:getPositionY()
                                local _itemInfo = zc._getIconInfo({
                                    data = {
                                        mainType =  _consumeItem[i]["itemType"],
                                        type = _consumeItem[i]["id"],
                                        id = _consumeItem[i]["id"],
                                        quality = 1,
                                    }
                                })
                                -- dump(_itemInfo)
                                local item = zc.createSprite(_itemInfo["img"])
                                item:setPosition(_nowPosX, _nowPosY)
                                item:setScale(80/125)
                                item:setVisible(false)
                                self._mySysBg:addChild(item, 2)
                                item:runAction(cc.Sequence:create(
                                    cc.DelayTime:create(i*0.1),
                                    cc.CallFunc:create(function() item:setVisible(true) end),
                                    -- cc.MoveBy:create(0.5,cc.p(_targetPosX-_nowPosX,_targetPosY-_nowPosY))
                                    cc.Spawn:create(
                                        cc.MoveBy:create(0.5,cc.p(_targetPosX-_nowPosX,_targetPosY-_nowPosY)),
                                        cc.ScaleTo:create(0.5, 0.3)
                                    ),
                                    cc.RemoveSelf:create(true)
                                ))
                            end
                        end)
                        _arr[#_arr+1] = cc.Sequence:create(
                            cc.DelayTime:create(0.6),
                            cc.CallFunc:create(function()
                                -- zc.tipInfo("合成成功")
                                self:createHeadItemList()
                            end
                        ))
                        self:runAction(cc.Sequence:create(_arr))
                    end,
                })
            elseif btnType == 3 then
                -- zc.tipInfo("一键合成！")
                --一键合成时候，保存原始状态
                self._saveBeforOneKeyState = table.copy(self._itemList)
                self:createHeadItemList(true)
            elseif btnType == 4 then
                zc.tipInfo(zc.lang("material_unenough")  .. "！")
            end
        end,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(touchSize.width/2, 40)
    })
    touchBg:addChild(backBtn)
    backBtn:setVisible(false)
end
--设置一键合成按钮点击状态
function ItemSynthesisPop:setOneKeyTouchState(params)
    local params = params or {}
    if not self._btnTouchBg then
        local touchSize = cc.size(self._middleBg:getContentSize().width, 80)
        -- local touchBg = zc.getScaleNode("res/Main/setting/scale9_1.png", touchSize)
        local touchBg = zc.createSprite()
        touchBg:setContentSize(touchSize)
        touchBg:setAnchorPoint(cc.p(0.5, 0))
        touchBg:setPosition(cc.p(self._popBg:getContentSize().width/2, 15))
        self._popBg:addChild(touchBg, 10)
        self._btnTouchBg = touchBg
    end
    local touchBg = self._btnTouchBg
    local touchSize = self._btnTouchBg:getContentSize()
    touchBg:removeAllChildren()


    local btnText = zc.lang("back_2")
    local btnType = 1 --1不能合成，只有掉落  2可以合成 3一键合成 4材料不足
    local trsSynthInfo = {} --合成信息
    local _consumeItem = params.conItem or {}
    local _consumeRes = params.conRes or {}
    local _sysInfo = params.sysInfo
    local _needNum = params.needNum or 1
    local _costNum = params.costNum or 1
    local _sysNum = params.sysNum or 1
    if _sysNum == 0 then
        _sysNum = 1
    end

    if params and params["sysInfo"] then --如果有合成信息先判断材料是否足够，足够直接合成，不足判断是否可以一键合成
        local _itemEnougth = true --材料是否足够
        local _resEnougth = true --资源是否足够
        for i = 1, #_consumeItem do
            if not _consumeItem[i]["enougth"] then
                _itemEnougth = false
                break
            end
        end
        for i = 1, #_consumeRes do
            if not _consumeRes[i]["enougth"] then
                _resEnougth = false
                break
            end
        end
        
        if _itemEnougth and _resEnougth then
            btnType = 2
            btnText = zc.lang("smith_synthesis")
            trsSynthInfo = PlayerData:canAKeySynthesis(_sysInfo, _sysNum, {})
        elseif _resEnougth and not _itemEnougth then
            --资源足够，材料不足，判断是否可以 一键合成
            trsSynthInfo = PlayerData:canAKeySynthesis(_sysInfo, _sysNum, {})
            local canAKeySynthesisFlag = true
            if trsSynthInfo and next(trsSynthInfo) then
                for i = 1, #trsSynthInfo do
                    for j = 1, 4 do
                        if trsSynthInfo[i]["stuff"..j] and tonumber(trsSynthInfo[i]["stuff"..j]) == -1 then 
                            canAKeySynthesisFlag = false
                            break
                        end
                    end
                end
            end                
            if canAKeySynthesisFlag then
                btnType = 3
                btnText = zc.lang("one_key_synthesis")
            else
                btnType = 4
                btnText = zc.lang("material_unenough")  
            end
        else
            btnType = 4
            btnText = zc.lang("material_unenough") 
        end
    end

    local backBtn = zc.createCommomBtn({
        tag = 1,
        text = btnText,
        needSwallow = false,
        endCallback = function()
        end,
        pos = cc.p(touchSize.width/2, 40)
    })
    touchBg:addChild(backBtn)

    if btnType == 2 then
        local paTrsSynthInfo
        paTrsSynthInfo = table.copy(trsSynthInfo)
        paTrsSynthInfo = zc.jsonencode(paTrsSynthInfo)
        zc.sendHttp({
            apiName = "Bag_synthItem",
            params = {synthInfo = paTrsSynthInfo},
            successCallback = function (data)
                self._changeItem = true --是否合成过，如果没有就不用刷新主界面
                LayerManager.addShieldLayout(nil, 0.3)
                PlayerData:updataData(data)
                if tolua.isnull(self) then
                    return
                end
                local _arr = {}
                local _targetPosX = self._targetItem:getPositionX()
                local _targetPosY = self._targetItem:getPositionY()
                _arr[#_arr+1] = cc.CallFunc:create(function() 
                    for i = 1,#self._showItem do 
                        local _v = self._showItem[i]
                        local _nowPosX = _v:getPositionX()
                        local _nowPosY = _v:getPositionY()
                        local _itemInfo = zc._getIconInfo({
                            data = {
                                mainType =  _consumeItem[i]["itemType"],
                                type = _consumeItem[i]["id"],
                                id = _consumeItem[i]["id"],
                                quality = 1,
                            }
                        })
                        -- dump(_itemInfo)
                        local item = zc.createSprite(_itemInfo["img"])
                        item:setPosition(_nowPosX, _nowPosY)
                        item:setScale(80/125)
                        item:setVisible(false)
                        self._mySysBg:addChild(item, 2)
                        item:runAction(cc.Sequence:create(
                            cc.DelayTime:create(i*0.1),
                            cc.CallFunc:create(function() item:setVisible(true) end),
                            cc.Spawn:create(
                                cc.MoveBy:create(0.5,cc.p(_targetPosX-_nowPosX,_targetPosY-_nowPosY)),
                                cc.ScaleTo:create(0.5, 0.3)
                            ), 
                            cc.RemoveSelf:create(true)
                        ))
                    end
                end)
                _arr[#_arr+1] = cc.Sequence:create(
                    cc.DelayTime:create(0.6),
                    cc.CallFunc:create(function() 
                        local costItemsmNum = self._targetItem:getChildByName("costItemsmNum")
                        local targetItemId = trsSynthInfo[1]["targetItemId"]
                        local targetItemNum = 0
                        if data.clientItems then
                            for i = 1, #data.clientItems do
                                local _v = data.clientItems[i]
                                if tonumber(_v["itemId"]) == tonumber(targetItemId) then
                                    targetItemNum = tonumber(_v["currentNum"])
                                    break
                                end
                            end
                        end
                        if costItemsmNum then
                            local costStr = targetItemNum.."/".._costNum
                            if _costNum <= 0 then
                                costStr = targetItemNum
                            end
                            costItemsmNum:setString(costStr)
                            if targetItemNum >= _costNum then
                                costItemsmNum:setColor(display.COLOR_WHITE)
                            end
                        end
                    end),
                    cc.DelayTime:create(0.5),
                    cc.CallFunc:create(function()
                        
                        local _onekey = true
                        if trsSynthInfo and trsSynthInfo[1] then
                            if tonumber(trsSynthInfo[1]["targetItemId"]) == tonumber(self._saveBeforOneKeyState[#self._saveBeforOneKeyState]["itemId"]) then
                                self._itemList = {}
                                self._itemList = table.copy(self._saveBeforOneKeyState)
                                self._saveBeforOneKeyState = nil
                                -- zc.tipInfo("合成成功")
                                self:createHeadItemList()
                                _onekey = false
                            end
                        end
                        if _onekey then
                            if table.nums(self._itemList) > 1 then
                                self._itemList[#self._itemList] = nil
                                self:createHeadItemList(true)
                            else
                                self._itemList = {}
                                self._itemList = table.copy(self._saveBeforOneKeyState)
                                self._saveBeforOneKeyState = nil
                                -- zc.tipInfo("合成成功")
                                self:createHeadItemList()
                            end
                        end

                    end
                ))
                self:runAction(cc.Sequence:create(_arr))
            end,
        })
    end
end
function ItemSynthesisPop:createGetInfo(params)
    self:initTable()
    if self._myTableBg then
        self._myTableBg:setVisible(true)
    end
    if self._middleBg then
        self._middleBg:setVisible(false)
    end

    if self._btnTouchBg then
        self._btnTouchBg:removeAllChildren()
        local backBtn = zc.createCommomBtn({
            tag =1,
            text = zc.lang("back_2"),
            needSwallow = false,
            endCallback = function()
                self:createHeadItemList()
            end,
            anchor = cc.p(0.5, 0.5),
            pos = cc.p(self._btnTouchBg:getContentSize().width/2, 40)
        })
        self._btnTouchBg:addChild(backBtn)
    end

    self:buildDropAllData({itemId=params["id"],itemType=params["itemType"],needNum=params["needNum"]})
    self._myTable:reloadData()
end

function ItemSynthesisPop:initTable()
    if self._myTableBg then
        return
    end  
    local tableSize = cc.size(self._middleBg:getContentSize().width, 350)
    local tableNode = self._popBg
    local myTableBg = zc.createGeneralPopScale({
        tag = 3,
        width = tableSize.width,
        height = tableSize.height,
    })
    myTableBg:setAnchorPoint(cc.p(0.5, 0))
    myTableBg:setPosition(cc.p(self._middleBg:getPositionX(), self._middleBg:getPositionY()))
    tableNode:addChild(myTableBg)
    myTableBg:setVisible(false)
    self._myTableBg = myTableBg

    local tipNoItemLab = zc.createSprite("res/Main/common/empty.png")
    tipNoItemLab:setAnchorPoint(0.5, 0.5)
    tipNoItemLab:setPosition(tableSize.width/2, tableSize.height/2)
    myTableBg:addChild(tipNoItemLab)
    tipNoItemLab:setVisible(false)
    self._tipNoItemLab = tipNoItemLab

    local _tipBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
    _tipBg:setContentSize( 285, 32 )
    _tipBg:setAnchorPoint(cc.p(0.5,0.5))
    _tipBg:setPosition( tableSize.width/2, tableSize.height/2 )
    myTableBg:addChild( _tipBg, 11 )
    cc.SpriteFrameCache:getInstance():addSpriteFrames("res/Main/home/homeUI.plist", "res/Main/home/homeUI.pvr.ccz")
    local _tipSp = zc.getSprite({
        src = "home_icon_info.png",
        plist = true,
        pos = cc.p( 15, 32/2 ),
        scale = 0.5,
    })
    _tipBg:addChild( _tipSp )
    local _tipLabel = zc.createRichLabel({
        fontSize = 22,
        pos = cc.p( 40, 32/2 ),
    })
    _tipBg:addChild( _tipLabel )
    _tipLabel:setAnchorPoint( 0, 0.5 )
    -- _tipLabel:setString( "[color=ffff0000]首次[/color][color=ff746548]通关章节可获得[/color]" )
    _tipLabel:setString( "[color=ffffffff]" .. zc.lang("tips_first_breakthrough_chapter_can_get") .. "[/color]" )
    _tipBg:setVisible(false)
    self._godWeaponGet = _tipBg
    
    local myTable = zc.ZCTableView:create(cc.size(myTableBg:getContentSize().width-4, 340))
    myTable:setPosition(2,6)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    myTableBg:addChild(myTable)
    self._myTable = myTable
    local function cellSizeForTable(table,idx)
        return 340/2, tableSize.width - 4
    end
    local function numberOfCellsInTableView(table)
        return #self._guankaList
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(tableSize.width - 4, 340/2))
        else
            cell:removeAllChildren()
        end
        self:updateCell(cell, nowIdx)
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    -- myTable:reloadData()
end

function ItemSynthesisPop:updateCell(cell, nowIdx)
    local cellSize = cell:getContentSize()
    local scaleSize = cc.size(cellSize.width, cellSize.height)

    local nowData = self._guankaList[nowIdx]

    local cellBg =  zc.createGeneralPopScale({
        tag = 2,
        width = cellSize.width-8,
        height = cellSize.height-7,
    })
    cellBg:setPosition(ccp(cellSize.width/2, cellSize.height/2))
    cell:addChild(cellBg)
    cellBg.cellBg = cellBg

    local src_config = {
        ["3"] = "putongfuben",
        ["4"] = "jingyixngfubenD",
        ["8"] = "wushenshilian",
        ["11"] = "yiqidangqian",
    }

    local titleDes = zc.createImageView({src = "res/Main/common/tipTitle/" .. src_config[tostring(nowData[1]._type)] .. ".png", pos = ccp(scaleSize.width/2, cellSize.height - 30)})
    cellBg:addChild(titleDes)

    local leftSide = zc.createImageView({src = "res/Main/common/side.png", pos = ccp(scaleSize.width/2 - 90, cellSize.height - 30)})
    leftSide:setScaleX(-1)
    cellBg:addChild(leftSide)
    local rightSide = zc.createImageView({src = "res/Main/common/side.png", pos = ccp(scaleSize.width/2 + 90, cellSize.height - 30)})
    cellBg:addChild(rightSide)

    local _scrollView = zc.createScrollview({
        size = cc.size(scaleSize.width -25, scaleSize.height - 50),
        pos = cc.p(12, 15),
    }) 
    cellBg:addChild(_scrollView)
    _scrollView:setSwallowTouches(false)
    cell.scrollView = _scrollView

    local _height = scaleSize.height - 45
    local _partW = 90

    dump(nowData)
    cell.scrollView:setInnerContainerSize(cc.size(table.nums(nowData) *_partW, _height))
    for i=1,table.nums(nowData) do
        if tonumber(nowData[i]._type) == 3 or tonumber(nowData[i]._type) == 4 then

            local iconInfo = gameData.getDataFromCache("tollgate", { id = nowData[i].id})
            local _icon = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeSoldier,
                    type = 1,
                    id = 1,
                },
                pos = cc.p(_partW*0.5 + (i - 1)*_partW, _height*0.5 + 7),
            })
            _icon:setScale(0.6)
            _icon:getChildByName("pic"):setTexture("res/Main/hero/head/hero_head_" .. iconInfo.headIcon .. ".png")
            cell.scrollView:addChild(_icon)

            if nowData[i].status == true then
                _icon:addChild(zc.createLabel({text = nowData[i].name, color = ccc3(246, 228, 171), pos = ccp(_icon:getContentSize().width/2, -25)}))
                _icon:setTouchEndedCall(function()
                    self:goDrop(nowData[i])
                end)
            else
                zc.setGray(_icon, true)
                _icon:addChild(zc.createLabel({text = LANGUAGE_TOLLGATEHERO.not_open, color = ccc3(169, 169, 169), pos = ccp(_icon:getContentSize().width/2, -25)}))
            end

        elseif tonumber(nowData[i]._type) == 8 then

            local icon = ZCSprite:create("res/Main/copy/"..nowData[i].icon..".png")
            icon:setScale(70/icon:getContentSize().width)
            icon:setPosition(cc.p(_partW*0.5 + (i - 1)*_partW, _height*0.5))

            cell.scrollView:addChild(icon)
            cell:addChild(zc.createLabel({text = zc.lang("cailiao_copy"), fontSize = 20, color = ccc3(246, 228, 171), pos = ccp(scaleSize.width/2 - 35, scaleSize.height*0.5 - 5)}))
            local _normal = zc.createSprite("res/Main/common/button/btn_sec_u.png")
            local _select = zc.createSprite("res/Main/common/button/btn_sec_d.png")
            _normal:setScaleY(0.7)
            _select:setScaleY(0.7)
            local goBtn = zc.createPushButton({
                normalFile = "res/Main/common/button/btn_sec_u.png",
                selectedFile = "res/Main/common/button/btn_sec_d.png",
                pos = cc.p(275, scaleSize.height/2-12), 
                anchor = cc.p(0.5, 0.5),
                needEnableWhenMoving = true,
                needSwallow = false,
                fontSize = 30,
                scale = 0.6,
                outLine = true,
                text = zc.lang("qianwang_2"),
                color2 = cc.c3b(76, 18, 18),
                endCallback = function()
                    self:goDrop(nowData[i])
                end
            })
            cellBg:addChild(goBtn)

        elseif tonumber(nowData[i]._type) == 11 then

            local icon = ZCSprite:create()

            local icon = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeSoldier,
                    type = 1,
                    id = 1,
                },
                pos = cc.p(_partW*0.5 + (i - 1)*_partW, _height*0.5 + 7),
            })
            icon:setScale(0.6)
            local pic = icon:getChildByName("pic")
            pic:setTexture("res/Main/copy/"..nowData[i].headId..".png")
            pic:setScaleX(icon:getContentSize().width/pic:getContentSize().width)
            pic:setScaleY(icon:getContentSize().height/pic:getContentSize().height)

            cell.scrollView:addChild(icon)
            -- icon:setSwallowTouches(false)
            if nowData[i].status == true then
                cell.scrollView:addChild(zc.createLabel({text = nowData[i].chapterId .. "-" .. nowData[i].guankaIdx, fontSize = 20, color = ccc3(246, 228, 171), pos = cc.p(_partW*0.5 + (i - 1)*_partW, 15)}))
                icon:setTouchEndedCall(function()
                    self:goDrop(nowData[i])
                end)
            else
                zc.setGray(pic, true)
                cell.scrollView:addChild(zc.createLabel({text = LANGUAGE_TOLLGATEHERO.not_open, color = ccc3(169, 169, 169), fontSize = 20, pos = cc.p(_partW*0.5 + (i - 1)*_partW, 15)}))
            end

        end
        
    end
end

-- 跳转
function ItemSynthesisPop:goDrop(_nowData)
    local data = _nowData
    local _itemType = self._itemType
    local _itemId = self._itemId
    local _itemNeedNum = self._needNum
    local itemInfo= gameData.getDataFromCacheWithPrimaryKey("item", _itemId)
    local _itemName = itemInfo["name"] or ""
    local _hideCallbcak = self._hideCallbcak
    self._callback = nil
    self:hide()
    if _hideCallbcak then
        _hideCallbcak()
    end
    if data.dropType == 0 then
        -- 副本掉落
        -- 打开扫荡
        local dropInfo = {
            mainType = _itemType,
            itemId = _itemId,
            needNum = _itemNeedNum,
            name = _itemName,
        }
        --如果可以直接扫荡，直接去扫荡
        if data["star"] and tonumber(data["star"]) >= 3 then
            --从后端获取怪物和掉落物品
            zc.sendHttp({
                apiName = "Tollgate_getTollInfo",
                params = {id=data.id},
                successCallback = function (net_data)
                    local _tollData = PlayerData:getCurTollGateData(data.id)
                    local _nationId = 1
                    if _itemType  == zc.mainTypeTrinket then
                        _nationId = 2
                    end
                    zc.createSourcePop("Copysweep", "src/layer/chapter/CopysweepPop.lua", {
                        enemyData = _tollData,
                        dropInfo = net_data.dropInfo,
                        tollDb = gameData.getDataFromCacheWithPrimaryKey("tollgate", _tollData.tollgateId),
                        dropNeedItem = dropInfo,
                        nationId = _nationId,
                    })
                end,
            })
        else
            zc.createTollgateLayer({
                nationId = data.nationId,
                tollgateId = data.chapterId,
                enemyid = data.id,
                dropInfo = dropInfo,
            })
        end
    elseif data._type == 11 then

        local currentGID = getGuideManager():getCurrentGID()

        if zc.getFunctionStatus(50) then
            local info = PlayerData:getHeroTrain()
            if table.nums(info) > 2 then
                if not PlayerData:getFuncGuideInfo(407) then
                    getGuideManager():sendFuncGuideTrigger(407)
                end
            end

            if not PlayerData:getFuncGuideInfo(407) then
                getGuideManager():setCurrentGID(GuideKey.KEY_15004)
                zc.sendHttp({
                    apiName = "Hero_CopyMain",
                    params = {},
                    successCallback = function(data)
                        zc.createSourceScene("HeroCopyPop", "src/layer/heroCopy/HeroCopyPop", {data = data})
                    end,
                })
                return
            end
        end

        zc.createSourcePop( "HeroCopyDetailPop", "src/layer/heroCopy/HeroCopyDetailPop.lua", {
            chapterId = math.ceil(data.chapterId/9), 
            data = data.data,
            houseIdx = data.chapterId - (math.ceil(data.chapterId/9)-1)*9,
            guankaIdx = data.guankaIdx,
            isDrop = true,
        })

    elseif data.dropType == 8 then
        -- 武神塔
        zc.createWushenshilian()
    elseif data.dropType == 2 then
        -- 多人副本
        zc.createMultiCopyMainScene( data.id )
    end
end

function ItemSynthesisPop:onCleanup()
    if self._callback  then
        if self._changeItem then
            self._callback()
        end
    end
    self._init = nil
end

return ItemSynthesisPop