--[[
    FileName: SmithyBookUsePop.lua
    Author: andong
    Date: 2016-08-05
    Purpose: 兵器铺消耗弹窗
]]
local SmithyBookUsePop = class( "SmithyBookUsePop", function ()
    return ZCPopLayer:create()
end)
function SmithyBookUsePop:create(params)
    return SmithyBookUsePop.new(params)
end
function SmithyBookUsePop:ctor(params)
    self:initData(params)
    self:initUI()
    self:show()
end
function SmithyBookUsePop:initData(params)
    self._houseInfo = PlayerData:getHouseInfoByHouseId(11)
    self._callback = params.callback
    self._params = params.data or {}
    self._activitied = self._params["activitied"]
    self._activityInfo = self._params["activityInfo"] or {}
    self._level = self._activitied and self._params["level"] or 0
    self._maxLevel = 5 --成就最大等级
    self._needWeapon = {} --需要消耗的兵器
    self._selectWeaponType = {} --已经选择的类型
    self._sortNum = {} --排序对应
    for i = 1, 5 do
        local weaponId = tonumber(self._params["weaponId"..i])
        if weaponId and weaponId > 0 then
            local idx = #self._needWeapon + 1
            self._needWeapon[weaponId] = weaponId
            self._selectWeaponType[weaponId] = 0
            self._sortNum[weaponId] = i * 10000
        end
    end
    self._weaponLevelList = {} --兵器等级表
    self._selectList = {} --选择框
    self:refreshShowInfo()
end
--刷新显示兵器数据
function SmithyBookUsePop:refreshShowInfo()
    self._showWeapons = {}
    local selfWeapon = PlayerData:getWeaponsInfo()
    for i = 1, table.nums(selfWeapon) do
        local v = selfWeapon[i]
        if v["isUser"] and tonumber(v["isUser"]) ~= 1 then --不是主角兵器
            if v["heroId"] and tonumber(v["heroId"]) == 0 then --未装备的兵器
                local sWeaponId = tonumber(v["weaponId"]) 
                if sWeaponId and self._needWeapon[sWeaponId] then
                    local idx = #self._showWeapons + 1
                    self._showWeapons[idx] = {}
                    self._showWeapons[idx]["weapon"] = v
                    self._showWeapons[idx]["sortWeight"] = 0
                    local _level = self:getWeaponLevel(v.id) --兵器等级
                    self._showWeapons[idx]["sortWeight"] = self._sortNum[sWeaponId] + _level 
                end
            end
        end
    end
    self._showNums = table.nums(self._showWeapons)
    table.sort(self._showWeapons,function(a,b)
        return tonumber(a.sortWeight) < tonumber(b.sortWeight)
    end)
    if not next(self._showWeapons) then
        if self._tipNoItemLab then
            self._tipNoItemLab:setVisible(true)
        end
    end
end
function SmithyBookUsePop:initUI()
    local popBg = zc.createNormalPop({
        tag = 1,
        titleSrc = "res/Main/common/tipTitle/jihuo.png",
        showSide = false,
        height = 540+31,
        width = 437,
        bianZOrder = 0
    })
    popBg:setPosition(zc.width*0.5, zc.height*0.5)
    self:addContent(popBg)
    local popSize = cc.size(437, 540)
    self._popBg = popBg
    self._popSize = popSize

    local close = zc.createBackButton({
        pos = cc.p(popBg:getContentSize().width-10, popBg:getContentSize().height-10),
        listener = function () 
            self:hide()
        end,
    })
    popBg:addChild(close, 10)

    local useItemBg = zc.getScaleNode("res/Main/smithy/book/cellimg.png", cc.size(413, 135) )
    useItemBg:setAnchorPoint(0.5, 1)
    useItemBg:setPosition(popSize.width/2, popSize.height - 52)
    popBg:addChild(useItemBg, 1)
    self._useItemBg = useItemBg
    local middle_bg = zc.createGeneralPopScale({
        tag = 3,
        width = 413,
        height = 265,
    })
    middle_bg:setAnchorPoint(cc.p(0.5, 0))
    middle_bg:setPosition(popSize.width/2-2, 83)
    popBg:addChild(middle_bg)
    self._middle_bg = middle_bg

    self:createNeedInfo()
    self:createTableview()
end
function SmithyBookUsePop:createNeedInfo()
    --遮蔽触摸
    local usetItemSize = self._useItemBg:getContentSize()
    local touchBtn = zc.createPushButton({
        touchSize = cc.size(usetItemSize.width, usetItemSize.height),
        needSwallow = true,
        pos = cc.p(usetItemSize.width/2, usetItemSize.height/2),
    })
    self._useItemBg:addChild(touchBtn)

    local bookName = zc.createLabel({
        text = self._params["name"],
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(20, 110),
    })
    self._useItemBg:addChild(bookName)

    self._useItemList = {}
    local posX = 55
    for i = 1, 5 do
        local weaponId = self._params["weaponId"..i] or 0 
        if weaponId and weaponId > 0 then
            local item = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeWeapon,
                    type = 1,
                    id = weaponId,
                    quality = 1,
                    level = "",
                }, 
                showGray = true,
                showLevel = true,
                showDetailPop = true,
                pos = cc.p( posX, 52), 
            })
            item:setScale(71/120)
            self._useItemBg:addChild(item)
            posX = posX + 81

            local idx = #self._useItemList+1
            self._useItemList[idx] = {}
            self._useItemList[idx]["weaponId"] = weaponId
            self._useItemList[idx]["item"] = item
        end
    end

    if self._level >= self._maxLevel then --最大等级是5级
        return
    end
    local btn = zc.createCommomBtn({
        tag = 2,
        text = zc.lang("activated"),
        touchScale = 0.9,
        pos = cc.p( self._popSize.width/2,46 ),
        needSwallow = true,
        needEnableWhenMoving = true,
        endCallback = function()
            local useWeapon = ""
            for k,v in pairs(self._selectWeaponType) do
                if tonumber(v) == 0 then
                    zc.tipInfo(zc.lang("tips_to_choosse_cost_weapon"))
                    return
                end
                useWeapon = v .. "|" .. useWeapon
            end
            useWeapon = string.sub(useWeapon,1,-2)
            zc.sendHttp({
                apiName = "Weapon_activeAchievement",
                params = {
                    houseId = self._houseInfo.id,
                    id = self._params.achievementId,
                    weaponIds = useWeapon,
                },
                successCallback = function (data)
                    LayerManager.addShieldLayout(nil, 0.5)
                    zc.tipInfo(zc.lang("activate_success"))
                    --增加成就
                    local weaponsBook = PlayerData:getWeaponsBook()
                    if weaponsBook then
                        weaponsBook[#weaponsBook+1] = {
                            achievementId = data["achievementId"],
                            id = data["id"],
                            level = data["level"],
                        }
                    end
                    for k,v in pairs(self._selectWeaponType) do
                        PlayerData:subWeapon(v)
                        self._selectWeaponType[k] = 0
                    end
                    --本地数据
                    PlayerData:updataData(data)
                    --记录激活信息
                    local achieveId = tonumber(self._params.achievementId)
                    self._activityInfo.id = data.id
                    self._activityInfo.level = 1

                    self:refreshShowInfo()
                    self._myTableview:reloadDataAndScrollToCurrentCell()
                    self._level = 1
                    self:refreshUseItem()
                    self:refreshStar()

                    self._activityBtn:setVisible(false)
                    self._levelUpBtn:setVisible(true)
                end,
            })
        end
    })
    self._activityBtn = btn
    self._popBg:addChild(btn, 10)

    local levelUpBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("upgrade"),
        touchScale = 0.9,
        pos = cc.p( self._popSize.width/2,46),
        needSwallow = true,
        needEnableWhenMoving = true,
        endCallback = function()
            local useWeapon = ""
            for k,v in pairs(self._selectWeaponType) do
                if tonumber(v) == 0 then
                    zc.tipInfo(zc.lang("tips_to_choosse_cost_weapon"))
                    return
                end
                useWeapon = v .. "|" .. useWeapon
            end
            useWeapon = string.sub(useWeapon,1,-2)

            zc.sendHttp({
                apiName = "Weapon_achievementUpgrade",
                params = {id = self._activityInfo.id, weaponIds = useWeapon},
                successCallback = function (data) 
                    PlayerData:setWeaponsBookByAchievementId(data["achievementId"], {level=tonumber(data["level"])})
                    for k,v in pairs(self._selectWeaponType) do
                        PlayerData:subWeapon(v)
                        self._selectWeaponType[k] = 0
                    end
                    --本地数据
                    PlayerData:updataData(data)

                    self._activityInfo.level = tonumber(data.level)
                    self:refreshShowInfo()
                    self._myTableview:reloadDataAndScrollToCurrentCell()

                    self._level = data.level
                    self:refreshUseItem(self._level)
                    self:refreshStar()

                    if tonumber(self._level) >= self._maxLevel then
                        self._levelUpBtn:setVisible(false)
                        zc.tipInfo(zc.lang("tips_congratulation_achieve_full_level"))
                    else
                        zc.tipInfo(zc.lang("upgrade_success"))
                    end
                end,
            })
        end
    })
    self._levelUpBtn = levelUpBtn
    self._popBg:addChild(levelUpBtn, 10)


    if self._activitied then
        self._activityBtn:setVisible(false)
        self._levelUpBtn:setVisible(true)
    else
        self._activityBtn:setVisible(true)
        self._levelUpBtn:setVisible(false)
    end

    self:initAchievementStar()
end
--成就等级
function SmithyBookUsePop:initAchievementStar()
    local _level = tonumber(self._level)
    local _bg = self._useItemBg
    for i = 1, 5 do
        local starPath = "res/Main/common/common_hero_star_2.png"
        if i <= _level then
            starPath = "res/Main/common/common_hero_star_1.png"
        end
        local _sprite = zc.createSprite(starPath)
        _sprite:setName("star"..i)
        _sprite:setPosition(cc.p(260+(i-1)*30, _bg:getContentSize().height - 25))
        _bg:addChild(_sprite)
    end
end
function SmithyBookUsePop:refreshStar()
    local _level = tonumber(self._level)
    local _bg = self._useItemBg
    for i = 1, 5 do
        local starPath = "res/Main/common/common_hero_star_2.png"
        if i <= _level then
            starPath = "res/Main/common/common_hero_star_1.png"
        end
        local _sprite = _bg:getChildByName("star"..i)
        _sprite:setTexture(starPath)
    end
end
function SmithyBookUsePop:createTableview()
    local tableSize = cc.size(413, 260)
    local tableNode = self._middle_bg

    local tipNoItemLab = zc.createSprite("res/Main/common/empty.png")
    tipNoItemLab:setPosition(tableSize.width/2, tableSize.height/2)
    tableNode:addChild(tipNoItemLab)
    tipNoItemLab:setVisible(false)
    self._tipNoItemLab = tipNoItemLab
    if not next(self._showWeapons) then
        tipNoItemLab:setVisible(true)
    end
    local myTable = zc.ZCTableView:create(cc.size(tableSize.width-4,tableSize.height-4))
    myTable:setPosition(2,2)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    tableNode:addChild(myTable)
    self._myTableview = myTable
    local cellSize = cc.size(tableSize.width, 170)
    local function cellSizeForTable(table,idx)
        return cellSize.height, cellSize.width
    end
    local function numberOfCellsInTableView(table)
        return math.floor((self._showNums - 1)/3) + 1
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(cellSize.width, cellSize.height))
            self:createCell(cell, nowIdx)
        end
        self:updateCell(cell, nowIdx)
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    myTable:reloadData()
end
function SmithyBookUsePop:createCell(cell, nowIdx)
    local cellSize = cell:getContentSize()
    local scaleSize = cc.size(cellSize.width, cellSize.height-5)
    for i = 1, 3 do
        local item_bg = zc.createPushButton({
            normalNode = "res/Main/smithy/book/book_item_bg.png",
            needSwallow = false,
            needEnableWhenMoving = true,
            pos = cc.p(70 + (i-1) * 134, cellSize.height/2),
            endCallback = function() end,
        })
        cell:addChild(item_bg)
        local itemSelect = zc.getScaleNode("res/Main/common/common_select_big.png", cc.size(112, 161))
        itemSelect:setPosition(cc.p(item_bg:getContentSize().width/2, item_bg:getContentSize().height/2))
        item_bg:addChild(itemSelect)
        itemSelect:setVisible(false)
        local item = zc.createIconByData({
            data = {
                mainType = zc.mainTypeWeapon,
                type = 1,
                id = 1,
                quality = 1,
                level = "Lfv.1", --主键id
            }, 
            showDetailPop = true,
            showLevel = true,
            pos = cc.p( item_bg:getContentSize().width/2-3, 114), 
        })
        item:setScale(92/120)
        item_bg:addChild(item)

        local name = zc.createLabel({
            outLine = false,
            fontSize = 18,
            pos = cc.p(item:getPositionX(), 51),
        })
        item_bg:addChild(name)
        
        local weizhuangbei = zc.createLabel({
            text = zc.lang("un_equiped"),
            stroke = false,
            fontSize = 18,
            pos = cc.p(item:getPositionX(), 23),
            color = cc.c3b(127, 98, 81)
        })
        item_bg:addChild(weizhuangbei)
        

        item_bg["item"] = item
        item_bg["name"] = name
        item_bg["itemSelect"] = itemSelect
        cell["item_bg"..i] = item_bg
    end
end
function SmithyBookUsePop:updateCell(cell, nowIdx)
    for i = 1, 3 do
        local item_bg = cell["item_bg"..i]
        item_bg:setVisible(false)
        local idx = (nowIdx-1) * 3 + i
        local itemInfo = self._showWeapons[idx]
        if itemInfo then
            local weaponData = itemInfo["weapon"]
            if weaponData and weaponData["id"] then
                item_bg:setVisible(true)
                local _level = self:getWeaponLevel(weaponData.id) or ""
                local newParmas = {
                    data = {
                        mainType = zc.mainTypeWeapon,
                        type = 1,
                        id = weaponData["weaponId"],
                        quality = 1,
                        grade = weaponData.grade,
                        level = zc.getLevelTipShow().._level, --主键id
                    }, 
                    primaryId = weaponData["id"],
                    showDetailPop = true,
                    showLevel = true,
                }
                local info = zc.updateIconByData(item_bg.item,newParmas)
                local name = item_bg["name"]
                name:setText(info["name"])
                name:setColor(zc.getColorByQuality(info["star"]))
                local id = tonumber(weaponData["id"]) --主键id
                local weaponId = tonumber(weaponData["weaponId"]) --静态id
                local itemSelect = item_bg["itemSelect"]
                itemSelect:setVisible(false)
                if self._selectWeaponType[weaponId] == id then
                    itemSelect:setVisible(true)
                end
                item_bg:setTouchEndedCall(function() 
                    --如果已经选择了，且选择的兵器相同
                    if self._selectWeaponType[weaponId] == id then
                        self._selectWeaponType[weaponId] = 0
                        self._selectList[weaponId]:setVisible(false)
                        self._selectList[weaponId] = nil
                    else
                        if self._selectWeaponType[weaponId] == 0 then
                            self._selectList[weaponId] = itemSelect
                        else
                            self._selectList[weaponId]:setVisible(false)
                            self._selectList[weaponId] = itemSelect
                        end
                        itemSelect:setVisible(true)
                        self._selectWeaponType[weaponId] = id
                    end
                    self:refreshUseItem()
                end)
            end
        end
    end
end
function SmithyBookUsePop:refreshUseItem()
    for i = 1, #self._useItemList do
        local v = self._useItemList[i]
        local weaponId = tonumber(v["weaponId"])
        local id = self._selectWeaponType[weaponId]
        if id > 0 then
            local _level = self:getWeaponLevel(id) or ""
            local newParmas = {
                data = {
                    mainType = zc.mainTypeWeapon,
                    type = 1,
                    id = weaponId,
                    quality = 1,
                    level = zc.getLevelTipShow().._level, --主键id
                }, 
                primaryId = id,
                showDetailPop = true,
                showLevel = true,
            }
            local info = zc.updateIconByData(v.item,newParmas)
        elseif id == 0 then
            local _level = ""
            local _showGray = true
            if self._level >= self._maxLevel then
                _showGray = false
            end
            local newParmas = {
                data = {
                    mainType = zc.mainTypeWeapon,
                    type = 1,
                    id = weaponId,
                    quality = 1,
                    level = "", --主键id
                },
                showGray = _showGray,
                showDetailPop = false,
                showLevel = false,
            }
            local info = zc.updateIconByData(v.item,newParmas)
        end
    end

end

--获取兵器等级，只获取一次
function SmithyBookUsePop:getWeaponLevel(_id)
    if not _id then
        return
    end
    if not self._weaponLevelList[_id] then
        local _level = zc.getWeaponLevel(_id)
        self._weaponLevelList[_id] = _level
    end
    return self._weaponLevelList[_id]
end
function SmithyBookUsePop:onCleanup()
    if self._callback then
        self._callback(self._activityInfo)
    end
end


return SmithyBookUsePop