--[[
    FileName: SmithyClearInfoPop.lua
    Author: andong
    Date: 2016-07-06
    Purpose: 兵器洗练信息弹窗
]]
local SmithyClearInfoPop = class( "SmithyClearInfoPop", function ()
    return ZCPopLayer:create()
end)
function SmithyClearInfoPop:create(params)
    return SmithyClearInfoPop.new(params)
end
function SmithyClearInfoPop:onEnter()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12904 or _currentGID == GuideKey.KEY_12908 then
        zc.setGuideFuncNextStep(_currentGID, false)
        LayerManager.addShieldLayout(nil, 0.3)
        performWithDelay(self, function()
            self:addGuide()
        end, 0.3)
    end
end
function SmithyClearInfoPop:onCleanup()
    local textureCache = cc.Director:getInstance():getTextureCache()
    textureCache:removeTextureForKey("res/Main/common/button_light.png")
end
function SmithyClearInfoPop:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12905 or _currentGID == GuideKey.KEY_12909 then
        getGuideManager():setObjTarget(self._guideBtn)
        getGuideManager():startGuide()
    end
end

function SmithyClearInfoPop:ctor(params)
    self:initData(params)
    self:initUI()
    self:show()
end
function SmithyClearInfoPop:initData(params)
    -- dump(params, "params =============== ")
    self._nowWeapon = params["weaponInfo"] or {}
    self._targetHero = params["taargetHero"] or {}
    self._doEquip = params["doEquip"]
    if self._targetHero and self._targetHero["weaponInfo"] and  self._targetHero["weaponInfo"]["type"] then
        self._hasTargetWeapon = true
    end
end
function SmithyClearInfoPop:initUI()
    
    local popSize = cc.size(330, 530)
    if self._hasTargetWeapon then
        popSize = cc.size(405*2+40, 530)
    end
    -- local popBg = zc.getScaleNode("res/Main/setting/scale9_1.png", popSize)
    local popBg = zc.getScaleNode("res/Main/common/img_empty.png", popSize)
    popBg:setAnchorPoint(cc.p(0.5, 0.5))
    popBg:setPosition(cc.p(zc.width/2, zc.height/2))
    self:addContent(popBg)
    self._popBg = popBg
    self._popSize = popSize
    local close = zc.createPushButton({
        touchSize = cc.size(10000,10000),
        needSwallow = true,
        endCallback = function()
            self:hide()
        end,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(popSize.width/2, popSize.height/2)
    })
    popBg:addChild(close)

    --当前作用兵器信息
    self:createNowEffectInfo()
    --目标兵器信息（武将穿戴兵器）
    self:createTargetEffectInfo()

end

function SmithyClearInfoPop:createNowEffectInfo()
    if self._nowWeapon and self._nowWeapon["type"] then
        local weaponData = self._nowWeapon
        --组织数据
        local effectInfoList = {}
        local teffectInfoList = {}
        for i = 1, 6 do
            local effectInfo = weaponData["effectInfo"..i]
            if effectInfo and  effectInfo["effectId"] then
                local idx = #effectInfoList + 1
                effectInfoList[idx] = {}
                effectInfoList[idx].effectId    = effectInfo["effectId"]
                effectInfoList[idx].effectValue = weaponData["effectValue"..i]
            end
        end
        for i = 1, 6 do
            local teffectId = weaponData["teffectId"..i]
            if teffectId and tonumber(teffectId) > 0 then
                local idx = #teffectInfoList + 1
                teffectInfoList[idx] = {}
                teffectInfoList[idx].teffectId    = weaponData["teffectId"..i]
                teffectInfoList[idx].teffectValue = weaponData["teffectValue"..i]
                teffectInfoList[idx].teffectColor = weaponData["teffectColor"..i]
            end
        end
        table.sort( teffectInfoList, function( a,b )
            local _aColor = tonumber(a.teffectColor)
            local _bColor = tonumber(b.teffectColor)
            if  _aColor ~= _bColor then
                return _aColor > _bColor
            else
                return tonumber(a.teffectId) < tonumber(b.teffectId)
            end
        end)
        self._nowWeaponTeffectNum = #teffectInfoList
        
        local _canEquip = false
        if self._targetHero and tonumber(self._targetHero["weaponType"]) == tonumber(weaponData["type"]) then
            local targetHeroReincarnate = tonumber(self._targetHero["reincarnate"]) or 0
            local targetHeroLevel = tonumber(self._targetHero["level"]) or 1
            local needReincarnate = tonumber(weaponData["needReincarnate"]) or 0
            local needLevel = tonumber(weaponData["needLevel"]) or 0
            if targetHeroLevel >= needLevel and targetHeroReincarnate >= needReincarnate then
                _canEquip = true
            end
        end

        local popBg = self._popBg
        local popSize = self._popSize
        -- local effSizeHeight = 238+30*(#effectInfoList+#teffectInfoList)
        local effSizeHeight = 238+30*((math.floor((#effectInfoList-1)/2)+1) + (math.floor((#teffectInfoList-1)/2)+1))
        if _canEquip then
            effSizeHeight = effSizeHeight + 60
        end
        local effSize = cc.size(405, effSizeHeight)

        local effBg = zc.createPushButton({
            normalNode = zc.getScaleNode("res/Main/common/common_inner17.png", effSize),
            needSwallow = true,
        })
        effBg:setPosition(cc.p(popSize.width/2-effSize.width/2-20, popSize.height/2))
        if not self._hasTargetWeapon then
            effBg:setPositionX(popSize.width/2)
        end
        popBg:addChild(effBg)
        
        local _level = zc.getWeaponLevel(weaponData.id)
        local item = zc.createIconByData({
            data = {
                mainType = zc.mainTypeWeapon,
                type = 1,
                id = weaponData.weaponId,
                quality = weaponData.color,
                level = zc.getLevelTipShow().._level, --主键id
            }, 
            showLevel = true,
            pos = cc.p( 75, effSize.height-70), 
        })
        item:setScale(80/120)
        effBg:addChild(item)

        local weaponType = zc.createSprite(zc.getHeroTypeImg( weaponData["type"] ))
        weaponType:setAnchorPoint(0.5, 0.5)
        weaponType:setPosition(150, effSize.height-50)
        effBg:addChild(weaponType)
        local _name = weaponData["name"] or ""
        local _grade = tonumber(weaponData["grade"]) or 0
        if _grade > 0 then
            _name = _name .. " +" .. _grade
        end
        local weaponName = zc.createLabel({
            text = _name,
            outLine = true,
            fontSize = 25,
            ap = cc.p(0, 0.5),
            pos = cc.p(weaponType:getPositionX()+weaponType:getContentSize().width/2, weaponType:getPositionY() ),
            pixel = 1.3,
            color = zc.getColorByQuality( weaponData.color )
        })
        effBg:addChild(weaponName)
        
        local zhuansheng = ""
        -- weaponData["needReincarnate"] = 10
        if weaponData["needReincarnate"] and tonumber(weaponData["needReincarnate"]) > 0 then
            zhuansheng = weaponData["needReincarnate"]..zc.lang("turn")
        end
        local needLevel = zc.createLabel({
            text = zc.lang("need_level") .. "："..zhuansheng..weaponData["needLevel"]..zc.lang("level_1"),
            outLine = true,
            fontSize = 22,
            ap = cc.p(0, 0.5),
            pos = cc.p(130, weaponType:getPositionY() - 40 ),
            color = cc.c3b(249,199,100),
            pixel = 1.3
        })
        effBg:addChild(needLevel)

        local line1 = zc.getScaleNode("res/Main/ornaments/trinket_cut_line.png", cc.size(329,2))
        line1:setPosition(effSize.width/2, weaponType:getPositionY() - 75)
        effBg:addChild(line1)
        local baseEffTitle = zc.createLabel({
            text = zc.lang("base_attribute"),
            outLine = true,
            fontSize = 24,
            ap = cc.p(0, 0.5),
            pos = cc.p(35, weaponType:getPositionY() - 98),
            pixel = 1.3
        })
        effBg:addChild(baseEffTitle)
        
        local posH = weaponType:getPositionY() - 128
        for i = 1, #effectInfoList do
            local effectInfo = effectInfoList[i]
            local effectId = effectInfo["effectId"]
            local effectValue = effectInfo["effectValue"] or 0
            local effectStr = LANGUAGE_getAttributeTextById(effectId)
            local effectNum = zc.getAttributeNumById(effectId,effectValue)
            local _pox = 35
            if i % 2 == 0 then
                _pox = 220
            end
            local effectLab = zc.createLabel({
                text = effectStr.."："..effectNum,
                outLine = true,
                fontSize = 22,
                ap = cc.p(0, 0.5),
                pos = cc.p(_pox, posH),
                color = cc.c3b(238,98,3),
                pixel = 1.3
            })
            effBg:addChild(effectLab)
          
            if i % 2 == 0 then
                posH = posH - 30
            elseif i == #effectInfoList then
                posH = posH - 30
            end
        end

        local line2 = zc.getScaleNode("res/Main/ornaments/trinket_cut_line.png", cc.size(329,2))
        line2:setPosition(effSize.width/2, posH+5)
        effBg:addChild(line2)
        posH = posH - 20

        local additionalEffectTitle = zc.createLabel({
            text = zc.lang("append_attribute"),
            outLine = true,
            fontSize = 24,
            ap = cc.p(0, 0.5),
            pos = cc.p(35, posH),
            pixel = 1.3
        })
        effBg:addChild(additionalEffectTitle)

        posH = posH - 30
        for i = 1, #teffectInfoList do
            local teffectInfo = teffectInfoList[i]

            local teffectId     = teffectInfo["teffectId"]
            local teffectValue  = teffectInfo["teffectValue"]
            local teffectColor  = teffectInfo["teffectColor"]

            local effectStr = LANGUAGE_getAttributeTextById(teffectId)
            local effectNum = zc.getAttributeNumById(teffectId,teffectValue)

            local _pox = 35
            if i % 2 == 0 then
                _pox = 220
            end
            local effectLab = zc.createLabel({
                text = effectStr.."："..effectNum,
                outLine = true,
                fontSize = 22,
                ap = cc.p(0, 0.5),
                pos = cc.p(_pox, posH ),
                color = zc.getColorByQuality(teffectColor),
                pixel = 1.3
            })
            effBg:addChild(effectLab)

            if i % 2 == 0 then
                posH = posH - 30
            elseif i == #teffectInfoList then
                posH = posH - 30
            end
        end

        if _canEquip then
            local touchBtn = zc.createCommomBtn({
                tag = 1,
                text = LANGUAGE_ROLE.activate_space,
                needSwallow = true,
                endCallback = function()
                    local doEquip = self._doEquip
                    self:hide()
                    if doEquip then
                        doEquip()
                    end
                end,
                pos = cc.p(effSize.width/2, 50),
            })
            effBg:addChild(touchBtn)
            self._guideBtn = touchBtn

            if weaponData["nowState"] and tonumber(weaponData["nowState"]) == 2 then
                local button_light = zc.createSprite("res/Main/common/button_light.png")
                button_light:setAnchorPoint(0.5, 0.5)
                button_light:setPosition(touchBtn:getContentSize().width/2, touchBtn:getContentSize().height/2)
                touchBtn:addChild(button_light,100)
                button_light:runAction(cc.RepeatForever:create(cc.Spawn:create(
                    cc.Sequence:create(
                        cc.FadeOut:create(1.0),
                        cc.FadeIn:create(1.0)
                    )
                )))
            end
        end
    end
end
function SmithyClearInfoPop:createTargetEffectInfo()
    if self._targetHero and self._targetHero["weaponInfo"] then
        local weaponData = self._targetHero["weaponInfo"]
        --组织数据
        local effectInfoList = {}
        local teffectInfoList = {}
        for i = 1, 6 do
            local effectInfo = weaponData["effectInfo"..i]
            if effectInfo and  effectInfo["effectId"] then
                local idx = #effectInfoList + 1
                effectInfoList[idx] = {}
                effectInfoList[idx].effectId    = effectInfo["effectId"]
                effectInfoList[idx].effectValue = weaponData["effectValue"..i]
            end
        end
        for i = 1, 6 do
            local teffectId = weaponData["teffectId"..i]
            if teffectId and tonumber(teffectId) > 0 then
                local idx = #teffectInfoList + 1
                teffectInfoList[idx] = {}
                teffectInfoList[idx].teffectId    = weaponData["teffectId"..i]
                teffectInfoList[idx].teffectValue = weaponData["teffectValue"..i]
                teffectInfoList[idx].teffectColor = weaponData["teffectColor"..i]
            end
        end
        table.sort( teffectInfoList, function( a,b )
            local _aColor = tonumber(a.teffectColor)
            local _bColor = tonumber(b.teffectColor)
            if  _aColor ~= _bColor then
                return _aColor > _bColor
            else
                return tonumber(a.teffectId) < tonumber(b.teffectId)
            end
        end)

        local popBg = self._popBg
        local popSize = self._popSize
        local effSizeHeight = 238+30*((math.floor((#effectInfoList-1)/2)+1) + (math.floor((#teffectInfoList-1)/2)+1))+60
        local effSize = cc.size(405, effSizeHeight)

        local effBg = zc.createPushButton({
            normalNode = zc.getScaleNode("res/Main/common/common_inner17.png", effSize),
            needSwallow = true,
            noScaleAction = true,
        })
        effBg:setPosition(cc.p(popSize.width/2+effSize.width/2+20, popSize.height/2))
        popBg:addChild(effBg)

        local _level = zc.getWeaponLevel(weaponData.id)
        local item = zc.createIconByData({
            data = {
                mainType = zc.mainTypeWeapon,
                type = 1,
                id = weaponData.weaponId,
                quality = weaponData.color,
                level = zc.getLevelTipShow().._level, --主键id
            }, 
            showLevel = true,
            pos = cc.p( 75, effSize.height-70), 
        })
        item:setScale(80/120)
        effBg:addChild(item)

        local weaponType = zc.createSprite(zc.getHeroTypeImg( weaponData["type"] ))
        weaponType:setAnchorPoint(0.5, 0.5)
        weaponType:setPosition(150, effSize.height-50)
        effBg:addChild(weaponType)

        local _name = weaponData["name"]
        local _grade = tonumber(weaponData["grade"]) or 0
        if _grade > 0 then
            _name = _name .. " +" .. _grade
        end
        local weaponName = zc.createLabel({
            text = _name .. "(" .. zc.lang("equiped") .. ")",
            outLine = true,
            fontSize = 25,
            ap = cc.p(0, 0.5),
            pos = cc.p(weaponType:getPositionX()+weaponType:getContentSize().width/2, weaponType:getPositionY() ),
            pixel = 1.3,
            color = zc.getColorByQuality( weaponData.color )
        })
        effBg:addChild(weaponName)
        
        local zhuansheng = ""
        if weaponData["needReincarnate"] and tonumber(weaponData["needReincarnate"]) > 0 then
            zhuansheng = weaponData["needReincarnate"].. zc.lang("turn")
        end
        local needLevel = zc.createLabel({
            text = zc.lang("need_level") .. "："..zhuansheng..weaponData["needLevel"]..zc.lang("level_1"),
            outLine = true,
            fontSize = 22,
            ap = cc.p(0, 0.5),
            pos = cc.p(130, weaponType:getPositionY() - 40 ),
            color = cc.c3b(250,197,110),
            pixel = 1.3
        })
        effBg:addChild(needLevel)

        local line1 = zc.getScaleNode("res/Main/ornaments/trinket_cut_line.png", cc.size(329,2))
        line1:setPosition(effSize.width/2, weaponType:getPositionY() - 75)
        effBg:addChild(line1)

        local baseEffTitle = zc.createLabel({
            text = zc.lang("base_attribute"),
            outLine = true,
            fontSize = 24,
            ap = cc.p(0, 0.5),
            pos = cc.p(35, weaponType:getPositionY() - 98),
            pixel = 1.3
        })
        effBg:addChild(baseEffTitle)
        
        local posH = weaponType:getPositionY() - 128
        for i = 1, #effectInfoList do
            local effectInfo = effectInfoList[i]
            local effectId = effectInfo["effectId"]
            local effectValue = effectInfo["effectValue"] or 0
            local effectStr = LANGUAGE_getAttributeTextById(effectId)
            local effectNum = zc.getAttributeNumById(effectId,effectValue)
            local _pox = 35
            if i % 2 == 0 then
                _pox = 220
            end
            local effectLab = zc.createLabel({
                text = effectStr.."："..effectNum,
                outLine = true,
                fontSize = 22,
                ap = cc.p(0, 0.5),
                pos = cc.p(_pox, posH),
                color = cc.c3b(238,98,3),
                pixel = 1.3
            })
            effBg:addChild(effectLab)
            if i % 2 == 0 then
                posH = posH - 30
            elseif i == #effectInfoList then
                posH = posH - 30
            end
        end

        local line2 = zc.getScaleNode("res/Main/ornaments/trinket_cut_line.png", cc.size(329,2))
        line2:setAnchorPoint(0.5, 0.5)
        line2:setPosition(effSize.width/2, posH+5)
        effBg:addChild(line2)
        posH = posH - 20
        local additionalEffectTitle = zc.createLabel({
            text = zc.lang("append_attribute"),
            outLine = true,
            fontSize = 24,
            ap = cc.p(0, 0.5),
            pos = cc.p(35, posH),
            pixel = 1.3
        })
        effBg:addChild(additionalEffectTitle)

        posH = posH - 30
        for i = 1, #teffectInfoList do
            local teffectInfo = teffectInfoList[i]

            local teffectId     = teffectInfo["teffectId"]
            local teffectValue  = teffectInfo["teffectValue"]
            local teffectColor  = teffectInfo["teffectColor"]

            local effectStr = LANGUAGE_getAttributeTextById(teffectId)
            local effectNum = zc.getAttributeNumById(teffectId,teffectValue)
            local _pox = 35
            if i % 2 == 0 then
                _pox = 220
            end
            local effectLab = zc.createLabel({
                text = effectStr.."："..effectNum,
                outLine = true,
                fontSize = 22,
                ap = cc.p(0, 0.5),
                pos = cc.p(_pox, posH ),
                color = zc.getColorByQuality(teffectColor),
                pixel = 1.3
            })
            effBg:addChild(effectLab)

            if i % 2 == 0 then
                posH = posH - 30
            elseif i == #teffectInfoList then
                posH = posH - 30
            end
        end

        --洗练
        local clearBtn = zc.createCommomBtn({
            tag = 1,
            text = zc.lang("smithy_clear_2"),
            needSwallow = true,
            endCallback = function()
                local nowWeapon = self._nowWeapon
                local targetWeapon = self._targetHero["weaponInfo"]
                self:hide()
                zc.createSourceScene("WeaponClear", "src/layer/smithyHouse/WeaponClearLayer.lua", {
                    nowWeapon = nowWeapon,
                    targetWeapon = targetWeapon,
                    tag = 1,
                })
            end,
            pos = cc.p(effSize.width/2+80, 50),
        })
        effBg:addChild(clearBtn)
        self._guideBtn = clearBtn

        local exchangeBtn = zc.createCommomBtn({
            tag = 1,
            text = zc.lang("transfer_2"),
            needSwallow = true,
            endCallback = function()
                local nowWeapon = self._nowWeapon
                local targetWeapon = self._targetHero["weaponInfo"]
                self:hide()
                zc.createSourceScene("WeaponClear", "src/layer/smithyHouse/WeaponClearLayer.lua", {
                    nowWeapon = nowWeapon,
                    targetWeapon = targetWeapon,
                    tag = 2,
                })
            end,
            pos = cc.p(effSize.width/2-80, 50),
        })
        effBg:addChild(exchangeBtn)
        if self._nowWeapon["nowState"] and tonumber(self._nowWeapon["nowState"]) ~= 2 then
            if self._nowWeaponTeffectNum and self._nowWeaponTeffectNum > #teffectInfoList then
                local button_light = zc.createSprite("res/Main/common/button_light.png")
                button_light:setAnchorPoint(0.5, 0.5)
                button_light:setPosition(exchangeBtn:getContentSize().width/2, exchangeBtn:getContentSize().height/2)
                exchangeBtn:addChild(button_light)
                button_light:runAction(cc.RepeatForever:create(cc.Spawn:create(
                    cc.Sequence:create(
                        cc.FadeOut:create(1.0),
                        cc.FadeIn:create(1.0)
                    )
                )))
            else
                if self._nowWeapon["nowState"] and tonumber(self._nowWeapon["nowState"]) == 1 then
                    local button_light = zc.createSprite("res/Main/common/button_light.png")
                    button_light:setAnchorPoint(0.5, 0.5)
                    button_light:setPosition(clearBtn:getContentSize().width/2, clearBtn:getContentSize().height/2)
                    clearBtn:addChild(button_light)
                    button_light:runAction(cc.RepeatForever:create(cc.Spawn:create(
                        cc.Sequence:create(
                            cc.FadeOut:create(1.0),
                            cc.FadeIn:create(1.0)
                        )
                    )))
                end
            end
        end
    end
end

return SmithyClearInfoPop