
--lua层网络管理类
local scheduler = requires("src/framework/scheduler.lua")
requires("src/netcenter/buffer.lua")
local Socket = requires("src/netcenter/Socket.lua")
local RequestCenter = requires("src/netcenter/RequestCenter.lua")
local NetManage = class("NetManage")
local HEARTBEAT_TIME = 50            --  socket heart beat time

function NetManage:ctor()          
    self:init()
end

--初始化类的实例
function NetManage:init()
    self.dataCache_ = {}                    --断网时缓存数据
    self.chatNet = nil                      --聊天
    self.heartBeatNet = nil                 --心跳
    self.pushMsgNet = nil                   --推送
    self._buf = nil
    -- self.httpCenter = nil
    self.socket = nil 
    self.requestCenter = nil
    ZCMarqueeNode.data = {}
    self.heartBeatResponse = true
    self.waitHeartBeatResponse = 0
    self.pre_time = nil
    self._reconnectTime = 0
end

-- 获取socket连接
function NetManage:getSocket()
    if self.socket == nil then
        print("new Socket=============================>")
        self.socket = Socket.new()
        self.socket:setDelegate(self)
        self._buf = net.Buffer:new()
    end
    return self.socket
end

-- 关闭连接
function NetManage:closeConnect()
    -- local socket = self:getSocket()
    if self.socket ~= nil then
        self.socket:closeConnect()
        self.socket = nil 
        self:init()   
    end
end
--连接成功
function NetManage:onConnectSuccess()
    -- self:onRemoveNetLoading()
    -- 登录 gameServer
    self.pre_time = PlayerData:getTime()
    -- print("---self.pre_time---",self.pre_time)
    self:getRequestCenter()
    if not IS_TOKEN_LOGIN then
        self:openHeartBeat()
    end
    -- dump(self.socket, "-------onConnectSuccess-----")
end

function NetManage:openHeartBeat()
    local __heartBeat = function()
        print("__heartBeat")
        if not self.pre_time then self.pre_time = PlayerData:getTime() end
        local _cur_time = PlayerData:getTime()
        if (_cur_time - self.pre_time) > 15 then
            self.pre_time = _cur_time
            --如果心跳没有返回则主动断开，重新连接
            if not self.heartBeatResponse then
                print("======================>heart beat did not response")
                self:closeHeartBeat()
                self:closeConnect()
                initConnectNet(SOCKET_LOGIN_SERVER, CHAT_SERVER_PORT)
                return
            end
            -- print("----GAMEUID---",GAMEUID)
            local socket = self:getSocket()
            local array = {op = 100,data = {userId = GAMEUID}}
            -- local sendData = self._buf:pack(array)
            socket:sendMsg(array,false)
            self.heartBeatResponse = false
        end       
    end

    local function __heartBeatCallback(data)
        print("__heartBeatCallback")
        --dump(data)
        if tonumber(data.op) == 100 then 
            self.heartBeatResponse = true
            self.waitHeartBeatResponse = 0
        else
            self.heartBeatResponse = false
            --self:loginout()
        end
    end

    self:getSocket():registerCallback(100, __heartBeatCallback)
    self.heartBeatNet = scheduler.scheduleGlobal(__heartBeat, HEARTBEAT_TIME)
end

function NetManage:closeHeartBeat()
    print("NetManage:closeHeartBeat")
    if self.heartBeatNet then 
        scheduler.unscheduleGlobal(self.heartBeatNet)
        self.heartBeatNet = nil  
    end
    if self._reConnectTimer then
        scheduler.unscheduleGlobal(self._reConnectTimer)
        self._reConnectTimer = nil
    end
end

--连接失
function NetManage:onConnectFailed()
    print("NetManage:onConnectFailed --ip_ ---port_---self._reconnectTime---",self.ip_,self.port_,self._reconnectTime)
    -- self:onRemoveNetLoading()
    --三次重连失败断开socket
    if self._reconnectTime >= 2 then
        print("重新连接失败，现在断开socket，30秒后重新尝试连接...")
        self:closeHeartBeat()
        self:closeConnect()
        self._reConnectTimer = scheduler.performWithDelayGlobal(function()
            self._reconnectTime = 0
            initConnectNet(SOCKET_LOGIN_SERVER, CHAT_SERVER_PORT)
        end, 30)
    else 
        self._reconnectTime = self._reconnectTime + 1
    end
end

-- loginout
function NetManage:loginout()
    self:closeConnect()
end

--连接ing
function NetManage:onNetLoading(comid)
    print("-----onNetLoading--------",comid)
    zc.createPop(LAYER_NAME_TAG.LAYER_LOADING)
end

--remove 连接ing
function NetManage:onRemoveNetLoading(comid)
    LayerManager.closeLoading()
end

--接受网络协议
function NetManage:onReceiveMsg(comid, data)
    print("NetManage:onReceiveMsg==========>",comid)
    -- self:dispatchEvent(comid, data)
    -- --移除loading
    -- if HEARTBEAT ~= comid then 
    --     self:onRemoveNetLoading(comid)
    -- end
end

--连接网络
function NetManage:connectNet(ip, port)
    -- self:onNetLoading()
    self.ip_ = ip or self.ip_
    self.port_ = port or self.port_
    self:getSocket():connect(self.ip_ ,self.port_)
end

--初始化加载数据加载
function NetManage:loadData()

end

--socket协议统一管理中心
function NetManage:getRequestCenter()
    if self.requestCenter == nil then
        self.requestCenter = RequestCenter.new()
    end
    return self.requestCenter
end

function NetManage:clear()
    self:closeHeartBeat()
    self:closeConnect()
    self:init()
end

--@return
return NetManage
