
local SocketTCP = requires("src/framework/cc/net/SocketTCP.lua")
requires("src/netcenter/buffer.lua")

local Socket = Socket or class("Socket")

-- 检测发送协议时间间隔
local SEND_SOCKET_TICK_TIME = 0.5  
-- 检测发送协议时间超时
local SEND_SOCKET_SEND_PROTO_TIMEOUT = 15   

local RECV_SOCKET_HEARTBEAT_TIME = 35.0

function Socket:ctor()
    self.ip = nil
    self.port = nil
    self.delegate = nil --netCenter
    self.sendTotalTime = 0.0
    self.recvHeartBeatCheck = nil
    self.receiveTable = {}
    self._buf = nil
    self._buffer = nil
    self.waitingForHeader = true
    self.buff_pool = ""
end


function Socket:setDelegate(delegate)
    self.delegate = delegate
end

function Socket:connect(ip, port)
    print("socket.getTime:",SocketTCP.getTime())
    print("os.gettime:", os.time())
    print("socket._VERSION:", SocketTCP._VERSION)
    self.ip = ip   
    self.port = port  
    if not self._socket then
        self._socket = SocketTCP.new(self.ip,self.port, true)
        self._socket:addEventListener(SocketTCP.EVENT_CONNECTED,handler(self,self.onStatus))
        self._socket:addEventListener(SocketTCP.EVENT_CLOSE, handler(self,self.onStatus))
        self._socket:addEventListener(SocketTCP.EVENT_CLOSED, handler(self,self.onStatus))
        self._socket:addEventListener(SocketTCP.EVENT_CONNECT_FAILURE, handler(self,self.onStatus))
        self._socket:addEventListener(SocketTCP.EVENT_DATA, handler(self,self.onReceiveMsg))      
    end
    self._buf = net.Buffer:new()
    self.status = nil
    self._socket:connect()
end

--注册协议号对应的callback函数
--decodeWhat对应proto文件中相关的结构名称
--callback 回调函数
function Socket:registerCallback(comid, callback)
    print("----comid----",comid)
    -- if self.receiveTable[comid] == nil then
        self.receiveTable[comid] = {}
    -- end

    -- if self.receiveTable[comid].callbacks == nil then
        self.receiveTable[comid].callbacks = {}
    -- end

    table.insert(self.receiveTable[comid].callbacks,callback)
end


--注销协议号对应的callback函数
function Socket:unregisterCallback(comid)
    self.receiveTable[comid] = nil
end

function Socket:onStatus(__event)
    self.status = __event.name
    print("Socket:onStatus=["..tostring(__event.name).."]")
    if SocketTCP.EVENT_CONNECTED == __event.name then
        print("Network is connected")
        if self.delegate ~= nil then
            self.delegate:onConnectSuccess()
        end
    elseif SocketTCP.EVENT_CLOSE == __event.name then
        print("Network connect close " .. __event.name)
    elseif SocketTCP.EVENT_CLOSED == __event.name then
        --连接中断，自动连接
        print("Network connect closed")
        if self.delegate ~= nil then
            self.delegate:closeHeartBeat()            
        end
    elseif SocketTCP.EVENT_CONNECT_FAILURE == __event.name then
        --连接超时，提示是否重连
        print("Network connect failed")        
        if self.delegate ~= nil then
            self.delegate:onConnectFailed()            
        end
    else
        error("Network status error: " .. __event.name)
    end
end
--在这里做分发
--13 + len 为当前数据包包含包头的总长度
function Socket:onReceiveMsg(__event)
    -- print("onReceiveMsg____________event.data＝",tostring(__event.data))
    self.buff_pool = self.buff_pool..__event.data
    local buff_len = #self.buff_pool
    repeat
        if buff_len < 13 then return end                
        local headlen,len,packet = self._buf:unpack(self.buff_pool)
        if (buff_len < headlen + len - 1) or (not packet) then return end
        self:mapping(packet)
        self.buff_pool = string.sub(self.buff_pool, len + headlen)
        buff_len = #self.buff_pool
    until false
    
end

--收到消息进行处理
function Socket:mapping(buff)
    print("-----------log--------ad--------get socket----- ", buff.op)
    -- if cc.Director:getInstance():isDisplayStats() then
    --     dump(buff)
    -- end
    local t = buff
    local dataHandler = self.receiveTable[buff.op]
    --数据层
    if dataHandler and dataHandler.callbacks then
        for _,callback in pairs(dataHandler.callbacks) do
            callback(t)
            if buff.op ~= 100 then
                -- zc.writeLog(t)
            end
        end         
    end
end

function Socket:reSend(data)
    -- cclog("net:___Socket:reSend=================>")
    --self._socket:send(data)
end

function Socket:sendMsg(data, isShowLoading)

    if self.delegate and (isShowLoading == nil or isShowLoading==true) then
        self.delegate:onNetLoading(comid)
    end

    if not self._socket then
        return
    end

    if self.delegate and (isShowLoading == nil or isShowLoading==true) then
        self.delegate:onNetLoading()
    end    
    local sendData = self._buf:pack(data)
    self._socket:send(sendData)
end

-- 关闭协议发送的检测
function Socket:closeSendTimeScheduler()
    -- if self.sendTimeTickScheduler then 
    --     timer.unscheduleGlobal(self.sendTimeTickScheduler) 
    -- end
    -- self.sendTotalTime = 0.0
end

-- 关闭连接
function Socket:closeConnect()
    -- print("--Socket:closeConnect--")   
    if self._socket then 
        self._socket:close()
        self._socket:disconnect()
        self._socket = nil
    end
    self.receiveTable = {}
end

return Socket
