--  Created by zhangchao on 16-04-21.
--[[
http网络请求模块.
1.异步请求
2.能设置请求的回调函数
3.网络失败需要提示，且能支持重新请求
]]
--游戏请求地址
-- debug

ZCHttp = class("ZCHttp")
requires("src/layer/loading/LoadingCircleLayer.lua")
local MessagePack = requires("src/netcenter/MessagePack.lua")
HTTP_OPEN_ENCRYPT = true
--[[loading的类型]]
HTTP_LOADING_TYPE = {
    CIRCLE  = 0,
    NONE    = 1
}
--请求的方式，默认全部是GET
HTTP_REQUEST_TYPE = {
    GET = 0,
    POST = 1
}

HTTP_ENCRYPT_TYPE = {
    AES = "aes",
    NONE = "none"
}

HTTP_RESPONSE_TYPE = {
    JSON = "json",
    PACK = "pack",
    STRING = "string"
}

local function _getMethod(method)
    local _method = "GET"
    if method == HTTP_REQUEST_TYPE.POST then
        _method = "POST"
    end
    return _method
end

function ZCHttp:ctor(params)
end

--创建http
function ZCHttp:createWithParams(params)
    local http = ZCHttp.new(params)
    return http
end


--[[
异步请求网络
@url                     请求的网络地址(完整地址)
@method                  HTTP_REQUEST_TYPE.POST / HTTP_REQUEST_TYPE.GET
@startCallback           请求开始时的回调函数
@successCallback         请求成功的回调
@failedCallback          请求失败的回调
@targetNeedsToRetain     
@postData  
@loadingType             
@loadingNode             loading界面 
@loadingParent           loading界面所在的父容器
@reconnectTimes          网络请求失败后重新连接的次数(0不重新链接)
]]
function ZCHttp:requestAsyncWithParams(params)
    print("ZCHttp:requestAsyncWithParams")
    local url                 = tostring(params.url)--[[请求的网络地址(完整地址)]]
    local method              = params.method--[[请求的方式]]
    local startCallback       = params.startCallback--[[开始请求时的回调函数]]
    local successCallback     = params.successCallback--[[请求成功的回调函数]]
    local failedCallback      = params.failedCallback--[[请求失败的回调函数(此处的失败一般是指网络超时或者服务器返回的数据无法解析成json)]]
    local errorCallback       = params.errorCallback--[[请求失败的回调函数(此处的失败是指走的错误码的通用处理)]]
    local targetNeedsToRetain = params.targetNeedsToRetain--[[请求时需要被retain的对象]]
    local postData            = params.postData--[[post请求时需要的数据]]
    local loadingType         = params.loadingType--[[]]
    local loadingNode         = params.loadingNode
    local loadingParent       = params.loadingParent
    local reconnectTimes      = params.reconnectTimes--[[如果网络失败，重新连接的次数(0或nil代表不需要重试)]]
    local timeoutForRead      = params.timeoutForRead
    local timeoutForConnect   = params.timeoutForConnect
    local encrypt             = params.encrypt
    local responseType        = params.responseType
    local isGameApi           = params.isGameApi

    if nil == loadingType       then loadingType = HTTP_LOADING_TYPE.CIRCLE     end
    if nil == method            then method = HTTP_REQUEST_TYPE.POST            end
    if nil == reconnectTimes    then reconnectTimes = 0                         end
    if nil == timeoutForRead    then timeoutForRead = 10                        end
    if nil == timeoutForConnect then timeoutForConnect = 10                     end
    if nil == responseType      then responseType = HTTP_RESPONSE_TYPE.JSON     end
    if nil == encrypt           then encrypt = HTTP_ENCRYPT_TYPE.AES            end
    if nil == isGameApi         then isGameApi = true                           end
    
    local runningScene   = cc.Director:getInstance():getRunningScene()
    local _loadingNode   = loadingNode
    local _loadingParent = loadingParent
    if _loadingParent == nil then _loadingParent = runningScene end
    --加载loading层
    if _loadingNode == nil then
        if loadingType == HTTP_LOADING_TYPE.CIRCLE   then _loadingNode = LoadingCircleLayer:create()
        elseif loadingType == HTTP_LOADING_TYPE.NONE then end
    end
    --[[移除loading页面]]
    if _loadingNode ~= nil and _loadingParent~= nil then
        print("开始添加loading页面")
        _loadingParent:addChild(_loadingNode, 1000)
    end
    local _doRequest = nil
    local _failedCallback = function()
        --如果有失败的回调，则需要执行该回调
        if reconnectTimes > 0 then
            reconnectTimes = reconnectTimes - 1
            print("网络请求失败，正在重新连接...重新连接次数还剩下:"..reconnectTimes)
            _doRequest()
        else
            if not tolua.isnull(_loadingNode) then _loadingNode:removeFromParent() end
            if failedCallback then failedCallback() else zc.tipInfo(zc.lang("tips_network_error")) end
        end
    end
    local _url = url
    _doRequest = function()
        print("开始创建网络请求")
        if not tolua.isnull(targetNeedsToRetain) then targetNeedsToRetain:retain() end
        local xhr = cc.XMLHttpRequest:new()
        xhr.timeoutForConnect = timeoutForConnect
        xhr.timeoutForRead = timeoutForRead
        -- cc.XMLHTTPREQUEST_RESPONSE_STRING       = 0
        -- cc.XMLHTTPREQUEST_RESPONSE_ARRAY_BUFFER = 1
        -- cc.XMLHTTPREQUEST_RESPONSE_BLOB         = 2
        -- cc.XMLHTTPREQUEST_RESPONSE_DOCUMENT     = 3
        -- cc.XMLHTTPREQUEST_RESPONSE_JSON         = 4
        xhr.responseType = cc.XMLHTTPREQUEST_RESPONSE_STRING
        --[[在所有请求中加入渠道参数，方便后端做数据统计]]
        local _isGt = zc.isGt() and 1 or 0
        if postData then
            if isGameApi == true then
                postData = postData .. "&game_channel=" .. tostring(GAME_CHANNEL) .. "&isTraditional=" .. _isGt
            end
            print("url="..tostring(_url)..tostring(postData))
        else
            if isGameApi == true then
                _url = _url .. "&game_channel=" .. tostring(GAME_CHANNEL) .. "&isTraditional=" .. _isGt
            end
            print("url="..tostring(_url))
        end
        xhr:open(_getMethod(method), _url)
        local function onReadyStateChanged()
            if not tolua.isnull(targetNeedsToRetain) then targetNeedsToRetain:release() end
            xhr:unregisterScriptHandler()
            local response = xhr.response
            -- print("ZCHTTP_response : ", response)
            --[[4:DONE ]]
            if xhr.readyState == 4 and xhr.status == 200 then
                local parseJsonFailedCallback = function(msg)
                    print("----------------------------------------")
                    print("LUA ERROR: " .. tostring(msg) .. "\n")
                    
                    print(debug.traceback())
                    print("----------------------------------------")
                    print("网络请求失败，原因是：解析数据出错")
                    zc.tipInfo(zc.lang("tips_data_error"))
                end
                local data = nil
                local function xpcall_callback()
                    if responseType == HTTP_RESPONSE_TYPE.PACK then
                        data = MessagePack.unpack(response)
                    elseif responseType == HTTP_RESPONSE_TYPE.JSON then
                        -- base64
                        if encrypt == HTTP_ENCRYPT_TYPE.AES then
                            local responseDecode = ""
                            local len = string.len(response)
                            local step = math.ceil(len / 4)
                            for i = 1, 4 do
                                local p2 = len - step * (i - 1)
                                local p = step * i * -1
                                responseDecode = responseDecode .. string.sub(response, p, p2)
                            end
                            response = crypto.decodeBase64(responseDecode)
                        end
                        print("ZCHTTP_response : ", response)
                        data = json.decode(response)
                    elseif responseType == HTTP_RESPONSE_TYPE.STRING then
                        print("ZCHTTP_response : ", response)
                        data = response
                    end
                end
                xpcall(xpcall_callback, parseJsonFailedCallback)
                if data then
                    --记录log
                    -- zc.writeLog(data, true, responseType, postData)
                    -- local info = ""
                    -- if responseType == HTTP_RESPONSE_TYPE.STRING then
                    --     print("url=".._url..tostring(postData).."------->"..data)
                    --     info = (postData or "") .."      " .. (data)
                    -- else
                    --     print("url=".._url..tostring(postData).."------->"..zc.table2json(data))
                    --     info = (postData or "") .."      " .. zc.table2json(data)
                    -- end

                    if not tolua.isnull(_loadingNode) then 
                        _loadingNode:removeFromParent() 
                        print("移除loading页面")
                    end

                    local status = data.status
                    --[[如果是游戏内的请求，则需要处理status]]
                    local function _updateTssTime( data )
                        if data.tss and PlayerData then
                            xpcall(function()
                                PlayerData:setTssTime(data.tss)
                            end, function() end)
                        end
                    end
                    if isGameApi == true then
                        if status == nil then
                            -- print("请求错误：状态值异常")
                            zc.tipInfo(zc.lang("tips_response_error"))
                        elseif status == 1 and isGameApi == true then
                            local errorCode = data.data.errorCode or 1
                            print(" errorCode ---------------------------------------------> ", errorCode)
                            if errorCode == 12 or errorCode == 158 then
                                -- 返回登录
                                zc.createReLoginTip()
                            elseif errorCode == 355 then
                                -- 请求过快不处理
                                if data and data.op and tonumber(data.op) == 805 then --国家科技捐献这里特殊处理，返回错误码
                                    local errorMsg = data.data.errorMsg
                                    if errorCallback then
                                        -- 把错误码传给回调
                                        errorCallback( errorCode, errorMsg )
                                    else
                                        zc.tipInfo(LANGUAGE_GETERRORTIP(errorMsg))
                                    end
                                else
                                    --其它的暂不处理
                                    
                                end
                            else
                                local errorMsg = data.data.errorMsg
                                if errorCallback then
                                    -- 把错误码传给回调
                                    errorCallback( errorCode, errorMsg )
                                else
                                    zc.tipInfo(LANGUAGE_GETERRORTIP(errorMsg))
                                end
                            end
                        elseif successCallback then
                            _updateTssTime(data)
                            successCallback(data,url)
                            --[[刷新用户数据]]
                            if PlayerData ~= nil and PlayerData.info ~= nil and tonumber(status) == 1 then
                                PlayerData:updateLiveness(data)
                            end
                        end
                    elseif successCallback then
                        _updateTssTime(data)
                        successCallback(data,url)
                    end
                    
                else
                    print("服务器返回出错，data为空data为空data为空data为空data为空")
                    _failedCallback()
                end
            else
                print("网络请求失败，原因是：网络问题或者服务器返回状态码不对")
                _failedCallback()
            end
        end
        xhr:registerScriptHandler(onReadyStateChanged)
        xhr:send(postData)
--*****************以下方式为自定义请求网络留作备用，优先使用官方自带的网络模块************************
        -- local request = zc.ZCRequest:create(_url,requestCallback,targetNeedsToRetain,method)
        -- request:setTimeoutForConnect(timeoutForConnect)
        -- request:setTimeoutForRead(timeoutForRead)
        -- if method == HTTP_REQUEST_TYPE.POST and postData then
        --     request:setRequestData(postData, string.len(postData))
        -- end
        -- --启动异步请求
        -- --阻塞式 用 request:start()--阻塞请求
        -- request:startWithAsync()
--***************************************************************************************
    end
    _doRequest()
end

